<?php
/**
* Class Content
*
* @copyright     ASTALAVISTA SECURE CMS - 2005 Astalavista IT Engineering GmbH          
* @module    	 themes
* @modulegroups  core                    
* @author        Ivan Schmid <ivan.schmid@astalavista.ch>
* @author        Christian Wehrli <christian.wehrli@astalavista.ch>              
* @version       $Id:  Exp $                                         
*/


class ContentManager
{
   /**
    * @var object
    * @desc template object
    */    
	var $_objTpl;
	
	
   /**
    * @var string
    * @desc page title
    */ 	
	var $pagetitle="";
	
   /**
    * @var string
    * @desc status message (error message)
    */ 		
	var $statusMessage = "";
	
   /**
    * @var string
    * @desc module id
    */ 		
	var $setModule = "";
	
   /**
    * @var string
    * @desc CMD
    */ 	
	var $setCmd = "";
	
   /**
    * @var array
    * @desc Array with the WYSIWYG module ids
    */ 	
	var $arrNoExpertmodes = array();
		
   /**
    * @var int
    * @desc Language id
    */ 	
	var $langId;

   /**
    * @var array
    * @desc array of all frontend groups ( name, id )
    */ 	
	var $arrAllFrontendGroups = array();
	
   /**
    * @var array
    * @desc array of all backend groups ( name, id )
    */ 	
	var $arrAllBackendGroups = array();	

	
   /**
    * @var array
    * @desc array of required modules
    * 1->core, 13->ids, 14->error, 15->home, 18->login
    *
    * @access private
    */ 	
	var $_requiredModules = array(1,13,14,15,18);	
	
	
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */
    function ContentManager()
    {        
    	global  $db, $objInit, $_CORELANG, $template;
    	
		$this->_objTpl = &new HTML_Template_Sigma(ASCMS_ADMIN_TEMPLATE_PATH);
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);
		
		$this->langId=$objInit->userFrontendLangId;

		$template->set_var("CONTENT_NAVIGATION",
		                   "<a href='index.php?cmd=content&amp;act=new'>[".$_CORELANG['TXT_NEW_PAGE']."]</a>&nbsp;
		                    <a href='index.php?cmd=content'>[".$_CORELANG['TXT_CONTENT_MANAGER']."]</a>&nbsp;
		                    <a href='index.php?cmd=media&path=/images/content/'>[".$_CORELANG['TXT_IMAGE_ADMINISTRATION']."]</a>");
		    	
	    $db->query("OPTIMIZE TABLE ".DBPREFIX."content");
	    $db->query("OPTIMIZE TABLE ".DBPREFIX."content_navigation"); 
	    
   		// normally all modules are in source code mode
   		// Except the following modules : 15 Home, 13 Error, 14 IDS, 0 no module 
   		// Not in use anymore!    
        $this->arrNoExpertmodes = array(0,13,14,15);
        	
        $this->arrAllFrontendGroups = $this->_getAllGroups($groupType="frontend"); 
        $this->arrAllBackendGroups = $this->_getAllGroups($groupType="backend");     
    }
    

    
    
    /**
    * getPage
    *
    * calls the requested function
    *     
    * @return object _objTpl                                                                               
    */
    function getPage()
    {
    	global $_CORELANG, $template, $objPerm;
    	
    	if(!isset($_GET['act'])){
    	    $_GET['act']="";	
    	}   	  	
    	    	
        switch($_GET['act'])
		{
			case "deleteAll":
			    $objPerm->checkPerm(53);
			    $this->_deleteAll();
			    $this->contentOverview();
			    // header("Location: index.php?cmd=content");
			    break;
			    
			case "copyAll":
				$objPerm->checkPerm(53);
				$this->_copyAll();
				$this->showCopyPage();
				break;
				
			case "new":
			    $objPerm->checkPerm(5);
			    $this->showNewPage();
			    break;
			    
			case "edit":
			    $objPerm->checkPerm(35);
				$this->showEditPage();
			    break;
			
			case "update":
			    $objPerm->checkPerm(35);
			    $this->updatePage();
		        $this->contentOverview();
			    break;				   
			    
			case "changeprotection":	    
			    $this->changeProtection();			    
		        $this->contentOverview();
			    break;	
			    		
			case "changestatus":
			    $objPerm->checkPerm(35);		    
			    $this->changeStatus();
		        $this->contentOverview();
			    break;			
			
			case "add":
			    $objPerm->checkPerm(5);
			    $this->addPage();
                $this->contentOverview();
		        break;	
			
			case "delete":
			    $objPerm->checkPerm(26);
			    $this->deleteContent();
		        $this->contentOverview();
			    break;
			/*    
		    case "updatepermission":
		        $objPerm->checkPerm(36);		    
			    $this->_updateFrontendPermissions();
		        $this->contentOverview();
			    break;
			*/

			case "addrepository":
			    $objPerm->checkPerm(37);		    
			    $this->addToRepository();
		        $this->contentOverview();
			    break;
			    
			default:
			    $objPerm->checkPerm(6);
		        $this->contentOverview();
		        break;
		}
		$template->set_var("CONTENT_TITLE",$this->pageTitle); 		
		$template->set_var("CONTENT_STATUS_MESSAGE",$this->statusMessage); 		
		return $this->_objTpl->get();  
    }

    
    
	/**
	* Show copy page
	*
	* @global	array $_CORELANG
	*/
	function showCopyPage()
	{
		global $_CORELANG, $objLanguage;
		
		if(isset($_REQUEST['langOriginal']) && !empty($_REQUEST['langOriginal'])){
			$this->contentOverview();
			unset($_REQUEST['langOriginal']);
		} else {						
			$this->_objTpl->loadTemplateFile('content_copy_all.html',true,true);
			$this->pageTitle = $_CORELANG['TXT_COPY_CONTENT'];
			$this->_objTpl->setVariable(array(
					'TXT_COPY_CONTENT'	=> $_CORELANG['TXT_COPY_CONTENT'],
					'TXT_COPY'			=> $_CORELANG['TXT_COPY'],
					'TXT_COPY_CONTENT_OF_TO'	=> $_CORELANG['TXT_COPY_CONTENT_OF_TO'],
					'TXT_THIS_PROCEDURE_DELETES_ALL_EXISTING_ENTRIES_OF_THE_SELECTED_LANGUAGE' => $_CORELANG['TXT_THIS_PROCEDURE_DELETES_ALL_EXISTING_ENTRIES_OF_THE_SELECTED_LANGUAGE'],
					'TXT_WARNING'		=> $_CORELANG['TXT_WARNING'],
					'TXT_DO_YOU_WANT_TO_CONTINUE'	=> $_CORELANG['TXT_DO_YOU_WANT_TO_CONTINUE']
					));
					
			foreach ($objLanguage->getLanguageArray() as $key){
				if($key['id'] == $this->langId) {
					$this->_objTpl->setVariable(array(
							'LANG_OLD_ID' => $this->langId,
							'LANG_OLD_NAME' => $key['name']
							));
				} else {
					$this->_objTpl->setCurrentBlock('langList');
					$this->_objTpl->setVariable(array(
							'LANG_ID' => $key['id'],
							'LANG_NAME' => $key['name']
							));
					$this->_objTpl->parseCurrentBlock();
				}
			}
		}
	}

	
	
	
	/**
	* Copy page content
	*
	* @global	object	$objDb
	* @global	array	$_CORELANG
	*/
	function _copyAll()
	{
		global $objDb, $_CORELANG;

		if(isset($_POST['langOriginal']) && !empty($_POST['langOriginal'])){
			$this->_deleteAll(intval($_POST['langNew']));
			$objDb->query("SELECT catid,
								  parcat,
								  catname,
								  displayorder,
								  displaystatus,
								  username,
								  changelog,
								  cmd,
								  module,
								  startdate,
								  enddate,
								  protected,
								  frontend_groups,
								  backend_groups,
								  themes_id
							 FROM ".DBPREFIX."content_navigation
							WHERE lang=".intval($_POST['langOriginal']));
			$arrQuery = array();
			$arrId = array();
			while ($objDb->next_record()){
				array_push($arrQuery, "INSERT INTO ".DBPREFIX."content_navigation (
													parcat, 
													catname, 
													displayorder, 
													displaystatus, 
													username, 
													changelog, 
													cmd, 
													lang,
													module,
													startdate,
													enddate,
													protected,  
													frontend_groups,  
													backend_groups,  
													themes_id
													) VALUES (
													'".addslashes($objDb->f("parcat"))."',  
													'".addslashes($objDb->f("catname"))."',  
													'".addslashes($objDb->f("displayorder"))."', 
													'".addslashes($objDb->f("displaystatus"))."', 
													'".addslashes($objDb->f("username"))."', 
													'".addslashes($objDb->f("changelog"))."', 
													'".addslashes($objDb->f('cmd'))."', 	
													'".intval($_POST['langNew'])."', 
													'".addslashes($objDb->f("module"))."', 
													'".addslashes($objDb->f("startdate"))."', 
													'".addslashes($objDb->f("enddate"))."', 
													'".addslashes($objDb->f("protected"))."', 	
													'".addslashes($objDb->f("frontend_groups"))."', 
													'".addslashes($objDb->f("backend_groups"))."', 
													'".addslashes($objDb->f("themes_id"))."'
													)");
				array_push($arrId,array("old" => $objDb->f("catid")));
			}
			
			for($i=0;$i<count($arrQuery);$i++){
				$objDb->query($arrQuery[$i]);
				$arrId[$i]['new'] = $objDb->insert_id();
			}
			
			for($i=0;$i<count($arrId);$i++){
			    $objDb->query("UPDATE ".DBPREFIX."content_navigation 
			                      SET parcat='".$arrId[$i]['new']."'
			                    WHERE parcat='".$arrId[$i]['old']."'
			                      AND lang='".$_POST['langNew']."'
			                      AND parcat!=0");
			}
			
			unset($arrQuery);
			$arrQuery = array();
			for($i=0;$i<count($arrId);$i++){
				$objDb->query("SELECT content,
									  title,
									  metadesc,
									  metakeys,
									  metarobots,
									  redirect,
									  expertmode
								 FROM ".DBPREFIX."content
								WHERE id=".intval($arrId[$i]['old']));
				if($objDb->next_record()){
					array_push($arrQuery,"INSERT INTO ".DBPREFIX."content (id,content,title,metadesc,metakeys,metarobots,redirect,expertmode)
					VALUES(
					'".intval($arrId[$i]['new'])."',
					'".$objDb->f("content")."', 
					'".$objDb->f("title")."',  
					'".$objDb->f("metadesc")."',  
					'".$objDb->f("metakeys")."', 
					'".$objDb->f("metarobots")."', 
					'".$objDb->f("redirect")."', 
					'".$objDb->f("expertmode")."'
					)
					");
				}
			}
			
			for($i=0;$i<count($arrQuery);$i++){
				$objDb->query($arrQuery[$i]);
			}
			unset($arrQuery);	
			$objDb->query("OPTIMIZE TABLE ".DBPREFIX."content_navigation");
			$objDb->query("OPTIMIZE TABLE ".DBPREFIX."content");
		}
	}
	
	
	
	/**
    * Deletes all global site content
    *
    * @global object $objDb
    * @global array  $_CORELANG                                                                      
    */
	function _deleteAll($langId=0)
	{
		global $objDb, $_CORELANG, $objLanguage;
		
		if(isset($_GET['contentId']) && intval($_GET['contentId'])!=0) {
			$langId = intval($_GET['contentId']);
		} 
		if(intval($langId)!=0){	
			// the default language site cannot be deleted
			if($objLanguage->getLanguageParameter($langId, "is_default")=="true"){
				$this->statusMessage= $_CORELANG['TXT_STANDARD_SITE_NOT_DELETED'];

			} else {
				$arrQuery = array();
				$objDb->query("SELECT catid FROM ".DBPREFIX."content_navigation WHERE lang=".intval($langId));
				while($objDb->next_record()){
					array_push($arrQuery, "DELETE FROM ".DBPREFIX."content WHERE id=".$objDb->f('catid'));
				}
				for($i=0;$i<count($arrQuery);$i++) {
					$objDb->query($arrQuery[$i]);
				}
				unset($arrQuery);
				$objDb->query("DELETE FROM ".DBPREFIX."content_navigation WHERE lang=".intval($langId));
			}
		}
	}   
    
	
	
    /**
    * @access private
    * @return array
    * @param string groupType
    * @desc gets all frontend groups as an array
    */   
	function _getAllGroups($groupType="frontend")
	{
	    $objDb = &new astalavistaDB;
	    
        if($groupType!="frontend"){
        	$groupType="backend";
        }
        	        
	    $arrGroups=array();	    
		$objDb->query("SELECT group_id, group_name FROM ".DBPREFIX."user_groups WHERE type='".$groupType."'");
    	while ($objDb->next_record()){
    		$arrGroups[$objDb->f('group_id')]=$objDb->f('group_name'); 		
    	}
    	return $arrGroups;					 				
	}
    
    
    
    
    
    /**
    * Show sitemap
    *
    * @version   1.0        initial version 
    * @global    object     $db
    * @global    array      $_GET['act']                                                                    
    */
    function contentOverview()
    {
    	global $db;
    	    	        
	    $this->pageTitle = $_CORELANG['TXT_CONTENT_MANAGER']; 
        
		if ($_GET['act'] == "mod"){
			foreach ($_POST['catid'] as $value){
				$displayorder_old = $_POST['displayorder_old'][$value];
				$displayorder_new = $_POST['displayorder_new'][$value];
				if ($displayorder_old != $displayorder_new){
					$db->query("UPDATE ".DBPREFIX."content_navigation 
					               SET displayorder='$displayorder_new' 
					             WHERE catid=$value");
				}
			}	
		}		
		$objNavbar = &new ContentSitemap(0);
		$this->_objTpl->setTemplate($objNavbar->getSiteMap(),true,true);	
    } 
    

    
    
    
    /**
    * Create new page
    *
    * @global    object     $db                                                                   
    */
    function showNewPage()
    {
	    global $db, $_CORELANG;
	    
	    // init variables
	    $contenthtml="";
	    $pageId = "";
	    $tablestatus="none";
		$existingFrontendGroups = "";
		$existingBackendGroups = "";
		
		
	    $this->_objTpl->loadTemplateFile('content_editor.html',true,true);	    
	    $this->pageTitle = $_CORELANG['TXT_NEW_PAGE'];
				
		if(isset($_GET['pageId']) & !empty($_GET['pageId'])){
			$pageId = intval($_GET['pageId']);
				
			$db->query("SELECT content,
			                   metadesc, 
			                   metarobots, 
			                   title, 
			                   metakeys 
			              FROM ".DBPREFIX."content 
			             WHERE id = $pageId LIMIT 1");
			
			if($db->next_record()){
				$contenthtml= stripslashes($db->f('content'));									
				$contenthtml = preg_replace('/\{([A-Z0-9_]*?)\}/', '[[\\1]]' ,$contenthtml);		
				
				$this->_objTpl->setVariable(array(
					'CONTENT_HTML'	 => get_wysiwyg_editor('html', $contenthtml, 'active'),
					'CONTENT_DESC'   => $db->f('contentdesc'),
					'CONTENT_TITLE'  => $db->f('contenttitle'),
					'CONTENT_KEY'  	 => $db->f('contentkey'),				
				));
			}
			$db->query("SELECT module, 
			                   startdate, 
			                   enddate, 
			                   displaystatus,
			                   themes_id
			              FROM ".DBPREFIX."content_navigation 
			             WHERE catid = $pageId LIMIT 1");
			
			if($db->next_record()){
				$moduleId=$db->f('module');
				$startDate=$db->f('startdate');
				$endDate=$db->f('enddate');
				$displaystatus="";
				$themesId = $db->f('themes_id');
				
				if ($db->f('displaystatus') == "on" ){ 
					$displaystatus = "checked";
				}

				$robotstatus="";
				if ($db->f('metarobots')=="index"){ 
					$robotstatus="checked";
				}				
				
				$this->_objTpl->setVariable(array(
				'CONTENT_MODULE_MENU'              => $this->_getModuleMenu($moduleId),
				'CONTENT_STARTDATE'	               => $startDate,
				'CONTENT_ENDDATE'                  => $endDate,
				'CONTENT_DISPLAYSTATUS'            => $displaystatus,
				'CONTENT_TABLE_STYLE'              => $tablestatus,
				'CONTENT_ROBOTS'                   => $robotstatus,
				'CONTENT_THEMES_MENU'              => $this->_getThemesMenu($themesId),
				));	
			}																							
		}else{
			$arrAssignedFrontendGroups=$this->_getAssignedGroups($groupType="frontend");
			$this->_objTpl->setVariable(array(
			'CONTENT_HTML'	                   => get_wysiwyg_editor('html', $contenthtml, 'active'),
			'CONTENT_MODULE_MENU'              => $this->_getModuleMenu($selectedOption=""),	
			'CONTENT_DATE'	                   => date("Y-m-d"),
			'CONTENT_TABLE_STYLE'              => $tablestatus,		
			));
		}
		
		// Frontend Groups
    	foreach($this->arrAllFrontendGroups AS $id => $name){
    		$existingFrontendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
    	}  
    	
		// Backend Groups
    	foreach($this->arrAllBackendGroups AS $id => $name){
    		$existingBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
    	}    	
    		

		$this->_objTpl->setVariable(array(
		    'TXT_TARGET'               => $_CORELANG['TXT_TARGET'],
		    'TXT_MORE_OPTIONS'         => $_CORELANG['TXT_MORE_OPTIONS'],		    
		    'TXT_BASIC_DATA'           => $_CORELANG['TXT_BASIC_DATA'], 
		    'TXT_FRONTEND_PERMISSION'  => $_CORELANG['TXT_FRONTEND_PERMISSION'],
		    'TXT_RELATEDNESS'          => $_CORELANG['TXT_BACKEND_RELATEDNESS'],
		    'TXT_PAGE_NAME'            => $_CORELANG['TXT_PAGE_NAME'],
		    'TXT_MENU_NAME'            => $_CORELANG['TXT_MENU_NAME'],
		    'TXT_NEW_CATEGORY'         => $_CORELANG['TXT_NEW_CATEGORY'],
		    'TXT_ACTIVE'               => $_CORELANG['TXT_ACTIVE'],
		    'TXT_META_INFORMATIONS'    => $_CORELANG['TXT_META_INFORMATIONS'],
		    'TXT_META_TITLE'           => $_CORELANG['TXT_META_TITLE'],
		    'TXT_META_DESCRIPTION'     => $_CORELANG['TXT_META_DESCRIPTION'],
		    'TXT_META_KEYWORD'         => $_CORELANG['TXT_META_KEYWORD'],
		    'TXT_META_ROBOTS'          => $_CORELANG['TXT_META_ROBOTS'],		    
		    'TXT_CONTENT'              => $_CORELANG['TXT_CONTENT'],
		    'TXT_GENERAL_OPTIONS'      => $_CORELANG['TXT_GENERAL_OPTIONS'],
		    'TXT_START_DATE'           => $_CORELANG['TXT_START_DATE'],
		    'TXT_END_DATE'             => $_CORELANG['TXT_END_DATE'],
		    'TXT_EXPERT_MODE'          => $_CORELANG['TXT_EXPERT_MODE'],		    
		    'TXT_MODULE'               => $_CORELANG['TXT_MODULE'],
		    'TXT_NO_MODULE'            => $_CORELANG['TXT_NO_MODULE'],
		    'TXT_REDIRECT'             => $_CORELANG['TXT_REDIRECT'],
		    'TXT_NO_REDIRECT'          => "",
		    'TXT_SOURCE_MODE'          => $_CORELANG['TXT_SOURCE_MODE'],
		    'TXT_THEMES'               => $_CORELANG['TXT_THEMES'],
		    'TXT_STORE'                => $_CORELANG['TXT_STORE'],	
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_PROTECTION'           => $_CORELANG['TXT_PROTECTION'],	    
		    'TXT_PROTECTION_CHANGE'    => $_CORELANG['TXT_PROTECTION_CHANGE'],
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_GROUPS'               => $_CORELANG['TXT_GROUPS'],
		    'TXT_GROUPS_DEST'          => $_CORELANG['TXT_GROUPS_DEST'],
		    'TXT_SELECT_ALL'           => $_CORELANG['TXT_SELECT_ALL'],
		    'TXT_DESELECT_ALL'         => $_CORELANG['TXT_DESELECT_ALL'],
		    'TXT_ACCEPT_CHANGES'       => $_CORELANG['TXT_ACCEPT_CHANGES'],
		    'TXT_PUBLIC_PAGE'          => $_CORELANG['TXT_PUBLIC_PAGE'],
		    'TXT_BACKEND_RELEASE'      => $_CORELANG['TXT_BACKEND_RELEASE'],
		    'TXT_LIMIT_GROUP_RIGHTS'   => $_CORELANG['TXT_LIMIT_GROUP_RIGHTS'],
		    'TXT_TARGET_BLANK'         => $_CORELANG['TXT_TARGET_BLANK'],
		    'TXT_TARGET_TOP'           => $_CORELANG['TXT_TARGET_TOP'],
		    'TXT_TARGET_PARENT'        => $_CORELANG['TXT_TARGET_PARENT'],
		    'TXT_TARGET_SELF'          => $_CORELANG['TXT_TARGET_SELF']		
		));		
		
		$this->_objTpl->setVariable(array(
			'CONTENT_ACTION'                   => "add",
			'CONTENT_TOP_TITLE'                => $_CORELANG['TXT_NEW_PAGE'],
			'CONTENT_DISPLAYSTATUS'            => "checked",
			'CONTENT_CAT_MENU'                 => $this->getPageMenu(),
			'CONTENT_FORM_ACTION'              => "add",
			'CONTENT_ROBOTS'                   => "checked",
			'CONTENT_THEMES_MENU'              => $this->_getThemesMenu(),		
			'CONTENT_EXISTING_GROUPS'          => $existingFrontendGroups,
			//'CONTENT_ASSIGNED_GROUPS'          => "",
			'CONTENT_PROTECTION_INACTIVE'      => "checked",
			'CONTENT_PROTECTION_ACTIVE'        => "",
			'CONTENT_PROTECTION_DISPLAY'       => "none",
			'CONTENT_CONTROL_BACKEND_INACTIVE' => "checked",
			'CONTENT_CONTROL_BACKEND_ACTIVE'   => "",
			'CONTENT_CONTROL_BACKEND_DISPLAY'  => "none",
			'CONTENT_EXISTING_BACKEND_GROUPS'  => $existingBackendGroups,
			'CONTENT_ASSIGNED_BACKEND_GROUPS'  => "",										
		));			
		
    }
    
    

    
    
    /**
    * @access private
    * @return string
    * @param pageId int
    * @desc ckecks if the page is protected (returns "checked") or not.
    */   
	function _getPageProtectionStatus($pageId)
	{
	    $objDb = &new astalavistaDB;
		$objDb->query("SELECT protected FROM ".DBPREFIX."content_navigation WHERE catid=$pageId LIMIT 1");								
		$objDb->next_record();
		if ($objDb->f('protected'))
		{ 
			return "checked";
		}
		else 
		{
		    return "";
		}						 				
	}
	
	
    /**
    * @access private
    * @return array
    * @param groupType string    
    * @param pageId int (optional)
    * @desc gets all frontend or backend groups ( id,name ) from this page
    */   
	function _getAssignedGroups($groupType, $pageId=0)
	{
	    $objDb = &new astalavistaDB;
	    $arr=array();
	    
	    if(intval($pageId)!=0)
	    {
			$objDb->query("SELECT backend_groups, 
			                      frontend_groups, 
			                      protected 
			                 FROM ".DBPREFIX."content_navigation 
			                WHERE catid=$pageId 
			                LIMIT 1");
				
			if($objDb->next_record())
			{						
				if($groupType=="frontend")
				{
					$arr=explode(",", $objDb->f("frontend_groups"));
				}
				else 
				{
					$arr=explode(",", $objDb->f("backend_groups"));					
				}
			}
	    }
		return $arr;				 				
	}	

    
    /**
    * Edit page
    *
    * @global    object     $db                                                                    
    */
	function showEditPage()
	{ 
		global $db, $_CORELANG;

		$this->_objTpl->loadTemplateFile('content_editor.html',true,true);	    
	    $this->pageTitle = $_CORELANG['txtEditPage'];

		$this->_objTpl->setVariable(array(
		    'TXT_TARGET'               => $_CORELANG['TXT_TARGET'],
		    'TXT_MORE_OPTIONS'         => $_CORELANG['TXT_MORE_OPTIONS'],		    
		    'TXT_BASIC_DATA'           => $_CORELANG['TXT_BASIC_DATA'], 
		    'TXT_FRONTEND_PERMISSION'  => $_CORELANG['TXT_FRONTEND_PERMISSION'],
		    'TXT_RELATEDNESS'          => $_CORELANG['TXT_BACKEND_RELATEDNESS'],
		    'TXT_PAGE_NAME'            => $_CORELANG['TXT_PAGE_NAME'],
		    'TXT_MENU_NAME'            => $_CORELANG['TXT_MENU_NAME'],
		    'TXT_NEW_CATEGORY'         => $_CORELANG['TXT_NEW_CATEGORY'],
		    'TXT_ACTIVE'               => $_CORELANG['TXT_ACTIVE'],
		    'TXT_META_INFORMATIONS'    => $_CORELANG['TXT_META_INFORMATIONS'],
		    'TXT_META_TITLE'           => $_CORELANG['TXT_META_TITLE'],
		    'TXT_META_DESCRIPTION'     => $_CORELANG['TXT_META_DESCRIPTION'],
		    'TXT_META_KEYWORD'         => $_CORELANG['TXT_META_KEYWORD'],
		    'TXT_META_ROBOTS'          => $_CORELANG['TXT_META_ROBOTS'],		    
		    'TXT_CONTENT'              => $_CORELANG['TXT_CONTENT'],
		    'TXT_GENERAL_OPTIONS'      => $_CORELANG['TXT_GENERAL_OPTIONS'],
		    'TXT_START_DATE'           => $_CORELANG['TXT_START_DATE'],
		    'TXT_END_DATE'             => $_CORELANG['TXT_END_DATE'],
		    'TXT_EXPERT_MODE'          => $_CORELANG['TXT_EXPERT_MODE'],		    
		    'TXT_MODULE'               => $_CORELANG['TXT_MODULE'],
		    'TXT_NO_MODULE'            => $_CORELANG['TXT_NO_MODULE'],
		    'TXT_REDIRECT'             => $_CORELANG['TXT_REDIRECT'],
		    'TXT_NO_REDIRECT'          => "",
		    'TXT_SOURCE_MODE'          => $_CORELANG['TXT_SOURCE_MODE'],
		    'TXT_THEMES'               => $_CORELANG['TXT_THEMES'],
		    'TXT_STORE'                => $_CORELANG['TXT_STORE'],	
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_PROTECTION'           => $_CORELANG['TXT_PROTECTION'],	    
		    'TXT_PROTECTION_CHANGE'    => $_CORELANG['TXT_PROTECTION_CHANGE'],
		    'TXT_RECURSIVE_CHANGE'     => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_GROUPS'               => $_CORELANG['TXT_GROUPS'],
		    'TXT_GROUPS_DEST'          => $_CORELANG['TXT_GROUPS_DEST'],
		    'TXT_SELECT_ALL'           => $_CORELANG['TXT_SELECT_ALL'],
		    'TXT_DESELECT_ALL'         => $_CORELANG['TXT_DESELECT_ALL'],
		    'TXT_ACCEPT_CHANGES'       => $_CORELANG['TXT_ACCEPT_CHANGES'],
		    'TXT_PUBLIC_PAGE'          => $_CORELANG['TXT_PUBLIC_PAGE'],
		    'TXT_BACKEND_RELEASE'      => $_CORELANG['TXT_BACKEND_RELEASE'],
		    'TXT_LIMIT_GROUP_RIGHTS'   => $_CORELANG['TXT_LIMIT_GROUP_RIGHTS'],	
		    'TXT_TARGET_BLANK'         => $_CORELANG['TXT_TARGET_BLANK'],
		    'TXT_TARGET_TOP'           => $_CORELANG['TXT_TARGET_TOP'],
		    'TXT_TARGET_PARENT'        => $_CORELANG['TXT_TARGET_PARENT'],
		    'TXT_TARGET_SELF'          => $_CORELANG['TXT_TARGET_SELF'],			    	
		));	    
	    
		$pageId = intval($_REQUEST['pageId']);
		if (!empty($pageId))
		{
			$db->query("SELECT * 
			              FROM ".DBPREFIX."content 
			             WHERE id =".$pageId." LIMIT 1");
			
			if($db->next_record()){
				$contenthtml = stripslashes($db->f('content'));
				$contenthtml = preg_replace('/\{([A-Z0-9_]*?)\}/', '[[\\1]]' ,$contenthtml);
												
				if ($db->f('expertmode') == "y" ){
					$expertmodeValue = "checked";
					$contenthtml = htmlspecialchars($contenthtml);
                    $ed = get_wysiwyg_editor('html',$contenthtml, 'html');					
				} else {
					$expertmodeValue = "";
					$ed = get_wysiwyg_editor('html',$contenthtml,'active');					

				}
				$robots="";
				if ($db->f('metarobots')=="index"){ 
					$robots = "checked";
				}														
					
				$this->_objTpl->setVariable(array(
					'CONTENT_FORM_ACTION'      => "update",
					'CONTENT_TOP_TITLE'	       => $_CORELANG['TXT_EDIT_PAGE'],
					'CONTENT_CATID'            => $pageId,
					'CONTENT_HTML'	           => $ed,
					'CONTENT_DESC'	           => htmlspecialchars(stripslashes($db->f('metadesc'))),
					'CONTENT_TITLE'	           => htmlspecialchars(stripslashes($db->f('title'))),
					'CONTENT_KEY'	           => htmlspecialchars(stripslashes($db->f('metakeys'))),
					'CONTENT_ROBOTS'	       => $robots,
					'CONTENT_SHOW_EXPERTMODE'  => $expertmodeValue,									
				));
				unset($ed);
				$redirect = $db->f('redirect');			
			}
			$db->query("SELECT module, 
			                   lang, 
			                   startdate, 
			                   enddate, 
			                   displaystatus, 
			                   catname, 
			                   catid, 
			                   target,
			                   cmd, 
			                   protected,
			                   themes_id 
			              FROM ".DBPREFIX."content_navigation 
			             WHERE catid = $pageId LIMIT 1");
			
			if($db->next_record()){				
				$displaystatus = "";
				$moduleId=$db->f('module');
				$startDate=$db->f('startdate');
				$endDate=$db->f('enddate');
				$cmd = $db->f('cmd');
				$catname = htmlspecialchars(stripslashes($db->f('catname')));
				$themesId=$db->f('themes_id');
				
				if ($db->f('displaystatus') == "on" ){ 
					$displaystatus = "checked";
				}
				$target = $db->f('target');
				//$target = "xyz";								
					
				$this->_objTpl->setVariable(array(
					'CONTENT_MENU_NAME'       => $catname,
					'CONTENT_CAT_MENU'	      => $this->getPageMenu($db->f('catid')),
					'CONTENT_TARGET'          => $target,				
					'CONTENT_SHOW_CMD'        => $cmd,
					'CONTENT_MODULE_MENU'     => $this->_getModuleMenu($moduleId),
					'CONTENT_DISPLAYSTATUS'   => $displaystatus,	
					'CONTENT_STARTDATE'	      => $startDate,
					'CONTENT_CATID'           => $pageId,
					'CONTENT_ENDDATE'	      => $endDate,					
					'CONTENT_THEMES_MENU'     => $this->_getThemesMenu($themesId)
				));						
			}
			
			
			
			// Frontend Groups
			////////////////////////////
			$arrAssignedFrontendGroups=$this->_getAssignedGroups($groupType="frontend",$pageId);
	    	foreach($this->arrAllFrontendGroups AS $id => $name)
	    	{
	    		if(in_array($id, $arrAssignedFrontendGroups)) {
	    		    $assignedGroups.="<option value=\"".$id."\">".$name."</option>\n";
	    		} 
	    		else {
	    		    $existingGroups.="<option value=\"".$id."\">".$name."</option>\n";	
	    		}
	    	}
	    	
	    	$activeProtectionStatus = $this->_getPageProtectionStatus($pageId);
	    	if($activeProtectionStatus=="checked"){
	    		$inactiveProtectionStatus = "";
	    		$displayStatus = "block";
	    	}
	    	else {
	    	    $inactiveProtectionStatus = "checked";
	    	    $displayStatus = "none";
	    	}

			// Backend Groups
			////////////////////////////
			$arrAssignedBackendGroups=$this->_getAssignedGroups($groupType="backend",$pageId);
			$_backendPermissions = false;
	    	foreach($this->arrAllBackendGroups AS $id => $name)
	    	{
	    		if(in_array($id, $arrAssignedBackendGroups)) {
	    		    $assignedBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";
	    		    $_backendPermissions = true;
	    		} 
	    		else 
	    		{
	    		    $existingBackendGroups.="<option value=\"".$id."\">".$name."</option>\n";	
	    		}
	    	}
	    	
	    	if($_backendPermissions){
	    		$activeBackendStatus = "checked";
	    		$inactiveBackendStatus = "";
	    		$displayBackendStatus = "block";
	    	}
	    	else {
	    	    $inactiveBackendStatus = "checked";
	    	    $activeBackendStatus = "";
	    	    $displayBackendStatus = "none";
	    	}	    	   		
	    	
			$this->_objTpl->setVariable(array(
			    //// frontend
			    'CONTENT_EXISTING_GROUPS'     => $existingGroups,
			    'CONTENT_ASSIGNED_GROUPS'     => $assignedGroups,	 
				'CONTENT_PROTECTION_ACTIVE'   => $activeProtectionStatus,
				'CONTENT_PROTECTION_INACTIVE' => $inactiveProtectionStatus,	
				'CONTENT_PROTECTION_DISPLAY'  => $displayStatus,					
				//// backend
			    'CONTENT_EXISTING_BACKEND_GROUPS'  => $existingBackendGroups,
			    'CONTENT_ASSIGNED_BACKEND_GROUPS'  => $assignedBackendGroups,	 
				'CONTENT_CONTROL_BACKEND_ACTIVE'   => $activeBackendStatus,
				'CONTENT_CONTROL_BACKEND_INACTIVE' => $inactiveBackendStatus,	
				'CONTENT_CONTROL_BACKEND_DISPLAY'  => $displayBackendStatus,												
			));			
		}
		
		$this->_objTpl->setVariable(array(
			'TXT_NO_REDIRECT'        => $redirect,
			'CONTENT_CATID'          => $pageId,
		));
	}

	
	
	
	
	/**
    * Update page content
    *                                                                    
    */
	function updatePage()
	{
		global $db, $_CORELANG;

		$expertmode = "n";
		if ($_POST['expertmode']== "y") { 
			$expertmode = $_POST['expertmode']; 
		}
		$displaystatus = "off";
		if ($_POST['displaystatus']== "on") { 
			$displaystatus = "on"; 
		}
		$robotstatus = "noindex";
		if ($_POST['robots']== "index") { 
			$robotstatus = "index"; 
		}		
		$pageId 			= intval($_POST['pageid']);
		$catname			= addslashes($_POST['newpage']);
		$contenthtml		= addslashes($_POST['html']);
		$contenthtml        = preg_replace('/\[\[([A-Z0-9_]*?)\]\]/', '{\\1}' ,$contenthtml);	
		$contenttitle 		= addslashes($_POST['title']);
		$contentdesc 		= addslashes($_POST['desc']);
		$contentkey 		= addslashes($_POST['key']);
		$command	  	    = $_POST['command'];
		$parcat				= $_POST['category'];
		$moduleId           = intval($_POST['selectmodule']);
		$themesId			= intval($_POST['themesId']);
		$startdate          = $_POST['startdate'];
		$enddate            = $_POST['enddate'];		
		$currentTime        = time();				
		$redirect 			= $this->checkRedirectUrl($_POST['redirect']);	
		$redirectTarget	    = $_POST['redirectTarget'];	
		$contenthtml=$this->_getBodyContent($contenthtml);
		$date=substr($_POST['startdate'],0,4)."-".substr($_POST['startdate'],5,2);
		
		if(!$this->_homeModuleCheck($moduleId, $_POST['command'], $_POST['pageid'])){
            $homeMessage=$this->statusMessage;
            $moduleId=intval($this->setModule);
            $command=$this->setCmd;
		}
		
		// Check if Expertmode is set for modules
		/*
		if(!in_array($moduleId, $this->arrNoExpertmodes))
		{
			$expertmode="y";
		}
		*/
		
		$db->query("UPDATE ".DBPREFIX."content 
		               SET id='$pageId', 
		                   content='$contenthtml', 
		                   title='$contenttitle', 
		                   metadesc='$contentdesc', 
		                   metakeys='$contentkey',
		                   metarobots='$robotstatus', 
		                   redirect='$redirect',		                   
		                   expertmode='$expertmode'	                     
		             WHERE id=$pageId");
		
		if ($parcat!=$pageId){
			$db->query( "UPDATE ".DBPREFIX."content_navigation 
			                SET parcat='$parcat', 
			                    catname='$catname', 
			                    target='$redirectTarget', 
			                    displaystatus='$displaystatus', 
			                    username='{$_SESSION['auth']['username']}', 
			                    changelog='$currentTime', 
			                    cmd='$command',
			                    lang='$this->langId', 
			                    module='$moduleId', 
			                    startdate='$startdate',
			                    enddate='$enddate',
			                    themes_id='$themesId'			           			                   
			              WHERE catid=$pageId");
		} else {
		   $db->query("UPDATE ".DBPREFIX."content_navigation 
		                  SET catname='$catname',
		                      target='$redirectTarget', 
							  displaystatus='$displaystatus', 
							  username='{$_SESSION['auth']['username']}', 
							  changelog='$currentTime', 
							  cmd='$command',
							  lang='$this->langId', 
							  module='$moduleId', 
							  startdate='$startdate',
							  enddate='$enddate',
		   			          themes_id='$themesId' 		                     		                     
		                WHERE catid=$pageId");
		}							

		if (isset($_POST['themesRecursive']) AND !empty($_POST['themesRecursive']))	{														
			$objNavbar= &new ContentSitemap(0);
			$catidarray=$objNavbar->getCurrentSonArray($pageId);			
		
			foreach ($catidarray as $value) {				
				$db->query("UPDATE ".DBPREFIX."content_navigation SET themes_id='$themesId' WHERE catid=$value");				   					
			}	
		}
		$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL']; 
		$this->_updateFrontendPermissions($pageId);
		$this->_updateBackendPermissions($pageId);
		$this->statusMessage .= $homeMessage;
	}


	
	
	
    /**
    * Add a new page
    *
    * @global    object     $db                                                                   
    */
	function addPage()
	{
		global $db, $_CORELANG;

		$parcat = !empty($_POST['category']) ? $_POST['category'] : 0;		
		$displaystatus = ( $_POST['displaystatus'] == "on" ) ? "on" : "off";		
		$expertmode = ( $_POST['expertmode'] == "y" ) ? "y" : "n";		
		$robotstatus = ( $_POST['robots'] == "index" ) ? "index" : "noindex";
				
		$catname = 	addslashes($_POST['newpage']);
		$section = 	$_POST['section'];
		$command = 	$_POST['command'];
		$contenthtml= addslashes($_POST['html']);
		$contenthtml = preg_replace('/\[\[([A-Z0-9_]*?)\]\]/', '{\\1}' ,$contenthtml);
		$contenttitle = addslashes($_POST['title']);
		$contentdesc = addslashes($_POST['desc']);
		$contentkey = addslashes($_POST['key']);
		$modul = intval($_POST['selectmodule']);
		$startdate = $_POST['startdate'];
		$enddate  =	$_POST['enddate'];
		$themesId = intval($_POST['themesId']);         
		$currentTime = time();
		

		if(!$this->_homeModuleCheck($modul,$_POST['command'],'')==true){
            $homemessage=$this->statusMessage;;
            $modul=intval($this->setModule);
            $command=$this->setCmd;
		}

		// Check if Expertmode is set for modules
		// module 15 is the home module (buggy test)
		if($modul!=0 AND $modul!=15){
			$expertmode="y";
		}	
			
		$protected=0;	
		$db->query("SELECT protected FROM ".DBPREFIX."content_navigation WHERE catid=$parcat");
		if($db->next_record()){
			if ($db->f("protected")) $protected=1;			
		}					
				
		$contentredirect= $this->checkRedirectUrl($_POST['redirect']);	
		$contenthtml=$this->_getBodyContent($contenthtml);
  		$q1 = "INSERT INTO ".DBPREFIX."content_navigation (catid, 
											  		parcat, 
											  		catname,
  		                                            target,
											  		displayorder, 
											  		displaystatus, 
											  		username, 
											  		changelog, 
											  		cmd, 
											  		lang,
											  		module,
											  		startdate,
											  		enddate,
  													frontend_groups,
  													protected,
  		                                            themes_id)
									         VALUES('',
											  		$parcat, 
											  		'$catname',
  		                                            '', 
											  		'{$_POST['redirectTarget']}', 
											  		'$displaystatus', 
											  		'{$_SESSION['auth']['username']}', 
											  		'$currentTime', 
											  		'$command',
											  		'$this->langId',
											  		'$modul', 
											  		'$startdate',
											  		'$enddate',
  													'',
  		                                            '$protected',
  		                                            '$themesId')";
  		
  		
		$db->query($q1);
		$pageId = $db->insert_id();
		
		$q2 ="INSERT INTO ".DBPREFIX."content (id,
												content,
												title,
												metadesc,
												metakeys,
		                                        metarobots,
												redirect,
												expertmode)
										VALUES ($pageId,
												'$contenthtml', 
												'$contenttitle', 
												'$contentdesc', 
												'$contentkey', 
		                                        '$robotstatus',
												'$contentredirect', 
												'$expertmode')";
		
		if($db->query($q2)){
			$this->statusMessage = $_CORELANG['TXT_DATA_RECORD_ADDED_SUCCESSFUL']; 
			$this->_updateFrontendPermissions($pageId);
			$this->_updateBackendPermissions($pageId);
			$this->statusMessage .= $homemessage;
		}
		else {
			$this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];
		}
	}
	

	
	
	/**
    * Delete page content
    *
    * @version   1.0        initial version 
    * @global    object     $db
    * @global    array      $_CORELANG[*]                                                                       
    */
	function deleteContent()
	{
		global $db, $_CORELANG;
		
		if (isset($_GET['pageId']) && !empty($_GET['pageId'])){
			$pageId = intval($_GET['pageId']);
			
			$db->query("SELECT parcat, 
			                   catid, 
			                   module 
			              FROM ".DBPREFIX."content_navigation 
			             WHERE parcat=$pageId 
			                OR catid=$pageId
			          ORDER BY catid");
						
			if($db->next_record()){
                $moduleId = $db->f('module');
				if($db->num_rows()>1){	
					$this->statusMessage=$_CORELANG['TXT_PAGE_NOT_DELETED_DELETE_SUBCATEGORIES_FIRST']; 
				}
				else{
					if(in_array($moduleId, $this->_requiredModules)){
					    $this->statusMessage=$_CORELANG['TXT_NOT_DELETE_REQUIRED_MODULES'];	
					} else {								
						$q1 = "DELETE FROM ".DBPREFIX."content WHERE id=$pageId";
						$q2 = "DELETE FROM ".DBPREFIX."content_navigation WHERE catid=$pageId";
						if (!$db->query($q1) || !$db->query($q2)){
							$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR']; 
						} else {	
						     $this->statusMessage=$_CORELANG['TXT_DATA_RECORD_DELETED_SUCCESSFUL'];
						}
					}
				}                
			}
		}
	}

	
	
	/**
    * Add page to repository
    *
    * @global    object     $db
    * @global    array      $_CORELANG                                                                      
    */
	function addToRepository()
	{	
		global $db, $_CORELANG;
	    $pageId = $_GET['pageid'];
		if ($pageId != "" ){		
		    $objNavbar= &new ContentSitemap(0);		    
			$catidarray=$objNavbar->getCurrentSonArray($pageId);	
			array_unshift ($catidarray,$pageId);		
			foreach ($catidarray as $value) {			
				$db->query("SELECT * 
				              FROM ".DBPREFIX."content_navigation, 
				                   ".DBPREFIX."content 
				             WHERE id=catid 
				               AND catid=$value");
				
				if ($db->next_record())
				{
					$repository['displayorder']=$db->f('displayorder');
					$repository['displaystatus']=$db->f('displaystatus');
					$repository['cmd']=$db->f('cmd');
					$repository['lang']=$db->f('lang');													
					$repository['content']=$db->f('content');													
					$repository['title']=$db->f('title');													
					$repository['expertmode']=$db->f('expertmode');													
					$repository['moduleid']=$db->f('module');													
					$repository['lang']=$db->f('lang');	
					$repository['username']=$db->f('username');	
					
					if ($paridarray[$db->f('parcat')]){							
					    $repository['parid']= $paridarray[$db->f('parcat')];
					} else {
						if (!$justonce) $db->query("DELETE FROM ".DBPREFIX."module_repository WHERE moduleid='".$repository['moduleid']."'");						
						$justonce=true;
				        $repository['parid']= 0;				
					}
				}
						
				$db->query("INSERT INTO ".DBPREFIX."module_repository SET
									displayorder ='".$repository['displayorder']."',
									displaystatus ='".$repository['displaystatus']."',
				                    username ='".addslashes($repository['username'])."',
									cmd ='".$repository['cmd']."',
									content ='".addslashes($repository['content'])."',
									title ='".addslashes($repository['title'])."',
									expertmode ='".$repository['expertmode']."',
									moduleid ='".$repository['moduleid']."',
									lang ='".$repository['lang']."',	
									parid ='".$repository['parid']."'");											

				if(!$db->next_record()){
					$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR']; 
				}
					
				$paridarray[$value]=$db->insert_id();																					
			}						
			$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];			
		}
	} 


	
	/**
    * string checkRedirectUrl($redirect)
    *
    * @version   1.0        initial version 
    * @param     string     redirect string
    * @return    string     checked redirect string                                                                              
    */
    function checkRedirectUrl($redirect)
    {
		if (!empty($redirect) AND strlen($redirect)>10){
			if (!eregi("^(http://|https://|ftp://)", $redirect)){
				$redirect = "http://" . $redirect;
			}
		}else{
			$redirect = "";
		}
		return $redirect; 
    }   

    
	
	/**
    * Gets the search option menus string
    * 
    * @global    object     $db
    * @param     string     optional $selectedOption
    * @return    string     $modulesMenu                                                                              
    */
    function _getModuleMenu($selectedOption="")
    {
	    global $db;
	    $strMenu = "";	

	    $q = "SELECT * FROM ".DBPREFIX."modules WHERE 1 AND id<>0 ORDER BY id";
		$db->query($q);
		while($db->next_record()){
			$selected = ($selectedOption==$db->f('id')) ? "selected" : "";
			$strMenu .="<option value=\"".$db->f('id')."\" $selected>".$db->f('name')."</option>\n"; 
		}
	    return $strMenu;
    }

    

    
    
    /**
    * Gets the body-content
    *
    * this function removes all the content outside the body tags
    *
    * @param     string     $fullContent      HTML-Content with more than BODY
    * @return    string     $content          HTML-Content between BODY-Tag                                                                
    */
    function _getBodyContent($fullContent)
    {
	    $res=false;
	    $posBody=0;
	    $posStartBodyContent=0;
	    $res=preg_match_all("/<body[^>]*>/i", $fullContent, $arrayMatches);
	    if($res==true) {
            $bodyStartTag = $arrayMatches[0][0];
            // Position des Start-Tags holen
            $posBody = strpos($fullContent, $bodyStartTag, 0);
            // Beginn des Contents ohne Body-Tag berechnen 
            $posStartBodyContent = $posBody + strlen($bodyStartTag);
	    }
	    $posEndTag=strlen($fullContent);
	    $res=preg_match_all("/<\/body>/i",$fullContent, $arrayMatches);
	    if($res==true) {
            $bodyEndTag=$arrayMatches[0][0];
            // Position des End-Tags holen
            $posEndTag = strpos($fullContent, $bodyEndTag, 0);
            // Content innerhalb der Body-Tags auslesen
	     }
	     $content = substr($fullContent, $posStartBodyContent, $posEndTag  - $posStartBodyContent);
         return $content;
    }

    
    
    
    function _homeModuleCheck($section,$cmd,$pageId)
    {
    	global $db, $_CORELANG;
    	$lang=$this->langId;
    	$section=intval($section);
    	if($db->query("SELECT id FROM ".DBPREFIX."modules WHERE name='home'")){
    		if($db->next_record()){
				$homeModuleId=intval($db->f('id'));
			}
    	} else {
    		$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];
    		return false;
    	}
    	
    	if($db->query("SELECT catid FROM ".DBPREFIX."content_navigation WHERE  lang=$lang AND module=$homeModuleId")){				
			if($db->next_record()){
			     if($db->query("SELECT m.name 
			                      FROM ".DBPREFIX."content_navigation AS n, 
			                           ".DBPREFIX."modules AS m 
			                     WHERE n.lang=$lang 
			                       AND n.module=$section 
			                       AND n.cmd='$cmd' 
			                       AND n.module>0 
			                       AND n.catid<>'$pageId'"))
			     {
				     if($db->next_record()) {
				     	  $sectionName=$db->f('m.name');
					      $this->statusMessage=$_CORELANG['TXT_PAGE_WITH_SAME_MODULE_EXIST']." ".$sectionName." ".$cmd;
					      $this->setModule=$section;
					      $this->setCmd=$cmd+1;
					      return false;
				     }
				     else {
				          return true;	
				     }
			     }	
		    }
		    elseif($section==$homeModuleId)
		    {
                return true;
		    }
		    else 
		    {
		        $this->statusMessage=$_CORELANG['TXT_CREATE_HOME_MODULE'];
			    $this->setModule=$homeModuleId;
			    return false;
		    }
		}	
	    $this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];
        return  false;
    }

    
    

	/*
	* Get dropdown menue
	*
	* Gets back a dropdown menu like  <option value='catid'>Catname</option>

    *
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function getPageMenu($selectedid=0)
	{
		 $result=$this->_getNavigationMenu($parcat=0, 0,$selectedid);
		 return $result;
	}

	
	
	
	/*
	* Do navigation dropdown
	*
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $selectedid
    * @return   string   $result
    */
	function _getNavigationMenu($parcat=0,$level,$selectedid)
	{				
		global $db;
		
		$lang=$this->langId;
		$result="";
		
		if(!$db->query("SELECT catid, parcat, catname
		                  FROM ".DBPREFIX."content_navigation 
		                 WHERE lang=$lang
		              ORDER BY parcat ASC, displayorder ASC"))		
		{ 
		    return "content::navigation() database error";
		}
		while($db->next_record())
		{			
		    $navtable[$db->f('parcat')][$db->f('catid')]=stripslashes($db->f('catname'));
		}	  					
		
		$list=$navtable[$parcat];
		 if(is_array($list))
		 {
				while(list($key,$val)=each($list))
				{
					  $output ="";
					  $selected ="";
					  if ($level!="0")
					  {
							$count= $level*3;
							for ($i = 1; $i <= $count; $i++) 
							{
								$output .=".";
							}
					  }
					  if ($selectedid==$key)
					  		$selected= "selected";
					  $result.= "<option value='$key' $selected>$output$val</option>\n";
		              if (isset($navtable[$key]))
					  {
							$result.= $this->_getNavigationMenu($key,$level+1,$selectedid);
					  }
				}
		 }
		 RETURN $result;
	}    
	

	
	/**
    * Change page protection
    *
    * @global    object     $db
    * @global    array      $_CORELANG[*]                                                                       
    */
	function changeProtection()
	{
		global $db, $_CORELANG;
		
		$this->pagetitle = $_CORELANG['TXT_CONTENT_MANAGER'];
		$loginModuleId = 18;
		
		if (!empty($_REQUEST['Id'])){							
			$pageId = intval($_REQUEST['Id']);
			$db->query("SELECT protected FROM ".DBPREFIX."content_navigation WHERE catid=$pageId");
			if($db->next_record()){			
				$newprotected = ($db->f("protected")) ? 0:1;				
				$objNavbar= &new ContentSitemap(0);
				$moduleId = intval($db->f("protected"));
				$catidarray=$objNavbar->getCurrentSonArray($pageId);
				$db->query("UPDATE ".DBPREFIX."content_navigation SET protected = $newprotected WHERE catid=$pageId");
				foreach ($catidarray as $value) {
					$db->query("UPDATE ".DBPREFIX."content_navigation SET protected = $newprotected WHERE catid=$value");				   				   
				}
				// Login Module must be unprotected!
				$db->query("UPDATE ".DBPREFIX."content_navigation SET protected=0 WHERE module=$loginModuleId");
				
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			} else {					
				$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];   	
			}
		}
	}
	

	
	/**
    * Change page status
    *
    * @global    array      $_CORELANG                                                                       
    */
	function changeStatus()
	{
		global $db, $_CORELANG;

		if (isset($_REQUEST['pageId']) && !empty($_REQUEST['pageId']))
		{							
			$currentTime = time();
			$pageId = intval($_REQUEST['pageId']);
			
			$db->query("SELECT displaystatus FROM ".DBPREFIX."content_navigation WHERE catid=".$pageId);
			if($db->next_record())
			{
				if ($db->f("displaystatus")=='on') $newstatus='off';
				else $newstatus='on';
				
				$objNavbar= &new ContentSitemap(0);
				$catidarray=$objNavbar->getCurrentSonArray($pageId);

				$db->query("UPDATE ".DBPREFIX."content_navigation 
				               SET displaystatus = '$newstatus',
				                   username='{$_SESSION['auth']['username']}',
				                   changelog='$currentTime'			 
				             WHERE catid=".$pageId);	
				
				foreach ($catidarray as $value) 
				{				
					$db->query("UPDATE ".DBPREFIX."content_navigation SET displaystatus = '$newstatus' WHERE catid=".$pageId);				   						   
				}
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			}
		    else 
			{					
				$this->statusMessage=$_CORELANG['TXT_DATABASE_QUERY_ERROR'];   	
			}
		}
	}
		
	
	/**
    * Edit page protection
    *
    * @global    object     $db
    * @global    array      $_CORELANG                                                                       
    */
	function editPermission()
	{
	    global $db, $_CORELANG;
	    
	    $this->_objTpl->loadTemplateFile('content_permission_edit.html',true,true);	    
	    $this->pageTitle = $_CORELANG['TXT_NEW_PAGE'];	 	    
	    	
	    $arrGroup=array();
	    $arrCurrentGroups=array();

		//begin language vars
		$this->_objTpl->setVariable(array(
		    'TXT_PROTECTION_CHANGE' => $_CORELANG['TXT_PROTECTION_CHANGE'],
		    'TXT_PAGE_NAME'	        => $_CORELANG['TXT_PAGE_NAME'],
		    'TXT_PROTECTION'        => $_CORELANG['TXT_PROTECTION'],
		    'TXT_RECURSIVE_CHANGE'  => $_CORELANG['TXT_RECURSIVE_CHANGE'],
		    'TXT_GROUPS'            => $_CORELANG['TXT_GROUPS'],
		    'TXT_GROUPS_DEST'       => $_CORELANG['TXT_GROUPS_DEST'],
		    'TXT_SELECT_ALL'        => $_CORELANG['TXT_SELECT_ALL'],
		    'TXT_DESELECT_ALL'      => $_CORELANG['TXT_DESELECT_ALL'],
		    'TXT_ACCEPT_CHANGES'    => $_CORELANG['TXT_ACCEPT_CHANGES'],		
		));
													
		$id = intval($_GET['pageid']);				
		$db->query("SELECT catid, catname, frontend_groups, protected FROM ".DBPREFIX."content_navigation WHERE catid = $id LIMIT 1");						
		
		if($db->next_record()){
			$pageId= $db->f("catid");	
			$pagename= $db->f("catname");	
			if ($db->f('protected')){ 
				$protected = "checked";
			}						
			$arrCurrentGroups=explode(",", $db->f("frontend_groups"));
		}
		
		$db->query("SELECT group_id, group_name FROM ".DBPREFIX."user_groups WHERE type='frontend'");
    	while ($db->next_record()){
    		$arrGroup[$db->f('group_id')]=$db->f('group_name');
    	}

    	foreach($arrGroup AS $id => $name){
    		if(in_array($id, $arrCurrentGroups)){
    		    $destgroups.="<option value=\"".$id."\">".$name."</option>\n";	
    		} else{
    		    $fromgroups.="<option value=\"".$id."\">".$name."</option>\n";	
    		}
    	}
	    
		$this->_objTpl->setVariable(array(
		    'CONTENT_NAME'          => $pagename,
			'CONTENT_PROTECTION'    => $protected,
			'PAGE_ID'               => $pageId,
			'GROUPS_EDIT_FROMPAGE'  => $fromgroups,
			'GROUPS_EDIT_DESTPAGE'  => $destgroups,
		));				
	}
		

	
	
	
	/**
    * Update page protection
    *
    * @global    object     $db
    * @global    array      $_CORELANG                                                                       
    */ 
	function _updateFrontendPermissions($pageId)
	{
		global $_CORELANG;		
		$objDB = &new astalavistaDB;
		$loginModuleId = 18;
			    	
		if (!empty($_POST['assignedGroups'])){
			$groups= implode(",",$_POST['assignedGroups']);
		}
		else {
		    $groups='';
		}
		
		$recursive= $_POST['recursive'];		
		$protected= $_POST['protection'];							

		if (empty($protected)) {
			$protected=0;
		}
		if ($recursive){														
			$objNavbar= &new ContentSitemap(0);
			$catidarray=$objNavbar->getCurrentSonArray($pageId);			
		
		    $objDB->query("UPDATE ".DBPREFIX."content_navigation SET frontend_groups='$groups', protected=$protected WHERE catid=$pageId");
			foreach ($catidarray as $value) {				
				$objDB->query("UPDATE ".DBPREFIX."content_navigation SET frontend_groups='$groups', protected=$protected WHERE catid=$value");				   					
			}
			$objDB->query("UPDATE ".DBPREFIX."content_navigation SET protected=0 WHERE module=$loginModuleId");
			$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];		
		}
		else {
			$objDB->query("UPDATE ".DBPREFIX."content_navigation SET frontend_groups='$groups', protected=$protected WHERE catid=$pageId");
			$objDB->query("UPDATE ".DBPREFIX."content_navigation SET protected=0 WHERE module=$loginModuleId");
			$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
		}
	}

	
	
	
	/**
    * Updates the backend control group for the current pageId
    *
    * @global  array _ARRAYLANG                                                                     
    */ 
	function _updateBackendPermissions($pageId)
	{
		global $_CORELANG;				
		if(intval($_POST['backendPermission'])==1)
		{	
			$objDB = &new astalavistaDB;				    	
			if (!empty($_POST['assignedBackendGroups']))
			{
				$groups= implode(",",$_POST['assignedBackendGroups']);
			}
			else 
			{
			    $groups='';
			}			
			if (isset($_POST['backendInherit']) && !empty($_POST['backendInherit']))
			{														
				$objNavbar= &new ContentSitemap(0);
				$catidarray=$objNavbar->getCurrentSonArray($pageId);			
			
			    $objDB->query("UPDATE ".DBPREFIX."content_navigation SET backend_groups='$groups' WHERE catid=$pageId");
				foreach ($catidarray as $value) 
				{				
					$objDB->query("UPDATE ".DBPREFIX."content_navigation SET backend_groups='$groups' WHERE catid=$value");				   					
				}
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];		
			}
			else 
			{
				$objDB->query("UPDATE ".DBPREFIX."content_navigation SET backend_groups='$groups' WHERE catid=$pageId");
				$this->statusMessage=$_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			}
		}
	}	
	
	
	
	
	
	
	/*
	* Do navigation dropdown
	*
    * @param    integer  $parcat
    * @param    integer  $level
    * @param    integer  $selectedid
    * @return   string   $result
    */		

	function _getThemesMenu($id=NULL)
	{
		/*######### old ############
		global $db, $_CORELANG; 
		
		$themesId = intval($id);
                		
		$return = "<option value='0' selected>".$_CORELANG['TXT_STANDARD']."</option>\n";		
		$db->query("SELECT id,themesname FROM ".DBPREFIX."themes ORDER BY id");			
		while($db->next_record())
		{				
			$selected= ($db->f('id')==$themesId) ? " selected" : "";						
			$return .="<option value='".$db->f('id')."'$selected>".$db->f('themesname')."</option>\n";
		}
		return $return;
		######### old ############*/
		
		global $db, $_CORELANG; 
		
		$themesId = intval($id);
                		
		$return = "<option value='0' selected>(".$_CORELANG['TXT_STANDARD'].")</option>\n";		
		$db->query("SELECT id,themesname FROM ".DBPREFIX."skins ORDER BY id");			
		while($db->next_record()){				
			$selected= ($db->f('id')==$themesId) ? " selected" : "";						
			$return .="<option value='".$db->f('id')."'$selected>".$db->f('themesname')."</option>\n";
		}
		return $return;
	}	
}
?>