<?php
/**
* Class Initialize
*
* init CMS
*
* @copyright     ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering GmbH          
* @module    	 coreInit
* @modulegroups  core                    
* @author        Ivan Schmid <ivan.schmid@astalavista.ch>             
* @version       $Id:  Exp $                                            
*/
class InitCMS
{
	var $defaultBackendLangId;
	var $backendLangCharset;	
	var $backendLangId;
		
	var $defaultFrontendLangId; 
	var $frontendLangCharset;
	var $frontendLangId;	
	var $userFrontendLangId;
			
	var $currentThemesId;	
	var $is_home;
	var $arrLang =array();
	var $templates = array();
	var $objDB;
	var $arrModulePath = array();
	
	
    /**
    * string $mode
    * frontend or backend
    */		
	var $mode; 

  
    /**
    * Constructor
    *
    */	    
	function InitCMS($mode="frontend")
	{
		$this->is_home=false;
		$this->mode=$mode;

		$this->objDb = &new astalavistaDB;
		
		$this->objDb->query("SELECT id,
									themesid,
									lang,
		                            name,
									charset,
		                            backend,
		                            frontend,
									is_default 
		                       FROM ".DBPREFIX."languages");		

		while($this->objDb->next_record()) {
			$this->arrLang[$this->objDb->f('id')]= array(
			    'id'         => $this->objDb->f('id'),
			    'themesid'   => $this->objDb->f('themesid'),
			    'lang'       => $this->objDb->f('lang'),
			    'name'       => $this->objDb->f('name'),
			    'charset'    => $this->objDb->f('charset'),
			    'backend'    => $this->objDb->f('backend'),
			    'frontend'   => $this->objDb->f('frontend'),
			    'is_default' => $this->objDb->f('is_default'));
			    
			if($this->objDb->f('is_default')=="true") {
				$this->defaultBackendLangId = $this->objDb->f('id');
				$this->defaultFrontendLangId = $this->objDb->f('id');
			}			    			    
		}
		if ($mode == "frontend") {
			$this->_initBackendLanguage();
			$this->getUserFrontendLangId();
		}
		$this->_initFrontendLanguage();
		$this->loadModulePaths();
	}

	

	
	function _initBackendLanguage()
	{
		global $_SESSION;
		
		// Backend language initialization
		$userId=0;
		
		if(isset($_SESSION['auth']['userid'])){
		     $userId=intval($_SESSION['auth']['userid']);
		}
						
		if(isset($_SESSION['auth']['lang']) && !empty($_SESSION['auth']['lang'])) {
            $backendLangId=intval($_SESSION['auth']['lang']); 
		} elseif(isset($_COOKIE['backendLangId']) && !empty($_COOKIE['backendLangId'])) {
		    $backendLangId=intval($_COOKIE['backendLangId']);			
		} else {
            $backendLangId=$this->defaultBackendLangId;             
		}	
		
		if($this->arrLang[$backendLangId]['backend']!=1) {
			$backendLangId=$this->defaultBackendLangId;
		}
		
		$this->backendLangId= $this->arrLang[$backendLangId]['id'];
		/*
		print_r($backendLangId);
		print_r($this->arrLang[$backendLangId]['id']);
		*/
		$this->currentThemesId= $this->arrLang[$backendLangId]['themesid'];
		$this->backendLangCharset = $this->arrLang[$backendLangId]['charset'];
		setcookie ("backendLangId", $backendLangId, time()+3600*24*30);							
	}	


	
	function _initFrontendLanguage()
	{		
		// Frontend language initialization	
		if(isset($_GET['langId']) AND !empty($_GET['langId'])){
		    $frontendLangId=intval($_GET['langId']);
	    } elseif(isset($_COOKIE['langId']) AND !empty($_COOKIE['langId'])){
		    $frontendLangId = intval($_COOKIE['langId']);			
	    } else {
	        $frontendLangId = $this->defaultFrontendLangId;	
	    }
		if($this->arrLang[$frontendLangId]['frontend']!=1){
			$frontendLangId = $this->defaultFrontendLangId;
		}
			    
		$this->frontendLangId= $frontendLangId;
		$this->currentThemesId= $this->arrLang[$frontendLangId]['themesid'];
		$this->frontendLangCharset = $this->arrLang[$frontendLangId]['charset'];
		setcookie ("langId", $frontendLangId, time()+3600*24*30);						
	}	

	
	

	
	/**
	* Gets the selected User Frontend Language id
	*
	* This method is only for the backend use!
	*            
	* @return   string $this->userFrontendLangId                                           
	*/	
    function getUserFrontendLangId()
	{	    			
		// print_r($_COOKIE);
		if(isset($_POST['userFrontendLangId']) AND !empty($_POST['userFrontendLangId']))
	    {
		    $id=intval($_POST['userFrontendLangId']);
	    }
	    elseif(isset($_SESSION['userFrontendLangId']) AND !empty($_SESSION['userFrontendLangId']))
	    {
		    $id = intval($_SESSION['userFrontendLangId']);			
	    }
	    else 
	    {
	        $id = $this->defaultFrontendLangId;	
	    }
		if($this->arrLang[$id]['frontend']!=1)
		{
			$id=$this->defaultFrontendLangId;
		}
			    
		$this->userFrontendLangId= $id;
	    $_SESSION['userFrontendLangId'] = $id;
	    
		return $this->userFrontendLangId; 	  	  	 		
	}	

	
    function getDefaultFrontendLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}
	
	

    function getDefaultBackendLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}
		
	
	
    function getFrontendLangId()
	{
		  return $this->frontendLangId;  	  	 		
	}

	
    function getBackendLangId()
	{
		  return $this->backendLangId; 	  	  	 		
	}	

	
	
	
    /**
    * gets all languages as an array
    *
    * @access public
    * @return array $arrLang
    */
     
    function getLanguageArray()
	{
		return $this->arrLang; 	  	 		
	}	
	
	

	
    /**
    * gets the current language charset for the html header
    *
    * @param string   charset
    * @access public
    */
     
    function getFrontendLangCharset()
	{
		if (empty($this->frontendLangCharset))
		{
            return "iso-8859-1";
		}
		else
		{
		    return $this->frontendLangCharset; 
		}  	  	 		
	}

	
    /**
    * gets the current language charset for the html header
    *
    * @param string   charset
    * @access public
    */
     
    function getBackendLangCharset()
	{
		if (empty($this->backendLangCharset))
		{
            return "iso-8859-1";
		}
		else
		{
		    return $this->backendLangCharset; 
		}  	  	 		
	}	
	
		
	
    /**
    * getDefaultLangId
    *
    * @param string   current language id
    * @access public
    */	 
    function getFrontendDefaultLangId()
	{
		  return $this->defaultFrontendLangId; 	  	  	 		
	}

	
    /**
    * getDefaultLangId
    *
    * @param string   current language id
    * @access public
    */	 
    function getBackendDefaultLangId()
	{
		  return $this->defaultBackendLangId; 	  	  	 		
	}		
	
	
    /**
    * getTemplate Function
    *
    * @param  array    Template strings
    * @access public
    */		
	function getTemplates()
	{	  	  		
		$this->objDb->query("SELECT id,
									themesname,
		                            foldername 
		                       FROM ".DBPREFIX."skins 
		                      WHERE id = '$this->currentThemesId' 
		                      LIMIT 1");
		
		while($this->objDb->next_record()){
			$themesPath = $this->objDb->f('foldername');
		}
								
	  	$this->templates['index'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/index.html'));
		$this->templates['content'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/content.html'));
		$this->templates['home'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/home.html'));
		$this->templates['navbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/navbar.html'));
		$this->templates['subnavbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/subnavbar.html'));
		$this->templates['sidebar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/sidebar.html'));
		$this->templates['shopnavbar'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/shopnavbar.html'));			
		$this->templates['headlines'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/headlines.html'));
		$this->templates['javascript'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/javascript.js'));			
		$this->templates['style'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/style.css'));
		$this->templates['buildin_style'] = stripslashes(file_get_contents(ASCMS_THEMES_PATH.'/'.$themesPath.'/buildin_style.css'));
		
	  	return $this->templates; 	  	  	 		
	}


	
	/**
	*  initialise the configuration array
	*
	* @return    array   $arrSettings                                                                               
	*/
	function loadConfiguration()
	{
	    global $_SYSCONFIG;
	    
	    $arrSettings = $_SYSCONFIG;    
	    
		if ($this->objDb->query("SELECT setname, setvalue FROM ".DBPREFIX."settings")){
	        while($this->objDb->next_record()){
	            $setname=$this->objDb->f('setname');
				$setvalue=$this->objDb->f('setvalue');
				$arrSettings[$setname]=$setvalue;
			}
		}
		else{
	        die("init::loadConfiguration() error");
		}
	    return $arrSettings;
	}	
	

	
	function loadModulePaths()
	{
		// generate "module paths" array
		$query = "SELECT name, is_core FROM ".DBPREFIX."modules";
		if($this->objDb->query($query)){
			while ($this->objDb->next_record()) {
				if(strlen($this->objDb->f('name'))>0){
					switch($this->objDb->f('name')){
						case 'core':
							$this->arrModulePath[$this->objDb->f('name')] = ASCMS_DOCUMENT_ROOT.'/lang/';
							break;
						case 'home':
							// home is not a real modul
							break;
						default:
						$this->arrModulePath[$this->objDb->f('name')] = ($this->objDb->f('is_core') == 1 ? ASCMS_CORE_MODULE_PATH : ASCMS_MODULE_PATH).'/'.$this->objDb->f('name').'/lang/';
					}
				}
			}
		}
	}

	
	
	/**
	*  initialise the setting array
	*
	* @return    array   $arrayLanguageSettings                                                                             
	*/
	function loadLanguageData($module = '')
	{
		global $objInit, $_CORELANG;

		$_ARRAYLANG = array();
		
		if($objInit->mode == "backend"){
			$langId = $this->backendLangId;
		} else {
			$langId = $this->frontendLangId;
		}	
		
    	// check which module will be loaded
    	if(empty($module)){
	    	if($objInit->mode == "backend"){
	    		$module = isset($_REQUEST['cmd']) ? $_REQUEST['cmd'] : 'core';
	    	} else {
	    		$module = isset($_REQUEST['section']) ? $_REQUEST['section'] : 'core';
	    	}
    	}
    	
    	// change module for core components
		if(!array_key_exists($module,$objInit->arrModulePath)){
			$module = '';
		}
    	
    	// check if the language file exist
    	$path = $objInit->arrModulePath[$module].$objInit->arrLang[$langId]['lang'].'/'.$objInit->mode.'.php';
   		if(!file_exists($path)){
    		$langId = $objInit->mode == "backend" ? $objInit->getBackendDefaultLangId() : $objInit->getFrontendDefaultLangId();
			$path = $objInit->arrModulePath[$module].$objInit->arrLang[$langId]['lang'].'/'.$objInit->mode.'.php';
			if(!file_exists($path)){
    			$path = '';
			}
		}
		
		// load variables
		if(empty($module)){
			return $_CORELANG;
		} else {
			if(!empty($path)){
				//require_once($path);
				require($path);
				return $_ARRAYLANG;
			} else {
				//die("init::loadLanguageData() error (".$objInit->arrModulePath[$module].$objInit->arrLang[$_LANGID]['lang'].'/'.$objInit->mode.'.php'.")");
				return $_CORELANG;
			}
		}
	}
//	function loadLanguageData()
//	{
//	    if($this->mode=="backend")
//	    {
//	        $variableTyp= "backend";
//	        $langId = $this->backendLangId;
//	    }
//	    else 
//	    {
//             $variableTyp= "frontend";
//             $langId = $this->frontendLangId;
//	    }
//		  $query= "SELECT name, content 
//		           FROM ".DBPREFIX."language_variable_content AS vc, 
//		                ".DBPREFIX."language_variable_names AS vn 
//		           WHERE lang_id='$langId' 
//		           AND vn.".$variableTyp." = 1
//		           AND vc.varid=vn.id";
//		  
//		if ($this->objDb->query($query))
//		{
//	        while($this->objDb->next_record())
//			{
//	            $name=$this->objDb->f('name');
//				$arrayLangSettings[$name]= $this->objDb->f('content');				
//			}		
//		}
//		else
//		{
//	        die("init::loadLanguageData() error");
//		}
//		
//	    return $arrayLangSettings;
//	}

	
	
	/**
	* Gets the page id
	*
	* gets the current pageId
	*
	* @global	 object	    $db      
	* @param     integer	$catID
	* @param     string		$command
	* @return    integer    $catID                                                                              
	*/
	function getPageID($catID="", $section="", $command="")
	{	    		
		$langId = $this->getFrontendLangId();
		
		if($section=='home'){
			$this->is_home=true;
		}	    
	    	
		if (empty($catID) OR $catID=="0")
		{
			if (empty($section) AND empty($command))
			{
				$query="SELECT n.catid AS catid, 
				               n.module AS module,
				               n.themes_id AS themes_id 
				          FROM ".DBPREFIX."content_navigation AS n, 
				               ".DBPREFIX."modules AS m 
				         WHERE 1 
				           AND m.name = 'home' 
				           AND n.module=m.id 
				           AND lang='$langId' 
				         LIMIT 1";
				if($this->objDb->query($query))
				{
					$this->objDb->next_record();							
					$catID=$this->objDb->f('catid');
					$this->_setCustomizedThemesId($this->objDb->f('themes_id'));
					$this->is_home=true;
				}
				else
				{
					die("init::getPageId() error");
				}
			}
			// section without command is given!
			elseif (!empty($section) AND empty($command))
			{
				$query="SELECT catid,
							   themes_id 
				         FROM ".DBPREFIX."content_navigation, 
				              ".DBPREFIX."modules 
				        WHERE name = '$section' 
				          AND cmd = ''
				          AND module=id 
				          AND lang='$langId'
				        ORDER BY parcat ASC 
				        LIMIT 1";
				
				//$query="SELECT catid FROM ".DBPREFIX."content_navigation WHERE section = '$section' LIMIT 1"
				if($this->objDb->query($query))
				{
				    if($this->objDb->next_record())
				    {
				        $catID = $this->objDb->f('catid');				        
				        $this->_setCustomizedThemesId($this->objDb->f('themes_id'));
				    }
				}
				else
				{
					die("init::getPageId() error");
				}
			}
			else
			{
				$query="SELECT catid,
			                   themes_id 
				          FROM ".DBPREFIX."content_navigation, 
				               ".DBPREFIX."modules 
				        WHERE name = '$section' 
				          AND cmd = '$command'
				          AND lang='$langId' 
				          AND module=id  
				        LIMIT 1";
				
				if($this->objDb->query($query))
				{
				    if($this->objDb->next_record())
				    {
				    	$catID = $this->objDb->f('catid');
				    	$this->_setCustomizedThemesId($this->objDb->f('themes_id'));
				    }
				}
				if(empty($catID))
				{
					die("init::getPageID() error");
				}			
			}
			return $catID;
		}
		else
		{
			$query="SELECT themes_id 
			          FROM ".DBPREFIX."content_navigation 
			         WHERE catid = '$catID' LIMIT 1";
						
			if($this->objDb->query($query))
			{
			    if($this->objDb->next_record())
			    {
			    	$this->_setCustomizedThemesId($this->objDb->f('themes_id'));
			    }
			}			
			return $catID;
		}
	}

	
	
	/**
	* Sets the customized ThemesId
	*
	* This method set the currentThemesId if a customized themesId is set
	* in the navigation table. 
	*     
	* @param optional string $themesId
	* @access public                                                                             
	*/	
    function _setCustomizedThemesId($themesId="")
    {
        $themesId=intval($themesId);
        
        if($themesId>0){
            $this->objDb->query("SELECT id FROM ".DBPREFIX."skins");
			while($this->objDb->next_record()) {
		    	if($this->objDb->f('id')==$themesId){
		    	    $this->currentThemesId=intval($themesId);	
		    	}
		    }      	       	        		
        }   	
    }
    
    
    
    
    function getUserFrontendLangMenu()
    { 
		$i = 0;				
		parse_str($_SERVER['QUERY_STRING'], $vars);
		$query = isset($vars['cmd']) ? "?cmd=".$vars['cmd'] : "";
		
		$return = "\n<form action='index.php".$query."' method='post' name='userFrontendLangIdForm'>\n";      	   
		$return .= "<select name='userFrontendLangId' size='1' onchange=\"document.forms['userFrontendLangIdForm'].submit()\">\n";		
		
		foreach($this->arrLang as $id=>$value){
			if($this->arrLang[$id]['frontend']==1) {
				$i++;
				if($id==$this->userFrontendLangId) {
				    $return .= "<option value='".$id."' selected='selected'>Frontend [".$value['name']."]</option>\n";
				} else {
				    $return .= "<option value='".$id."'>Frontend [".$value['name']."]</option>\n";	
				}
		    }
		}
		$return .= "</select>\n</form>\n";
		return ($i>1) ? $return : ""; 	   	
    }       
}
?>