<?php
/**
* Class Navigation 
*
* This class creates the navigation tree
*
* @copyright   ASTALAVISTA SECURE CMS - 2004 Astalavista Group GmbH
* @author      Ivan Schmid <ivan.schmid@astalavista.ch>             
* @module      navigation 
* @modulegroup core                                                                                     
* @version	   $Id:    Exp $
*/
class Navigation
{
    var $langId; 
    var $data = array();
    var $table = array(); 
    var $tree = array();
    var $parents = array();   
    var $pageId;
    var $styleNameActive = "active";
    var $styleNameNormal = "inactive";
    var $separator = " > ";
    var $spacer = "&nbsp;";
    var $levelInfo = "down";
    
    
    /**
    * Constructor
    *
    * @global    string   $_LANGID
    * @param     integer  $pageId
    */
	function Navigation($pageId)
	{
	    global $_LANGID;	
	    
	    $this->langId = $_LANGID;
	    $this->pageId = $pageId;		   	
        $this->_initialize();
        $this->_getParents();		  
		// $parcat is the starting parent id
		// optional $maxLevel is the maximum level, set to 0 to show all levels
		$this->_buildTree();                	
	}
	

	
    /**
    * Initialize the data hash from the database
    *
    * @global  object $db
    * @access private
    */	
    function _initialize()
    {
    	global $db;
    	
		$db->query("SELECT n.cmd AS cmd,
		                   n.catid AS catid,
		                   n.catname AS catname,
		                   n.target AS target, 
		                   n.parcat AS parcat,
		                   n.displayorder AS displayorder,
		                   m.name AS section 
		              FROM ".DBPREFIX."content_navigation AS n,
		                   ".DBPREFIX."modules AS m 
		             WHERE n.module=m.id 
		               AND (n.displaystatus = 'on' OR n.catid='$this->pageId')
		               AND n.lang='$this->langId' 		  	             
		          ORDER BY n.parcat ASC, n.displayorder ASC"); 
		  
		 while($db->next_record()){	
			$this->table[$db->f('parcat')][$db->f('catid')]= $db->f('catname');
			$this->parentId[$db->f('catid')]=$db->f('parcat');
			   
			$s=$db->f('section');
			$c=$db->f('cmd');
			$section = ($s=="") ? "" : "&amp;section=$s"; 
			$cmd = ($c=="") ? "" : "&amp;cmd=$c"; 
			$link = (!empty($s)) ? "?section=".$s.$cmd : "?page=".$db->f('catid').$section.$cmd;
				
			$this->data[$db->f('catid')]= array(
			    'catid'    => $db->f('catid'),
			    'url'      => $_SERVER['PHP_SELF'].$link,			
			    'catname'  => stripslashes($db->f('catname')),
			    'target'   => $db->f('target')     
			    );			
		  }
    }

    
    
    /**
    * builds the navigation tree sorted by parents
    *
    * @access private
    * @param int $parentId (Optional)
    * @param int $maxlevel (Optional) 
    * @param int $level (Optional)              
    */	
	function _buildTree($parentId=0,$maxlevel=0,$level=0)
	{
		foreach( $this->table[$parentId] AS $id => $data ){
	    	$this->tree[$id]=$level+1;	 	            	
			if ((isset($this->table[$id])) AND (($maxlevel>=$level+1) OR ($maxlevel==0))){
			  $this->_buildTree($id,$maxlevel,$level+1);
			}
	    }
	}
	

	
    /**
    * Gets the parsed navigation
    *
    * @access private
    * @param string  $templateContent    
    * @return mixed parsed navigation      
    */	
	function getNavigation($templateContent)
	{		
		$_objTpl = &new HTML_Template_Sigma('.');
		$_objTpl->setErrorHandling(PEAR_ERROR_DIE);			
		$_objTpl->setTemplate($templateContent, true, true);
		
		// not set
		$topLevelBlockName = NULL;
		$blockName = NULL;
		$htmlOutput = NULL;	
		$navigationId[] = 0; // CSS styling ID's
		
		/*
		$counter = count($this->tree);
		for ($i=0,$j=1;$j<$counter;$i++,$j++)
		*/
		
		$array_ids = array_keys( $this->tree );	
		// foreach($this->tree as $id => $level)
		foreach( $array_ids as $key => $id ) { 			
			$level =$this->tree[$id];
			$navigationId[$level]++;
			$nextlevel = ( isset( $this->tree[$array_ids[$key+1]] ) ) ? $this->tree[$array_ids[$key+1]] : 0;
			// print_r($nextlevel);			
			
			$hideLevel=false;
			// checks if the page is in the current tree
			if(in_array($this->parentId[$id], $this->parents)){						
				// checks for customized blocks. e.g. "level_1"
				if($_objTpl->blockExists('level_'.$level)){ 				
					// gets the top level block name from the template
					if(!isset($topLevelBlockName)){
                        $topLevelBlockName='level_'.$level;
					}
					$blockName = 'level_'.$level;			    
				}
				// no customized blocks for this level
				else {
					// we already had cutomized blocks 
					if(isset($topLevelBlockName)){
						// checks for the standard block e.g. "level"
						if($_objTpl->blockExists('level')){ 				
							$blockName = 'level';			    
						}else {
							$hideLevel=true; 	
						}										
					}
				}

				if(isset($topLevelBlockName)){				
					if(!$hideLevel){
												
						// checks if we are in the active tree
						$activeTree = (in_array($id, $this->parents)) ? true : false;
						// gets the style sheets value for active or inactive						
						$style = ($activeTree) ? $this->styleNameActive : $this->styleNameNormal;
						// get information about the next level id -> down or empty					
						// $levelInfo = (($level > $nextlevel) OR $activeTree AND $id <> $this->pageId) ? $this->levelInfo : "";
						
						$levelInfo = ($level > $nextlevel) ? $this->levelInfo : "";	
						$target = empty($this->data[$id]['target']) ? "_self" : $this->data[$id]['target'];					
						$_objTpl->setCurrentBlock($blockName);									
					    $_objTpl->setVariable('URL',$this->data[$id]['url']);
					    $_objTpl->setVariable('NAME',$this->data[$id]['catname']);
					    $_objTpl->setVariable('TARGET',$target);
					    $_objTpl->setVariable('LEVEL_INFO',$levelInfo);
					    $_objTpl->setVariable('NAVIGATION_ID',$navigationId[$level]);
					    $_objTpl->setVariable('STYLE',$style);			    
					    $_objTpl->parse($blockName);
					    $htmlOutput.=$_objTpl->get($blockName, true);
					}										
				}			
			}
		}
		unset($navigationId);
		
		if(isset($topLevelBlockName)){
			// replaces the top level block with the complete parsed navigation
			// this is because the Sigma Template system don't support nested blocks 
			// with difference object based orders
			$_objTpl->replaceBlock($topLevelBlockName, $htmlOutput, true);		
			$_objTpl->touchBlock($topLevelBlockName);
			if($_objTpl->blockExists('navigation')){ 		
			    $_objTpl->parse('navigation');
			}
		}
		return $_objTpl->get();	
	}

	
	
	/**
    * Get an array with all parentids
    *
    * @access  private
    */
	function _getParents()
	{
		$parentId = $this->parentId[$this->pageId];		
		while($parentId!=0) 
		{
			if(is_array($this->table[$parentId]))
			{ 		
				array_push($this->parents, $parentId);
				$parentId = $this->parentId[$parentId];
			} 			
		}		
		// adds the current pageId and the root id 0 to the parents array
		array_push($this->parents, $this->pageId, 0);		
	}
	
	

	/**
    * Get trail
    *
    * @param     integer  $currentid
    * @return    integer  $allparents
    */
	function getTrail()
	{
		$return ="";
		$parentId = $this->parentId[$this->pageId];
		while ($parentId!=0) 
		{
			if(!is_array($this->table[$parentId]))
			{ 
			    return $return;	
			}
			$n = $this->data[$parentId]['catname'];
			$u = $this->data[$parentId]['url'];
			$trail = "<a href=\"".$u."\" title=\"".$n."\">".$n."</a>".$this->separator;
			$return=$trail.$return;
			$parentId = $this->parentId[$parentId]; 
		}
		return $return;
	}
	
	
	
    /**
    * getFrontendLangNavigation()
    *
    * @param string   language navigation
    * @access public
    */	
  
    function getFrontendLangNavigation()
	{
	  	global $objInit;
	  	$this->arrLang = $objInit->getLanguageArray();  
		$langNavigation = "";				
	  	if(count($this->arrLang)>1) {
	  	  	foreach($this->arrLang as $id=>$value) {
	  	  		if($this->arrLang[$id]['frontend']==1) {
	  	  		    $langNavigation .= " [ <a href='?langId=".$id."' title='".$value['name']."' >".$value['name']."</a> ] ";
	  	  		}
	  	  	}
	  	}
		return $langNavigation; 	  	  	 		
	}
	
	
	
	function _debug($obj){
		  echo "<pre>";
		  print_r($obj);	
		  echo "</pre>";		
	}
}
?>