<?
/**
* Security class
*
* The security class  checks for possible attacks to the server 
* and supports a few functions to make everything more secure.
*
* @copyright    ASTALAVISTA SECURE CMS - 2005 Astalavista IT Engineering
* @author	    Ivan Schmid <ivan.schmid@astalavista.ch> 
* @author	    Gerben van der Lubbe <spoofedexistence@gmail.com>
* @module	    security
* @modulegroup	core
* @version	2.0	improved version
**/


class Security
{
	/**
	* function getRequestInfo($reqarray, $arrname);
	* @description	Lists the content for an array for sending it with an e-mail
	* @argument 1	$reqarray The array to send the contents from.
	* @argument 2	$arrname  The name in the array.
	* @returns	The value ready to send
	**/
	function getRequestInfo($reqarray, $arrname)
	{
		$retdata = "";
		if(!is_array($reqarray))
			return "";

		// For each content of the $reqarray
		foreach($reqarray as $nname => $nval){
			// If this is an array
			if(is_array($nval)){
				// It's an array. Add the contents of it.
				$retdata .= $arrname." [$nname] : array {\r\n";
				$retdata .= $this->getRequestInfo($nval, $arrname." [$nname]");
				$retdata .= $arrname." [$nname] : }\r\n";
			} else {
				// It's no array, just add it
				$retdata .= $arrname." [$nname] : $nval\r\n";
			}
		}
		return $retdata;
	}
	
	
	
	

	/**
	* function ReportIntrustion($type, $file = "Filename not available", $line = "Linenumber not available");
	* @description	Reports a possible intrusion attempt to the administrator
	* @argument 1	$type	The type of intrusion attempt to report.
	* @argument 2	$file	The file requesting the report (defaults to "Filename not available")
	* @argument 3	$line	The line number requesting the report (defaults to "Linenumber not available")
	**/
	function reportIntrusion($type, $file = "Filename not available", $line = "Linenumber not available")
	{
		GLOBAL $objDb, $_CONFIG;

		$remoteaddr = isset($_SERVER['REMOTE_ADDR']) ? $_SERVER['REMOTE_ADDR'] : "Not set";
		$httpxforwardedfor = isset($_SERVER['HTTP_X_FORWARDED_FOR']) ? $_SERVER['HTTP_X_FORWARDED_FOR'] : "Not set";
		$httpvia = isset($_SERVER['HTTP_VIA']) ? $_SERVER['HTTP_VIA'] : "Not set";
		$httpclientip = isset($_SERVER['HTTP_CLIENT_IP']) ? $_SERVER['HTTP_CLIENT_IP'] : "Not set";
		$gethostbyname = gethostbyname($remoteaddr);
		if($gethostbyname == $remoteaddr)
			$gethostbyname = "No matching hostname";

		// Add all the user's info to $user
		$user = "REMOTE_ADDR : $remoteaddr\r\n".
			    "HTTP_X_FORWARDED_FOR : $httpxforwardedfor\r\n".
			    "HTTP_VIA : $httpvia\r\n".
			    "HTTP_CLIENT_IP : $httpclientip\r\n".
			    "GetHostByName : $gethostbyname\r\n";

		// Add all requested information
		$httpheaders = getallheaders();
		$gpcs = "";
		$gpcs .= $this->getRequestInfo($httpheaders, "HTTP HEADER");
		$gpcs .= $this->getRequestInfo($_REQUEST, "REQUEST");
		$gpcs .= $this->getRequestInfo($_GET, "GET");
		$gpcs .= $this->getRequestInfo($_POST, "POST");
		$gpcs .= $this->getRequestInfo($_SERVER, "SERVER");
		$gpcs .= $this->getRequestInfo($_COOKIE, "COOKIE");
		$gpcs .= $this->getRequestInfo($_FILES, "FILES");
		$gpcs .= $this->getRequestInfo($_SESSION, "SESSION");

		// Get the data to insert in the database
		$cdate = time();
		$dbuser = htmlspecialchars(addslashes($user));
		$dbgpcs = htmlspecialchars(addslashes($gpcs));
		$where = addslashes("$file : $line");

		// Insert the intrusion in the database
		$objDb = &new astalavistaDB;
		$objDb->query("INSERT INTO ".DBPREFIX."ids (timestamp, type, remote_addr, http_x_forwarded_for, http_via, user, gpcs, file)
				VALUES($cdate, '$type', '$remoteaddr', '$httpxforwardedfor', '$httpvia', '$dbuser', '$dbgpcs', '$where')");

		// The headers for the e-mail
		$sendto = $_CONFIG['coreAdminName']." <".$_CONFIG['coreAdminEmail'].">\r\n";
		$from = $_CONFIG['coreAdminEmail'];

		// The message to send
		$message = "DATE : $cdate\r\nFILE : $where\r\n\r\n$user\r\n\r\n$gpcs";
		$subject = $_SERVER['HTTP_HOST']." : ".$type;

		// Send the e-mail to the administrator
		@mail($sendto, 
		      $subject, 
		      $message, 
		      "From: $from\r\n" .
			  "Reply-To: $from\r\n" .
			  "X-Priority: 1\r\n" .
			  "X-Mailer: Contrexx Mailer/" . phpversion());								  
	}
	
	
	
	/**
	* function detectIntrusion($array);
	* @description	Looks through an array and tries to detect possible hacking attempts.
	* @argument 1	$array	The array (or string) to check for security.
	* @return	The array with the trusted values, or the string
	**/
	function detectIntrusion($array)
	{
		// If it's not an array, test this record for safety and return the result
		if(!is_array($array)){
			while(1){
				$safe = 1;

				// Test the string (called $array) for cross site scripting attacks
				if(
					// Disallow <*script
					eregi("<[^>a-z0-9]*script[^a-z]+", $array) ||
					// Disallow <*xml*
					eregi("<[^>a-z0-9]*xml[^a-z]+", $array) ||
					// Disallow <*style*
					eregi("<[^>a-z0-9]*style[^a-z]+", $array) ||
					// Disallow <*form*
					eregi("<[^>a-z0-9]*form[^a-z]+", $array) ||
					// Disallow <*input*
					eregi("<[^>a-z0-9]*input[^a-z]+", $array) ||
					// Disallow <*window*
					eregi("<[^>a-z0-9]*window[^a-z]+", $array) ||
					// Disallow <*alert*
					eregi("<[^>a-z0-9]*alert[^a-z]+", $array) ||
					// Disallow <*img*
					eregi("<[^>a-z0-9]*img[^a-z]+", $array) ||
	 				// Disallow <*cookie*
					eregi("<[^>a-z0-9]*cookie[^a-z]+", $array) ||
					// Disallow <*object*
					eregi("<[^>a-z0-9]*object[^a-z]+", $array) ||
					// Disallow <*iframe*
					eregi("<[^>a-z0-9]*iframe[^a-z]+", $array) ||
					// Disallow <*applet*
					eregi("<[^>a-z0-9]*applet[^a-z]+", $array) ||
					// Disallow <*meta*
					eregi("<[^>a-z0-9]*meta[^a-z]+", $array) ||
					// Disallow <*body*
					eregi("<[^>a-z0-9]*body[^a-z]+", $array) ||
					// Disallow <*font*
					eregi("<[^>a-z0-9]*font[^a-z]+", $array) ||
					// Disallow <*p*
					eregi("<[^>a-z0-9]*p[^a-z]+", $array) ||
					// Disallow "javascript: and 'javascript
					eregi("[\"|']javascript:", $array) ||
					// Disallow =javascript:
					eregi("=javascript:", $array) ||
					// Disallow "vbscript: and 'vbscript:
					eregi("[\"|']vbscript:", $array) ||
					// Disallow =vbscript:
					eregi("=vbscript:", $array) ||
					// Disallow on*=
					eregi("[^a-z0-9]*on[a-z]+[\t ]*=", $array)
				  )
				{
					// Report a potential cross site scripting attack
					$this->reportIntrusion("SQL Injection");
					$safe = 0;

					// Use special ways to protect to some cross site scriptings
					if(
						eregi("[\"|']javascript:", $array) ||
						eregi("=[\t ]*javascript:", $array) ||
						eregi("[\"|']vbscript:", $array) ||
						eregi("=[\t ]*vbscript:", $array)
					  )
					{
						// Remove the ':'
						$array = eregi_replace("([\"|']javascript):", "\\1", $array);
						$array = eregi_replace("(=[\t ]*javascript):", "\\1", $array);
						$array = eregi_replace("([\"|']vbscript):", "\\1", $array);
						$array = eregi_replace("(=[\t ]*vbscript):", "\\1", $array);
					}
					if(eregi("[^a-z0-9]*on[a-z]+[\t ]*=", $array)){
						// Remove the =
						$array = eregi_replace("([^a-z0-9]*on[a-z]+[\t ]*)=", "\\1", $array);
					}
					// Secure it using htmlspecialchars
					$array = htmlspecialchars($array);
				}

				// Test for SQL injection
				if(
					// Disallow "*or/and*=*" or "*or*like*"
					eregi("([^a-z]+|^)(OR|AND)[^a-z]+.*(=|like)", $array) ||
					// Disallow "*UNION*SELECT "
					eregi("([^a-z]+|^)UNION[^a-z]+.*SELECT[\t ]+", $array)
				  )
				{
					// Report for an intrusion attempt
					$this->reportIntrusion("SQL Injection");
					$safe = 0;

					// On "*or/and*=/like*", remove OR/AND
					$array = eregi_replace("([^a-z]+|^)(OR|AND)([^a-z]+.*(=|like))", "\\1\\3", $array);

					// On "*UNION*SELECT ", remove union
					$array = eregi_replace("([^a-z]+|^)UNION([^a-z]+.*SELECT[\t ]+)", "\\1\\3", $array);
				}

				// Return the untrusted value, it's fine
				if($safe == 1)
					return $array;
			}
		}

		// The trusted value will become an array
		$trusted = array();

		// For each record in the array
		foreach($array as $nname => $untrusted){
			// Get untrusted's trusted value and store it
			$trusted[$nname] = $this->detectIntrusion($untrusted);
		}

		// Return the trusted array
		return $trusted;
	}
}
?>