<?php
/**
* This class creates a tree structure as an indexed array object
*
* content array provider
*
* @copyright     ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering          
* @module    	 ContentTree
* @modulegroups  core                    
* @author        Ivan Schmid <ivan.schmid@astalavista.ch>             
* @version       $Id:  Exp $                                         
*
*
* Dev.status / Public methods for Tree class:
*   1 getTree()               Retrieves an indexed array of the nodes from top to bottom, left to right
*   1 getThisNode()          Retrieves an array of the current nodes
*   0 getPrevious()           Returns the previous Tree_Node object if any
*   0 getNext()               Returns the next Tree_Node object if any
*   0 getParent()             Returns the parent Tree_Node object if any
*   0 hasChildren()           Returns whether this node has child nodes or not
*   0 depth()                 Returns the depth of this node in the tree (zero based)
*   0 isChildOf()             Returns whether this node is a direct child of the given node/tree
*   1 getNodeCount()          Retreives the number of nodes in the collection, optionally recursing
*   0 getThisTree()           Retreives an indexed array of the current node
*/
class ContentTree
{
  var $table   = array();
  var $node   = array();
  var $tree   = array();  
  var $langId = '';
  var $index = 0;
  

  
    /**
    * Constructor
    *
    */
	function ContentTree()
	{
		global $db, $_LANGID;	
		
		$this->langId =$_LANGID;
		
		$modules = array(); 
		$db->query("SELECT id, name FROM ".DBPREFIX."modules");
		while($db->next_record())
		{
			$modules[$db->f('id')]=$db->f('name');
		}
		 
		$db->query( "SELECT catid,  
							parcat,
							catname,
							displayorder, 
							displaystatus, 
							username,
							FROM_UNIXTIME(changelog,'%d.%m.%Y %T') AS changelog, 
							cmd,
							lang,
							module,
							startdate,
							enddate, 
							protected,
							frontend_groups,
							backend_groups 			  
		               FROM ".DBPREFIX."content_navigation
		              WHERE lang=".$this->langId." 
		           ORDER BY parcat ASC, displayorder ASC");  		  
		  
		 while($db->next_record())
		 {	
			$this->node[$db->f('catid')]= array(
				'catid' => $db->f('catid'),	
			    'parcat' => $db->f('parcat'),		
			    'catname' => $db->f('catname'),
			    'displayorder' => $db->f('displayorder'),
			    'displaystatus' => $db->f('displaystatus'),
			    'changelog' => $db->f('changelog'),
			    'cmd' => $db->f('cmd'),
			    'modulename' => $modules[$db->f('module')],
			    'moduleid' => $db->f('module'),
			    'lang' => $db->f('lang'),
			    'startdate' => $db->f('startdate'),
			    'enddate' => $db->f('enddate'),
			    'protected' => $db->f('protected'),
			    'frontend_groups' => $db->f('frontend_groups'),
			    'backend_groups' => $db->f('backend_groups')	    
			    );
		 				
			$this->table[$db->f('parcat')][$db->f('catid')]= array(
				'catid' => $db->f('catid'),	
			    'parcat' => $db->f('parcat'),		
			    'catname' => $db->f('catname'),
			    'displayorder' => $db->f('displayorder'),
			    'displaystatus' => $db->f('displaystatus'),
			    'changelog' => $db->f('changelog'),
			    'cmd' => $db->f('cmd'),
			    'modulename' => $modules[$db->f('module')],
			    'moduleid' => $db->f('module'),
			    'lang' => $db->f('lang'),
			    'startdate' => $db->f('startdate'),
			    'enddate' => $db->f('enddate'),
			    'protected' => $db->f('protected'),
			    'frontend_groups' => $db->f('frontend_groups'),
			    'backend_groups' => $db->f('backend_groups'),
			    'level' => '0',		    
			    );
		 }
		 // $parcat is the starting parent id
		 // optional $maxLevel is the maximum level, set to 0 to show all levels
		 $this->buildTree($parcat=0,$maxlevel=0,$level=0);		   		
	}


	function buildTree($parcat=0,$maxlevel=0,$level=0)
	{
		$list=$this->table[$parcat];
		foreach( $list AS $key => $data )
	    {			
  	        $this->tree[$this->index] =$list[$key];
  	        $this->tree[$this->index]['level']=$level;	    	
	    	$this->index++;
			if ((isset($this->table[$key])) AND (($maxlevel>=$level+1) OR ($maxlevel==0)))
			{
			  $this->buildTree($key,$maxlevel,$level+1);
			}
	    }
	}	

	
	function getNodeCount()
	{
		return count($this->table);
	}
	
	

	function getThisNode($nodeId)
	{	
		if(!empty($nodeId))
		return $this->node[$nodeId];
	}
	
	
	function getTree()
	{
		// $parcat is the starting parent id
		// optional $maxLevel is the maximum level, set to 0 to show all levels		
		return $this->tree;
		/*
		print "<pre>";
		print_r($this->tree);
		print "</pre>";
		*/
	}	
}
?>