<?php
/**
* Authentification class
*
* The Authentification class checks if the username/password combination matches 
* the database user table.
*
* @copyright   ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering
* @author      Ivan Schmid <ivan.schmid@astalavista.ch>   
* @module      authentification
* @modulegroup core                                                                                     
* @version	   $Id:    Exp $
*/  

class Auth
{
    var $type = ''; // values are frontend or backend     	
    var $errorMessage = array();

    
    
	/**
	 * Constructor
	 *
	 */	
    function Auth($authType='frontend')
	{
		$this->type=$authType;				
	}

	
	
		
	function checkAuth()
	{
		global $sessionObj, $_CORELANG;	
		
		$this->assignData();
			
		if(isset($_SESSION['auth']['username']) && isset($_SESSION['auth']['password'])) { 		
			///////////////////////////////////
			// Backend Authentification
			///////////////////////////////////	
			if($this->type=='backend') {								
				if(!$this->checkCode()) {
				    $this->errorMessage[] = $_CORELANG['TXT_SECURITY_CODE_IS_INCORRECT'];
				    return false;
				}
		    	if($this->checkUserData() AND $this->checkType()) {	
		    		// sets cookie for 30 days						
					setcookie("username", $_SESSION['auth']['username'], time()+3600*24*30);
					$this->log();															
					$sessionObj->cmsSessionUserUpdate($username=$_SESSION['auth']['username']);																			
					return true;
				}				
			}
			///////////////////////////////////
			// Frontend Authentification
			///////////////////////////////////				
			else 
			{
		    	if($this->checkUserData() AND $this->checkType()) {																						
					$sessionObj->cmsSessionUserUpdate($username=$_SESSION['auth']['username']);																			
					return true;
				}				
			} 			
		}  
		$sessionObj->cmsSessionUserUpdate($username="unknown");
		$sessionObj->cmsSessionStatusUpdate($status=$this->type);
		return false;
	}



	
	
    /**
     * Assign data from login form to internal values
     *
     * This function takes the values for username and password
     * from $_POST and assigns them to internal variables.
     *
     * @access private
     * @global $_POST
     * @see    Auth
     * @return void
     */
    function assignData()
    {
        if (isset($_POST['USERNAME']) && $_POST['USERNAME'] != '') {
            $_SESSION['auth']['username'] = (get_magic_quotes_gpc() == 1 ? stripslashes($_POST['USERNAME']) : $_POST['USERNAME']);
        }

        if (isset($_POST['PASSWORD']) && $_POST['PASSWORD'] != '') 
        {
        	// iclient-side md5 hash -> not yet implemented
        	// http://pajhome.org.uk/crypt/md5/
        	if(strlen($_POST['PASSWORD'])==32) {
                $_SESSION['auth']['password'] = stripslashes($_POST['PASSWORD']);	
            } else {
        	    $_SESSION['auth']['password'] = (get_magic_quotes_gpc() == 1 ? md5(stripslashes($_POST['PASSWORD'])) : md5($_POST['PASSWORD']) );
            }
        }
        
        if (isset($_POST['secid2']) && $_POST['secid2'] != '') {
            $_SESSION['auth']['secid2'] = (get_magic_quotes_gpc() == 1 ? stripslashes($_POST['secid2']) : $_POST['secid2']);
        }
    }
    
    
    
    /**
     * checks the code from the security image
     *
     * This function compares the security image code with the
     * Code in the session     
     *
     * @access private
     * @global $_SESSION
     * @see    Auth
     * @return void
     */
    function checkCode()
    {	
		if($_SESSION['auth']['secid2'] != $_SESSION['auth']['secid'])	
		    return false;
		else
		    return true;
    }    	


    
    
    

    /**
     * check user data from the database
     *
     * check user data from the database.
     *
     * @access private
     * @global $db, $sessionObj
     * @see    Auth
     * @return void
     */
    function checkUserData()
    {
		global $db;	   
	
		if(isset($_SESSION['auth']['username']) AND isset($_SESSION['auth']['password']))
	    {	  
			if ($db->query("SELECT password,
			                       username,
			                       id,
			                       groups,
			                       is_admin,
			                       langId,
			                       firstname,
			                       lastname,
			                       active
			                  FROM ".DBPREFIX."users 
			                 WHERE username = '{$_SESSION['auth']['username']}' AND active=1 LIMIT 1")) 	
			{
				if($db->next_record())
				{
					if($_SESSION['auth']['password'] == $db->f('password'))
					{
						$_SESSION['auth']['userid']=$db->f('id');
						$_SESSION['auth']['username']=$db->f('username');
						$_SESSION['auth']['groups']=$db->f('groups');
						$_SESSION['auth']['name']= $db->f('firstname')." ".$db->f('lastname');
						$_SESSION['auth']['lang']= $db->f('langId');
						$_SESSION['auth']['is_admin']=$db->f('is_admin');																
						return true;
					}
					else {
						$this->errorMessage[] = $_CORELANG['TXT_PASSWORD_OR_USERNAME_IS_INCORRECT'];
						return false;
					}
				} else {
				    $this->errorMessage[] = $_CORELANG['TXT_PASSWORD_OR_USERNAME_IS_INCORRECT'];
				    return false;	
				}
			}
	    }
	    return false;
    }    
	
	

    
    
	function checkType() 
	{					
	    global $db;
	    
	    if($this->type=='backend')
	    {
	    	if($_SESSION['auth']['is_admin']==1)
	    	    return true;
	    	$arrUserGroups=explode(",",$_SESSION['auth']['groups']);
	    	if(is_array($arrUserGroups)) {
	    		$db->query("SELECT group_id FROM ".DBPREFIX."user_groups WHERE type='$this->type'");
	    		while($db->next_record())
	    		{
	    			if(in_array($db->f('group_id'),$arrUserGroups))
	    			    return true;
	    		}
	    	}
	    }
	    return false;
	}   
    
  
    

	function log()
	{
	    global $db;	
	    
		if(!isset($_SESSION['auth']['log']))
		{
			$remote_host = @gethostbyaddr($_SERVER['REMOTE_ADDR']);
			$referer = htmlspecialchars(strtolower($_SERVER['HTTP_REFERER']));   
		       		
			$db->query("INSERT INTO ".DBPREFIX."log 
			                    SET userid={$_SESSION['auth']['userid']},
			                        datetime = NOW(),
		                            useragent = '{$_SERVER['HTTP_USER_AGENT']}',
		                            userlanguage = '{$_SERVER['HTTP_ACCEPT_LANGUAGE']}',	
		                            remote_addr = '{$_SERVER['REMOTE_ADDR']}',	
		                            remote_host = '$remote_host',	
		                            http_x_forwarded_for = '{$_SERVER['HTTP_X_FORWARDED_FOR']}',	
		                            http_via = '{$_SERVER['HTTP_VIA']}',	
		                            http_client_ip = '{$_SERVER['HTTP_CLIENT_IP']}',
									referer ='$referer'");
				
			$_SESSION['auth']['log']=true;
		}
	}
	

	/**
	* Function logout
	*  
	* kills all sessions and redirects to the frontend page   	                                                                       
	*/	
	function logout()
	{	
		if(isset($_SESSION['auth']))
		{
			unset($_SESSION['auth']);
			session_destroy();
		}
		
		if($this->type=='public')	
		    header('Location: ?section=login');
		else
		    header('Location: ../'); 
		exit;
	}
	
	
	/**
	* Function status
	*
	* @global    array      $_SESSION[]                                                                         
	*/
	
	function status()
	{
		global $sessionObj, $_CORELANG;
		
		if (!isset($_SESSION['auth']['username'])) {
			return "";
		} else {
			return $_CORELANG['TXT_LOGGED_IN_AS']." ".$_SESSION['auth']['username']." (<a href='?section=logout'>logout</a>)";
		}
		
	}	
	
	
	
	/**
	* Function lost password
	*
	* @global    array      $_SESSION[]                                                                         
	*/
	
	function lostpw()
	{
		global $db, $_CORELANG;
		
		//check email
		if (isset($_POST['EMAIL'])) {
			$user_mail = $_POST['EMAIL'];
        	$db->query("SELECT password,
			                       username,
			                       id,
        	                       email
			                  FROM ".DBPREFIX."users 
			                 WHERE email = '$user_mail' AND active=1");
        	
			while ($db->next_record()) {
				$userid = $db->f('id');
				$username = $db->f('username');
				$usermail = $db->f('email');
				
				//generate restore_key
				$rand=rand(0, 255);
				$restore_key = md5($rand);
				
				$objDb =&new astalavistaDB;
				$objDb->query("UPDATE ".DBPREFIX."users 
		                    		SET restore_key='$restore_key' 
				                  WHERE id = '$userid'");
				
				//send email
				$link = strtolower(ASCMS_PROTOCOL)."://".$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF'])."/index.php?cmd=restorepw&key=".$restore_key;
				
				if(getenv("HTTP_X_FORWARDED_FOR"))	{$ipaddress = @getenv("HTTP_X_FORWARDED_FOR");}
				else								{$ipaddress = @getenv("REMOTE_ADDR");}	
				
				$host 		= @gethostbyaddr($ipaddress);
				$lang 		= @getenv("HTTP_ACCEPT_LANGUAGE");
				$browser 	= @getenv("HTTP_USER_AGENT");
				$to         = $usermail;
				$sendTo		= $usermail;
				
				$subject 	= $_CORELANG['TXT_RESTORE_MAIL_TITLE'];
		        $now 		= date(ASCMS_DATE_FORMAT);
			
			   // Email message
		        $message  = $_CORELANG['TXT_RESTORE_MAIL_PART1'].$_SERVER['SERVER_NAME'].$_CORELANG['TXT_RESTORE_MAIL_PART2'].$username;
			    $message .= $_CORELANG['TXT_RESTORE_MAIL_PART3'];
			    $message .= $_CORELANG['TXT_RESTORE_MAIL_PART4'];
			    $message .= "\n";
			    $message .= "$link\n";
			    $message .= "\n";
			    $message .= $_CORELANG['TXT_RESTORE_MAIL_PART5']."\n";
			    $message .= "\n";
			    $message .= "Host: $host\n";
			    $message .= "Language: $lang\n";
			    $message .= "Browser: $browser\n";
			    $headers  = "From: $subject <$to>\n";
			    
				$sendmail = @mail($to,
							$subject,
							$message,
							"From: ".$sendTo."\r\n" .
							"Reply-To: ".$sendTo."\r\n" .
							"X-Mailer: PHP/" . phpversion());
			}	
			if(!isset($userid)){
				$this->errorMessage[] = $_CORELANG['TXT_WRONG_EMAIL'];
			} else {
				$this->errorMessage[] = $_CORELANG['TXT_PW_RESTORE_SUCCESS'];
			}
		}
	}	
	
	
	
	/**
	* Function restore password
	*
	* @global    array      $_SESSION[]                                                                         
	*/
	
	function restorepw()
	{
		global $db, $_CORELANG;
		
		if (isset($_GET['key'])) {
			
			//get restore_key
			$restore_key = $_GET['key'];
			$db->query("SELECT id,
			                   username,
			                   restore_key
		                  FROM ".DBPREFIX."users 
		                 WHERE restore_key = '$restore_key' AND active=1 LIMIT 1");
			
			if($db->next_record())
			{
				$user_name= $db->f('username');
				$user_id= $db->f('id');
				$user_key = $db->f('restore_key');
			} else {
			    $this->errorMessage[] = $_CORELANG['TXT_NO_DATA_FOUND'];
			}
			
			//check both keys
			if($restore_key == $user_key) {
				$this->errorMessage[] = $_CORELANG['TXT_ENTER_NEW_PW'];
				return $user_name;
			} else {
				$this->errorMessage[] = $_CORELANG['TXT_WRONG_KEY'];
			}

        }else{
        	$this->errorMessage[] = $_CORELANG['TXT_NO_KEY'];
        }
	}

	
	/**
	* Function set new password
	*
	* @global    array      $_SESSION[]                                                                         
	*/
	function newpw()
	{
		global $db, $_CORELANG;
		
		if (isset($_POST['NEWPASSWORD']) && isset($_POST['CONFIRM_NEWPASSWORD'])) {
			
			$newpw = $_POST['NEWPASSWORD'];
			$con_newpw= $_POST['CONFIRM_NEWPASSWORD'];
			$restore_key = $_POST['RESTOREKEY'];
			
			$db->query("SELECT restore_key,
			                   username,
			                   email
		                  FROM ".DBPREFIX."users 
		                 WHERE restore_key = '$restore_key' AND active=1 LIMIT 1");
			
			if($db->next_record())
			{
				$user_key = $db->f('restore_key');
				$usermail = $db->f('email');
				$username = $db->f('username');
			}
			
			//check both keys
			if($restore_key == $user_key) {
				if($newpw == $con_newpw) {
					$newpw = md5($newpw);
					$db->query("UPDATE ".DBPREFIX."users 
		                    		SET restore_key='', 
					                    password='$newpw'
				                  WHERE restore_key = '$restore_key'");
					
					$this->errorMessage[] = $_CORELANG['TXT_NEW_PW_SUCCESS'];
					
					//send mail
					$link = strtolower(ASCMS_PROTOCOL)."://".$_SERVER['SERVER_NAME'].dirname($_SERVER['PHP_SELF'])."/";
					
					if(getenv("HTTP_X_FORWARDED_FOR"))	{$ipaddress = @getenv("HTTP_X_FORWARDED_FOR");}
					else								{$ipaddress = @getenv("REMOTE_ADDR");}	
					
					$host 		= @gethostbyaddr($ipaddress);
					$lang 		= @getenv("HTTP_ACCEPT_LANGUAGE");
					$browser 	= @getenv("HTTP_USER_AGENT");
					$to         = $usermail;
					$sendTo		= $usermail;
					
					$subject 	= $_CORELANG['TXT_NEWPW_MAIL_TITLE'];
			        $now 		= date(ASCMS_DATE_FORMAT);
				
				   // Email message
			        $message  = $_CORELANG['TXT_NEWPW_MAIL_PART1'].$_SERVER['SERVER_NAME'].$_CORELANG['TXT_NEWPW_MAIL_PART2'].$username;
				    $message .= $_CORELANG['TXT_NEWPW_MAIL_PART3']."\n";
			        $message .= "\n";
			        $message .= $_CORELANG['TXT_NEWPW_MAIL_USER'].$username."\n";
			        $message .= "\n";
			        $message .= $_CORELANG['TXT_NEWPW_MAIL_PART4']."\n";
			        $message .= $link."\n";
				    $headers  = "From: $subject <$to>\n";
				    
					$sendmail = @mail($to,
								$subject,
								$message,
								"From: ".$sendTo."\r\n" .
								"Reply-To: ".$sendTo."\r\n" .
								"X-Mailer: PHP/" . phpversion());
				} else {
					$this->errorMessage[] = $_CORELANG['TXT_NEW_PW_ERROR'];
				}
			} else {
				$this->errorMessage[] = $_CORELANG['TXT_WRONG_KEY'];
			}
		}
	}
	
	
	

   /**
    * Returns a textual error message
    *  
    * @access public
    * @return string   error message
    */
    function errorMessage()
    {
        $_errorMessage ='';
        foreach($this->errorMessage AS $value) {
            $_errorMessage .= $value."<br />";
        }
        return $_errorMessage;
    }
}
?>