<?php
/**
* Language Module
*
* This class provides all the language functions and options for the core CMS system
*
* @copyright   ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering GmbH
* @author      Ivan Schmid <ivan.schmid@astalavista.ch>             
* @module      users
* @modulegroup core                                                                                     
* @version	   $Id:    Exp $
*/  

class LanguageManager
{
    var $_objTpl;
	var $pageTitle='';
	var $statusMessage='';
	var $arrLang = array();
	var $filePath='';
	var $hideVariables = true;
	
	/**
	* constructor                                                                             
	*/
	function LanguageManager()
	{
    	global  $db, $_CORELANG, $template;
    	
    	$arrTables = array();
    	
		$this->_objTpl = &new HTML_Template_Sigma(ASCMS_ADMIN_TEMPLATE_PATH);
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);
		$this->filePath = ASCMS_LANGUAGE_PATH. '/';
	    
		// get tables in database
		if($db->query("SHOW TABLES")){
			$arrMetadata = $db->metadata();
			while ($db->next_record()){
				array_push($arrTables,$db->f($arrMetadata[0]['name']));
			}
		}
		if(in_array(DBPREFIX."language_variable_names",$arrTables) && in_array(DBPREFIX."language_variable_content",$arrTables)){
			$this->hideVariables = false;
		}
		
		$template->set_var("CONTENT_NAVIGATION","<a href='index.php?cmd=language'>[".$_CORELANG['TXT_LANGUAGE_LIST']."]&nbsp;"
		                                         .($this->hideVariables == false ? "<a href='index.php?cmd=language&amp;act=vars'>[".$_CORELANG['TXT_VARIABLE_LIST']."]</a>&nbsp;
		                                         <a href='index.php?cmd=language&amp;act=mod'>[".$_CORELANG['TXT_ADD_LANGUAGE_VARIABLES']."]</a>&nbsp;
												 <a href='index.php?cmd=language&act=writefiles' title='".$_CORELANG['TXT_WRITE_VARIABLES_TO_FILES']."'>[".$_CORELANG['TXT_WRITE_VARIABLES_TO_FILES']."]</a>" 
		                                         : ""));
		                                         
	    
		                                         
	    $db->query("SELECT id,name FROM ".DBPREFIX."languages");
		while($db->next_record())
		{
			$this->arrLang[$db->f('id')]=$db->f('name');
		}
		    	
	    $db->query("OPTIMIZE TABLE ".DBPREFIX."languages");
	    $db->query("OPTIMIZE TABLE ".DBPREFIX."language_variable_content");
	    $db->query("OPTIMIZE TABLE ".DBPREFIX."language_variable_names"); 			
	}	

	
		
    /**
    * Gets the requested methods
    *
    * @global   array     $_CORELANG
    * @global   object    $template
    * @global   object    $objPerm
    * @return   string    parsed content                                                                                  
    */	
	function getLanguagePage()
    {
    	global $_CORELANG, $template, $objPerm;
    	
    	if(!isset($_GET['act']))
    	{
    	    $_GET['act']="";	
    	}
    	
        switch($_GET['act'])
		{
			case "dellang":			     
			    $objPerm->checkPerm(49); 
			    $this->deleteLanguage();	
			    $this->languageOverview();			           	
			break;				
			case "vars":		     
			    $this->listVariables();      	
			break;				
			case "mod":	
			    $objPerm->checkPerm(48); 
			    $this->addUpdateVariable();    
			    $this->modifyVariables();       	
			break;
			case "add":	
			    $objPerm->checkPerm(50); 
			    $this->addLanguage();    
			    $this->languageOverview();      	
			break;			
			case "del":	
			    $objPerm->checkPerm(48);			        
			    $this->deleteVariable();
			    $this->listVariables(); 	         	
			break;
			case "writefiles":
				$objPerm->checkPerm(48);
				$this->createFiles();
				$this->listVariables();
				break;
			default:
			    $objPerm->checkPerm(50);
			    $this->modifyLanguage();          
			    $this->languageOverview();       	     		        
		}
		$template->set_var("CONTENT_TITLE",$this->pageTitle); 		
		$template->set_var("CONTENT_STATUS_MESSAGE",$this->statusMessage); 		
		return $this->_objTpl->get(); 
    } 

	
	
	/**
	* deletes the selected language
	*
	* @global    array      $_CORELANG
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     error string or empty string                                                                             
	*/
	function deleteLanguage()
	{
		global $_CORELANG, $db;	
		if (!empty($_REQUEST['id']))
		{
	        $db->query("SELECT lang FROM ".DBPREFIX."content_navigation WHERE lang={$_REQUEST['id']}");
			if($db->num_rows()<1)
			{  
				if($db->query("DELETE FROM ".DBPREFIX."languages WHERE id={$_REQUEST['id']}"))
				{
					$db->query("DELETE FROM ".DBPREFIX."language_variable_content WHERE lang_id={$_REQUEST['id']}");
					$this->statusMessage = $_CORELANG['txtLanguageDeletedSuccessful']; //not available	
					return true;							
				}
			}
			else
			{
			    $this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];
			    return false;					
			}
		}
	}
    
    
    
	/**
	* deletes the selected language variables
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    boolean                                                                             
	*/
	function deleteVariable()
	{
		global $_CORELANG, $db;
		if (!empty($_REQUEST['id']))
		{
	        $db->query("DELETE FROM ".DBPREFIX."language_variable_names WHERE id={$_REQUEST['id']}");
			$db->query("DELETE FROM ".DBPREFIX."language_variable_content WHERE varid={$_REQUEST['id']}");
			$this->statusMessage = $_CORELANG['TXT_DATA_RECORD_DELETED_SUCCESSFUL'];
			return true;
		}
		return false;
	}    


	
	/**
	* deletes the selected language variables
	*
	* @global    object     $db
	* @return    boolean                                                                             
	*/
	function addLanguage()
	{
		global $_CORELANG, $db;
		if (!empty($_POST['name']) && !empty($_POST['shortName']) && !empty($_POST['charset']))
		{
            $shortName = mysql_escape_string($_POST['shortName']);
            $name = mysql_escape_string($_POST['name']);
            $charset = mysql_escape_string($_POST['charset']);
            
			$db->query("SELECT lang FROM ".DBPREFIX."languages WHERE lang='$shortName'");
			if($db->num_rows()>=1)
			{
				$this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];	
				return false;		
			}
			else
			{
				$db->query("INSERT INTO ".DBPREFIX."languages 
				                    SET lang='$shortName', 
									    name='$name',
									    charset='$charset',
									    is_default='false'");
				
				$newLanguageId = $db->insert_id();												  
				$db->query("SELECT id FROM ".DBPREFIX."languages WHERE is_default='true' LIMIT 1");
				while($db->next_record())
				{
					$defaultLanguageId=$db->f('id');
				}
				$db->query("SELECT varid,content 
				              FROM ".DBPREFIX."language_variable_content 
				             WHERE lang_id=$defaultLanguageId");
				
				while($db->next_record())
				{
					$arrContent[$db->f('varid')]=stripslashes($db->f('content'));
				}			
				foreach ($arrContent as $key => $content) 
				{
					$db->query("INSERT INTO ".DBPREFIX."language_variable_content 
					                    SET varid=$key, 
					                        content='".addslashes($content)."',
					                        lang_id=$newLanguageId, 
					                        status=0");
				}
				$this->statusMessage = $_CORELANG['TXT_NEW_LANGUAGE_ADDED_SUCCESSFUL'];
				return true;												
			}
        }
	}	

	
	
    
	/**
	* Gets the language add variable page
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     parsed content                                                                             
	*/
	function addUpdateVariable()
	{
		global $_CORELANG, $db;
		if (!empty($_POST['submit']) AND !empty($_POST['name']))
		{
			$name = mysql_escape_string($_POST['name']);
			$adminzone = intval($_POST['backend']);
			$website = intval($_POST['frontend']);
			$moduleId = intval($_POST['moduleId']);

			// Add new variable
			if (empty($_POST['id']))
			{
				$db->query("SELECT name 
				              FROM ".DBPREFIX."language_variable_names 
				             WHERE name = '$name'
				               AND module_id =$moduleId");
				
				if ($db->num_rows()>=1)
				{
					$this->statusMessage= $_CORELANG['TXT_LANGUAGE_VARIABLE_ALREADY_EXIST'];
					return false;
				}
				else
				{
					$db->query("INSERT INTO ".DBPREFIX."language_variable_names 
					                   SET name='$name', 
					                       module_id='$moduleId', 
					                       backend='$adminzone',
					                       frontend='$website'");
					
	                $varId = $db->insert_id();

					foreach ($_POST['content'] as $langId => $content) 
					{
						$status = intval($_POST['status'][$langId]);
						$db->query("INSERT INTO ".DBPREFIX."language_variable_content 
						                    SET varid=$varId, 
						                        content='".addslashes($content)."',
						                        status=$status, 
						                        lang_id=$langId");
					}
					$this->statusMessage= $_CORELANG['TXT_LANGUAGE_VARIABLE_ADDED_SUCCESSFUL'];
					if(isset($_POST['writeFiles']) && !empty($_POST['writeFiles'])){
						$this->createFiles();
					}
					return true;
				}
	        }
			// Update variable
			else
			{
				// Edit not add
				$id = intval($_POST['id']);
				
				$db->query("UPDATE ".DBPREFIX."language_variable_names 
				               SET name='$name',
				                   module_id='$moduleId',
				                   backend='$adminzone',
				                   frontend='$website' 
				             WHERE id=$id");
				
				foreach ($_POST['content'] as $langId => $content) 
				{
					$content=addslashes($content);
					$status = intval($_POST['status'][$langId]);
					
				    $db->query("UPDATE ".DBPREFIX."language_variable_content 
				                   SET content='$content', 
				                       status='$status' 
				                 WHERE varid=$id 
				                   AND lang_id=$langId");
				}
				$this->statusMessage = $_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
				if(isset($_POST['writeFiles']) && !empty($_POST['writeFiles'])){
					$this->createFiles();
				}
				return true;
			}
		}
		return false;
	}
	    
    
    
    
    
	
	/**
	* Gets the language add/mod variable page
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     parsed content                                                                             
	*/
	function modifyVariables()
	{
		global $db, $_CORELANG;
		
		$variableName = "";
		$variableId = "";
		$variableModule = "";

	    $this->_objTpl->loadTemplateFile('language_mod.html',true,true);
	    $this->pageTitle = $_CORELANG['TXT_ADD_LANGUAGE_VARIABLES'];

	    $this->_objTpl->setVariable(array(
	        'TXT_NAME'                   => $_CORELANG['TXT_NAME'],
	        'TXT_VALUE_CONTROL_LANGUAGE' => $_CORELANG['TXT_VALUE_CONTROL_LANGUAGE'],
	        'TXT_MODULE'                 => $_CORELANG['TXT_MODULE'],
	        'TXT_SELECT_MODULE'          => $_CORELANG['TXT_SELECT_MODULE'],
	        'TXT_STORE'                  => $_CORELANG['TXT_STORE'],
	        'TXT_WEB_PAGES'              => $_CORELANG['TXT_WEB_PAGES'],
	        'TXT_ADMINISTRATION_PAGES'   => $_CORELANG['TXT_ADMINISTRATION_PAGES'],
	        'TXT_APPLICATION_RANGE'      => $_CORELANG['TXT_APPLICATION_RANGE'],
	        'TXT_LANGUAGE_NAME_REQUIRED' => $_CORELANG['TXT_LANGUAGE_NAME_REQUIRED'],	
	        'TXT_APPLICATION_RANGE_REQUIRED'  => $_CORELANG['TXT_APPLICATION_RANGE_REQUIRED'],
	        'TXT_WRITE_VARIABLES_TO_FILES' => $_CORELANG['TXT_WRITE_VARIABLES_TO_FILES']
	    ));

		$db->query("SELECT id,name,lang FROM ".DBPREFIX."languages ORDER BY id");
		while($db->next_record())
		{
	        $arrayLang[$db->f('id')]=$db->f('name')." (".$db->f('lang').")";	
		}
		if(isset($_GET['id']))
		//---------------------------
		// mod status
		//---------------------------	
		{
		    $this->_objTpl->setVariable("TXT_LANGUAGE_SETTING", $_CORELANG['TXT_MOD_LANGUAGE_VARIABLES']);
		    $variableId = intval($_GET['id']);
			$db->query("SELECT id,
			                   name,
			                   module_id,
			                   backend,
			                   frontend 
			              FROM ".DBPREFIX."language_variable_names 
			              WHERE id = $variableId LIMIT 1");	
			
			while($db->next_record())
			{
				$variableName=$db->f('name');	
				$variableAdminzone=$db->f('backend');
				$variableWebsite=$db->f('frontend');
				$variableModule=$db->f('module_id');
			}
			$db->query("SELECT content, 
			                   lang_id, 
			                   status 
			              FROM ".DBPREFIX."language_variable_content 
			             WHERE varid = $variableId
			          ORDER BY varid");
			
			while($db->next_record())
			{
				$variableContent[$db->f('lang_id')]=$db->f('content');
				$variableStatus[$db->f('lang_id')]=$db->f('status');						
			}
			foreach ($arrayLang as $k => $v) 
			{
				$checked="";
				if($variableStatus[$k]==1)
				{
				    $checked="checked";
				}
				//echo htmlspecialchars($variableContent[$k]);
				$content=htmlspecialchars(stripslashes($variableContent[$k]));
				$strLangInputFields .="<input type='text' name='content[$k]' size=80 value=\"".$content."\" maxlength='250'>&nbsp;\n
									   <input type='checkbox' name='status[$k]' value='1' $checked>&nbsp;$v<br>\n";
			}			
		}
		else
		//---------------------------
		// Add status
		//---------------------------
		{
			$this->_objTpl->setVariable("TXT_LANGUAGE_SETTING", $_CORELANG['TXT_ADD_LANGUAGE_VARIABLES']);
			foreach ($arrayLang as $k => $v) 
			{
				$strLangInputFields .="<input type='text' name='content[$k]' size=80 value='' maxlength='250'>&nbsp;\n
									   <input type='checkbox' name='status[$k]' value='1' checked>&nbsp;$v<br>\n";
			}	
		}
		
		if($variableAdminzone==1)
		{
			$variableAdminzone="checked";
		}
		else 
		{
			$variableAdminzone="";
		}
		if($variableWebsite==1)
		{
			$variableWebsite="checked";
		}
		else 
		{
			$variableWebsite="";
		}

		$this->_objTpl->setVariable("LANGUAGE_VARIABLE_NAME", $variableName);										
		$this->_objTpl->setVariable("LANGUAGE_INPUT_FIELDS",$strLangInputFields);
		$this->_objTpl->setVariable("LANGUAGE_ADMINZONE",$variableAdminzone);
		$this->_objTpl->setVariable("LANGUAGE_WEBSITE",$variableWebsite);		
		$this->_objTpl->setVariable("LANGUAGE_MODULES_MENU", $this->getSearchOptionMenu("modules",$variableModule));										
		$this->_objTpl->setVariable("LANGUAGE_VARIABLE_ID",$variableId);
	}
    

	
	/**
	* Get the language variable default page
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     parsed content                                                                             
	*/
	function listVariables()
	{
		global $_CORELANG, $db;		
		
		//init variables
		$q_term = ""; 
		$q_lang = ""; 
		$q_module = "";
		$q_status = "";
		$q_zone = "";
		$i=0;
		$zoneMenu ="";
	    $selected1="";
	    $selected2="";
	    $selected3="";	
	    
			    
	    $this->_objTpl->loadTemplateFile('language_list.html',true,true); 
	    $this->pageTitle = $_CORELANG['TXT_VARIABLE_LIST'];
	    	    
		if(!isset($_SESSION['lang']['term'])) $_SESSION['lang']['term']="";
		if(!isset($_SESSION['lang']['langId'])) $_SESSION['lang']['langId']="";
		if(!isset($_SESSION['lang']['status'])) $_SESSION['lang']['status']="";
		if(!isset($_SESSION['lang']['zone'])) $_SESSION['lang']['zone']="both";	 
		
		if(isset($_POST['term']))
		{
			$_SESSION['lang']['term']=mysql_escape_string($_POST['term']);
		}
		if(isset($_POST['lang']))
		{
			$_SESSION['lang']['langId']=intval($_POST['lang']);
		}		
		if(isset($_POST['status']))
		{
			$_SESSION['lang']['status']=$_POST['status'];
		}
		if(isset($_POST['zone']))
		{
			$_SESSION['lang']['zone']=intval($_POST['zone']);
		}					
		
		$term = $_SESSION['lang']['term'];
		$lang = $_SESSION['lang']['langId'];
		$status = $_SESSION['lang']['status'];
		$zone = $_SESSION['lang']['zone'];

	    if($zone=="frontend")
		{	
			$selected1="selected";	
		}
		elseif($zone == "backend") 
		{
			$selected2="selected";				
		}
		elseif($zone == "both" OR $zone == "") 
		{
			$zone = "both";
			$selected3="selected";				
		}
		$zoneMenu .="<option value='both' ".$selected3.">".$_CORELANG['TXT_SECTION']."</option>\n";		
		$zoneMenu .="<option value='frontend' ".$selected1.">".$_CORELANG['TXT_WEB_PAGES']."</option>\n";		
		$zoneMenu .="<option value='backend' ".$selected2.">".$_CORELANG['TXT_ADMINISTRATION_PAGES']."</option>\n";		
		$this->_objTpl->setVariable("LANGUAGE_ZONE_MENU", $zoneMenu);
	
	    //Begin language varibales
	    $this->_objTpl->setVariable(array(
	        'TXT_CONFIRM_DELETE_DATA'                    => $_CORELANG['TXT_CONFIRM_DELETE_DATA'],
	        'TXT_ACTION_IS_IRREVERSIBLE'                 => $_CORELANG['TXT_ACTION_IS_IRREVERSIBLE'],
	        'TXT_ATTENTION_SYSTEM_FUNCTIONALITY_AT_RISK' => $_CORELANG['TXT_ATTENTION_SYSTEM_FUNCTIONALITY_AT_RISK'],
	        'TXT_MODULE'                                 => $_CORELANG['TXT_MODULE'],
	        'TXT_LANGUAGE'                               => $_CORELANG['TXT_LANGUAGE'],
	        'TXT_STATUS'                                 => $_CORELANG['TXT_STATUS'],
	        'TXT_CONTROLLED'                             => $_CORELANG['TXT_CONTROLLED'],
	        'TXT_OPEN_ISSUE'                             => $_CORELANG['TXT_OPEN_ISSUE'],
	        'TXT_LANGUAGE_DEPENDANT_SYSTEM_VARIABLES'    => $_CORELANG['TXT_LANGUAGE_DEPENDANT_SYSTEM_VARIABLES'],
	        'TXT_FOUND'                                  => $_CORELANG['TXT_FOUND'],
	        'TXT_NAME'                                   => $_CORELANG['TXT_NAME'],
	        'TXT_VALUE'                                  => $_CORELANG['TXT_VALUE'],
	        'TXT_DISPLAY'                                => $_CORELANG['TXT_DISPLAY'],
	        'TXT_ADMIN'                                  => $_CORELANG['TXT_ADMINISTRATION_PAGES'],
	        'TXT_PUBLIC'                                 => $_CORELANG['TXT_WEB_PAGES'],
	        'TXT_EXPORT_VARIABLES_TO_FILES'				 => $_CORELANG['TXT_EXPORT_VARIABLES_TO_FILES'] //not available 
	    ));
	    //End language variables
		if(!empty($term))
		{
			if (empty($lang))
			{
		        $db->query("SELECT id FROM ".DBPREFIX."languages WHERE is_default='true'");	
				while($db->next_record())
				{
			        $q_lang = "AND con.lang_id=".intval($db->f('id'))." ";			    		
				}
			}
			else
			{
		        $q_lang = "AND con.lang_id=".intval($lang)." "; 		
			}
			
			if ($zone <> "both") 
			{
			    $q_zone = "AND nam.$zone=1";
			} 
			
			if($status=="0" || $status=="1")
			{
			    $q_status = "AND con.status=".intval($status)." ";
			}

			$q = "SELECT con.content AS content, 
			             con.status AS status,
			             con.lang_id AS lang, 
			             nam.name AS name, 
			             nam.id AS varid, 
			             modu.name AS module,
			             nam.backend AS backend,
			             nam.frontend AS frontend 
			      FROM ".DBPREFIX."language_variable_content AS con, 
					   ".DBPREFIX."language_variable_names AS nam,
					   ".DBPREFIX."modules AS modu
				  WHERE modu.id=nam.module_id
			        AND con.varid=nam.id
			        AND (nam.name LIKE '%$term%' OR con.content LIKE '%$term%') ".$q_zone.$q_lang.$q_status."  	          
				  ORDER BY nam.id";				
	
		
			$db->query($q);
			$numRows = $db->num_rows();		
			$this->_objTpl->setCurrentBlock('languageRow');		
			while($db->next_record())
			{
				if (($i % 2) == 0) {$class="row1";} else {$class="row2";}
				
				if (intval($db->f('backend'))==1)
				{
					$this->_objTpl->setVariable("LANGUAGE_ADMIN","<img alt='' src='images/icons/check.gif'>");
				}
				if (intval($db->f('frontend'))==1)
				{
					$this->_objTpl->setVariable("LANGUAGE_WEBSITE","<img alt='' src='images/icons/check.gif'>");
				}
				$this->_objTpl->setVariable("LANGUAGE_ROWCLASS",$class);					
				$this->_objTpl->setVariable("LANGUAGE_ID",$db->f('varid'));
				$this->_objTpl->setVariable("LANGUAGE_VARIABLENAME",$db->f('name'));
				$this->_objTpl->setVariable("LANGUAGE_CONTENT",htmlspecialchars(stripslashes($db->f('content'))));
				$this->_objTpl->setVariable("LANGUAGE_MODULE",$db->f('module'));
				$this->_objTpl->setVariable("LANGUAGE_LANG",$this->arrLang[$db->f('lang')]); 
				if(intval($db->f('status')==1)) // not carefully checked variable
				{
				    $langStatus ="<img alt='' src=\"images/icons/led_green.gif\">";		
				}
				else // checked variable
				{
				    $langStatus ="<img alt='' src=\"images/icons/led_red.gif\">";
				}
				$this->_objTpl->setVariable("LANGUAGE_STATUS",$langStatus);
				$this->_objTpl->parse('languageRow');
				$i++;
			}
		}
		else 
		{
		    $this->_objTpl->hideBlock('languageSearchTable');	
		}
		$this->_objTpl->setVariable("LANGUAGE_STATS",$numRows);
		$this->_objTpl->setVariable("LANGUAGE_MODULES_MENU", $this->getSearchOptionMenu("modules",$module));					
		$this->_objTpl->setVariable("LANGUAGE_LANG_MENU",$this->getSearchOptionMenu("languages",$lang));					
	    $this->_objTpl->setVariable("LANGUAGE_SEARCHTERM", $term);
	}
	
	
	
	
    
    

	/**
	* get the language list page
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     parsed content                                                                             
	*/
	function languageOverview()
	{
		global $_CORELANG, $db;
	    // init vars
	    $i=0;
	    
		$this->_objTpl->loadTemplateFile('language_langlist.html',true,true); 
		$this->pageTitle = $_CORELANG['TXT_LANGUAGE_LIST']; 	    
	    
	    //begin language variables			   
	    $this->_objTpl->setVariable(array(
		    'TXT_ADD_NEW_LANGUAGE'	         => $_CORELANG['TXT_ADD_NEW_LANGUAGE'],
		    'TXT_NAME'	                     => $_CORELANG['TXT_NAME'],
		    'TXT_SHORT_NAME'                 => $_CORELANG['TXT_SHORT_NAME'],
		    'TXT_CHARSET'                    => $_CORELANG['TXT_CHARSET'],
		    'TXT_ADD'  	                     => $_CORELANG['TXT_ADD'],
		    'TXT_LANGUAGE_LIST'              => $_CORELANG['TXT_LANGUAGE_LIST'],
		    'TXT_ID'                         => $_CORELANG['TXT_ID'],	           
		    'TXT_SHORT_FORM'                 => $_CORELANG['TXT_SHORT_FORM'],
		    'TXT_STANDARD_LANGUAGE'          => $_CORELANG['TXT_STANDARD_LANGUAGE'],	            
		    'TXT_ACTION'                     => $_CORELANG['TXT_ACTION'], 
		    'TXT_ACCEPT_CHANGES'             => $_CORELANG['TXT_ACCEPT_CHANGES'], 
		    'TXT_REMARK'                     => $_CORELANG['TXT_REMARK'],     
		    'TXT_ADD_DELETE_LANGUAGE_REMARK' => $_CORELANG['TXT_ADD_DELETE_LANGUAGE_REMARK'], 
		    'TXT_CONFIRM_DELETE_DATA'        => $_CORELANG['TXT_CONFIRM_DELETE_DATA'],    
		    'TXT_ACTION_IS_IRREVERSIBLE'     => $_CORELANG['TXT_ACTION_IS_IRREVERSIBLE'],
		    'TXT_SEARCH_FILTER'              => $_CORELANG['txtSearchFilter'], //not available
		    'TXT_VALUE'                      => $_CORELANG['TXT_VALUE'],
		    'TXT_MODULE'                     => $_CORELANG['TXT_MODULE'],
		    'TXT_LANGUAGE'                   => $_CORELANG['TXT_LANGUAGE'],
		    'TXT_STATUS'                     => $_CORELANG['TXT_STATUS'],
		    'TXT_VIEW'                       => $_CORELANG['TXT_VIEW'],
		    'TXT_CONTROLLED'                 => $_CORELANG['TXT_CONTROLLED'],
		    'TXT_OPEN_ISSUE'                 => $_CORELANG['TXT_OPEN_ISSUE'],  
		    'TXT_SHORT_NAME'                 => $_CORELANG['TXT_SHORT_NAME'],  
		    'TXT_LANGUAGE_DEPENDANT_SYSTEM_VARIABLES'=> $_CORELANG['TXT_LANGUAGE_DEPENDANT_SYSTEM_VARIABLES'],
		    'TXT_USAGE_OF_LANGUAGE_VARIABLE' => $_CORELANG['txtUsageOfLanguageVariable'], //not available
		    'TXT_ADMINISTRATION_PAGES'       => $_CORELANG['TXT_ADMINISTRATION_PAGES'],
		    'TXT_WEB_PAGES'                  => $_CORELANG['TXT_WEB_PAGES'],
		    'TXT_SECTION'                    => $_CORELANG['TXT_SECTION'],
		    'TXT_DEFAULT_LANGUAGE'           => $_CORELANG['TXT_STANDARD_LANGUAGE'],
		));
	    //end language variables	    
		
	    if($this->hideVariables == true){
	    	$this->_objTpl->setGlobalVariable(array('LANGUAGE_ADMIN_STYLE' => 'display: none'));
	    } else {
	    	$this->_objTpl->setGlobalVariable(array('LANGUAGE_ADMIN_STYLE' => 'display: block'));
	    }
	    
	    
		$this->_objTpl->setCurrentBlock('languageRow');		
		$db->query("SELECT * FROM ".DBPREFIX."languages ORDER BY id");
		while($db->next_record())
		{
			$checked = "";		
			if($db->f('is_default')=="true")
			{
			  $checked = "checked";
			}
			$status ="<input type='radio' name='langDefaultStatus' value='".$db->f('id')."' $checked>";
	
			$checked = "";
			if($db->f('frontend')==1)
			{
			  $checked = "checked";
			}
			$activeStatus ="<input type='checkbox' name='langActiveStatus[".$db->f('id')."]' value='1' $checked>";
			$checked = "";				
			if($db->f('backend')==1)
			{
			  $checked = "checked";
			}
			$adminStatus ="<input type='checkbox' name='langAdminStatus[".$db->f('id')."]' value='1' $checked>";
			
			($i % 2) ? $class  = 'row1' : $class  = 'row2';	
			$this->_objTpl->setVariable("LANGUAGE_ROWCLASS",$class);					
			$this->_objTpl->setVariable("LANGUAGE_LANG_ID",$db->f('id'));
			$this->_objTpl->setVariable("LANGUAGE_LANG_NAME",$db->f('name'));
			$this->_objTpl->setVariable("LANGUAGE_LANG_SHORTNAME",$db->f('lang'));
			$this->_objTpl->setVariable("LANGUAGE_LANG_CHARSET",$db->f('charset'));
			$this->_objTpl->setVariable("LANGUAGE_LANG_STATUS",$status);
			$this->_objTpl->setVariable("LANGUAGE_ACTIVE_STATUS",$activeStatus);	
			$this->_objTpl->setVariable("LANGUAGE_ADMIN_STATUS",$adminStatus);				
			$this->_objTpl->parse('languageRow');
			$i++;
		}
	}    


	
	/**
	* add and modify language values
	*
	* @global    object     $db
	* @global    string     DBPREFIX
	* @return    string     parsed content                                                                             
	*/ 
	function modifyLanguage()
	{
		global $_CORELANG, $db;
		if (!empty($_POST['submit']) AND ($_POST['addLanguage']=="true"))
		{
			//-----------------------------------------------
			// Add new language with all variables
			//-----------------------------------------------
			if (!empty($_POST['newLangName']) AND !empty($_POST['newLangShortname']))
			{
	            $newLangShortname = $_POST['newLangShortname'];
	            $newLangName = $_POST['newLangName'];
	            $newLangCharset = $_POST['newLangCharset'];
				$db->query("SELECT lang FROM ".DBPREFIX."languages WHERE lang='$newLangShortname'");
				if($db->num_rows()>=1)
				{
					$this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];
					return false;		
				}
				else
				{
					$db->query("INSERT INTO ".DBPREFIX."languages SET lang='$newLangShortname', 
																	   name='$newLangName',
																	   charset='$newLangCharset',
																	   is_default='false'");
					$newLanguageId = $db->insert_id();												  
					if(!empty($newLanguageId))
					{
						$db->query("SELECT id FROM ".DBPREFIX."languages WHERE is_default='true' LIMIT 1");
						while($db->next_record())
						{
							$defaultLanguage=$db->f('id');
						}
						$db->query("SELECT varid,content,module FROM ".DBPREFIX."language_variable_content WHERE 1 AND lang=$defaultLanguage");
						while($db->next_record())
						{
							$arrayLanguageContent[$db->f('varid')]=stripslashes($db->f('content'));
							$arrayLanguageModule[$db->f('varid')]=$db->f('module');
						}			
						foreach ($arrayLanguageContent as $varid => $content) 
						{
							$LanguageModule = $arrayLanguageModule[$varid];
							$db->query("INSERT INTO ".DBPREFIX."language_variable_content SET varid=$varid, content='".addslashes($content)."', module=$LanguageModule, lang=$newLanguageId, status=0");
						}
						$this->statusMessage = $_CORELANG['TXT_NEW_LANGUAGE_ADDED_SUCCESSFUL'];
				        return true;
				    }
					else
					{
						$this->statusMessage = $_CORELANG['TXT_DATABASE_QUERY_ERROR'];
						return false;			
					}												
				}
	        }
		}
	   elseif(!empty($_POST['submit']) AND ( $_POST['modLanguage'] == "true"))
	   {
			//-----------------------------------------------
			// Update languages
			//-----------------------------------------------
			foreach ($_POST['langName'] as $id => $name) 
			{
				$active = 0;
				if( $_POST['langActiveStatus'][$id]==1 )
				{
					$active = 1;
				}			
				$status = "false";
				if($_POST['langDefaultStatus']==$id)
				{
				    $status = "true";
				}
				$adminstatus = 0;
				if($_POST['langAdminStatus'][$id]==1)
				{
					$adminstatus = 1;
				}			
				$db->query("UPDATE ".DBPREFIX."languages SET name='$name', frontend=$active , is_default='$status',backend='$adminstatus' WHERE id=$id");
			}
			$this->statusMessage = $_CORELANG['TXT_DATA_RECORD_UPDATED_SUCCESSFUL'];
			return true;   
	   }
		return false;
	}
	

	
	
	function getSearchOptionMenu($dbTableName, $selectedOption="")
	{
		global $db;
		$strMenu = "";
		if($dbTableName=="languages" OR $dbTableName=="modules")
		{
		    $q = "SELECT * FROM ".DBPREFIX.$dbTableName." WHERE 1 ORDER BY id";
			$db->query($q);
			while($db->next_record())
			{
				$selected = "";
				if($selectedOption==$db->f('id'))
				{
					$selected = "selected";
				}
				if($db->f('id')!=0)
				{
				    $strMenu .="<option value=\"".$db->f('id')."\" $selected>".$db->f('name')."</option>\n"; 
				}
			}
		}
		return $strMenu;
	}
	
	
	
	/**
    * checks if the permissions on the language directory are correct
    *   
	* @return   boolean    
    */
	function checkPermissions()
	{
		if(is_writeable($this->filePath) AND 
		   is_dir($this->filePath))
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
    * createXML: parse out the XML
    *
	* @global	string		$objDb
	* @global	array		$_CORELANG
    */
    function createFiles()
    {
    	global $objDb, $_CORELANG;
    	
    	$arrModules = array();
    	$arrLanguages = array();
    	$arrModulesPath = array();
    	$arrModuleVariables = array();
    	$arrErrorFiles = array();
    	
    	$strHeader = "/**\n* ASTALAVISTA secure CMS\n* generated date ".date('r',time())."\n**/\n\n";
    	
    	// generate the arrays $arrModulesPath and $arrModules
		$query = "SELECT id, name, is_core FROM ".DBPREFIX."modules";
		if($objDb->query($query)){
			while ($objDb->next_record()) {
				if(strlen($objDb->f('name'))>0){
					switch($objDb->f('name')){
						case 'core':
							$arrModulesPath[$objDb->f('name')] = ASCMS_DOCUMENT_ROOT;
							break;
						default:
						$arrModulesPath[$objDb->f('name')] = ($objDb->f('is_core') == 1 ? ASCMS_CORE_MODULE_PATH : ASCMS_MODULE_PATH).'/'.$objDb->f('name');
					}
					$arrModulesPath[$objDb->f('name')] .= '/lang/';
				}
				$arrModules[$objDb->f('id')] = array(
    												'id'	=>	$objDb->f('id'),
    												'name'	=>	$objDb->f('name')
    												);
			}
		}
		
    	// get language array
    	$query = "SELECT id, lang FROM ".DBPREFIX."languages";
    	if($objDb->query($query)){
    		while ($objDb->next_record()) {
    			$arrLanguages[$objDb->f('id')] = array(
    													'id'	=> $objDb->f('id'),
    													'lang'	=> $objDb->f('lang')
    													);
    		}
    	}
    	
    	// get language variables
    	$query = "SELECT vn.name, vn.module_id, vn.backend, vn.frontend, vc.content, vc.lang_id
    				FROM ".DBPREFIX."language_variable_names AS vn,
    					 ".DBPREFIX."language_variable_content AS vc
				   WHERE vn.id=vc.varid";
    	
    	// generate array $arrModuleVariables including the variables
    	if($objDb->query($query)){
    		while ($objDb->next_record()) {
				if($objDb->f('module_id') == 0){
					$moduleId = 1;
				} else {
					$moduleId = $objDb->f('module_id');
				}
				if($objDb->f('backend') == 1){
					$arrModuleVariables[$moduleId][$objDb->f('lang_id')]['backend'][$objDb->f('name')] = stripslashes($objDb->f('content'));
				}
				if($objDb->f('frontend') == 1){
					$arrModuleVariables[$moduleId][$objDb->f('lang_id')]['frontend'][$objDb->f('name')] = stripslashes($objDb->f('content'));
				}
    		}
    	}
    	
    	// generate array $arrOutput with the data to write into files
    	foreach ($arrModuleVariables as $moduleId => $arrLanguageVariables){
    		foreach ($arrLanguageVariables as $langId => $arrModeVariables){
    			$filePath = $arrModulesPath[$arrModules[$moduleId]['name']].$arrLanguages[$langId]['lang'].'/';
    			foreach ($arrModeVariables as $strMode => $arrVariables){
    				$fileName = $strMode.".php";
    				foreach ($arrVariables as $strName => $strContent){
    					$arrOutput[$filePath.$fileName] .= "$"."_ARRAYLANG['".$strName."'] = \"".$strContent."\";\n";
    				}
    			}
    		}
    	}
    	unset($arrModuleVariables);
    	
    	// write variables to files
    	foreach ($arrOutput as $file => $strOutput){
    		$fileHandle = @fopen($file,"w");
			if($fileHandle)
			{
				@fwrite($fileHandle,"<?php\n".$strHeader.$strOutput."?>");
				@fclose($fileHandle);
			} else {
				array_push($arrErrorFiles,$file);
			}
    	}
    	
    	unset($arrOutput);
    	if(count($arrErrorFiles)>0){
    		foreach ($arrErrorFiles as $file){
    			$this->statusMessage .= "<br />".$_CORELANG['TXT_COULD_NOT_WRITE_TO_FILE']." (".$file.")";
    		}
    	} else {
    		$this->statusMessage .= "<br />".$_CORELANG['TXT_SUCCESSFULLY_EXPORTED_TO_FILES'];
    	}
    }
}
?>