<?
/**
* @var const
* @desc Standard-Fehlermeldung fr ein nicht ausgeflltes Pflichtfeld
*/
define('ERROR_MESSAGE', 'ungltige Eingabe!');

/**
* @var const
* @desc HTML-Code, welcher die Legende fr Pflichtfelder generiert
*/
define('LEGEND_REQUIRED_FIELD', '<small>(*) Pflichtfeld</small>');

/**
* @var const
* @desc HTML-Code, welcher Elemente abschliet
*/
define('POST_ELEMENT', '</td></tr>');

/**
* @var const
* @desc HTML-Code, welcher ein Formular abschliet
*/
define('POST_FORM', '</td></tr></table></td></tr></table>');


/**
* @var const
* @desc HTML-Code, welcher Elementen vorangeht
*/
define('PRE_ELEMENT', '<tr><td valign="top">');

/**
* @var const
* @desc HTML-Code, welcher einem Formular vorangeht.
*/
define('PRE_FORM', '<table width="300" cellspacing="0" cellpadding="0" align="center">
                      <tr>
                        <td>
                          <table>
                            <tr>
                              <td>');

/**
* @var const
* @desc HTML-Code mit berschrieft, welcher einem Formular vorangeht. Enthlt {headline} als Platzhalter fr eine berschrift
*/
define('PRE_FORM_HEADLINE', '<table width="300" cellspacing="0" cellpadding="0">
                               <tr>
                                 <td>
                                   <h1>{headline}</h1>
                                 </td>
                               </tr>
                               <tr>
                                 <td>
                                   <table>
                                     <tr>
                                       <td>');

/**
* @var const
* @desc HTML-Code, welcher Pflichtfelder kennzeichnet
*/
define('REQUIRED_FIELD', '<sup>*</sup>');

/**
* @var const
* @desc HTML-Code, welcher ein Element und seine Beschreibung trennt
*/
define('SEPARATE_ELEMENT', '</td><td valign="top">');

/**
* @var const
* @desc HTML-Code, welcher ein Trennelement erzeugt
*/
define('SEPARATOR', '<tr>
                       <td colspan="2">
                         <b>{text}</b><br>
                         <table width="100%" cellspacing="0" cellpadding="0">
                           <tr hight="1" bgcolor="{color}">
                             <td></td>
                           </tr>
                         </table>
                       </td>
                     </tr>');

/**
* @var const
* @desc HTML-Code, welcher unter nicht ausgefllten Pflichtfeldern
angezeigt wird, wenn das Formular abgeschickt wird
*/
define('UNFILLED_REQUIRED_FIELD', '<br><small><font color="#FF0000">{errorMessage}</font></small>');

/**
* class formElement (bedingt class formWizard)
*
* Diese Klasse und alle Kinderklassen sind unter der ffentlichen GNU Lizenz (GPL)
* verffentlicht Weiterverffentlichungen (auch in vernderter Form) sind fr jedes
* Medium usdrcklich erlaubt, sofern diese Copyright-Klauseln bernommen werden.
* Der Autor ist neugierig, in welchen Projekten seine Klasse zum Einsatz kommt,
* und freut sich ber jede Email, welche ihn darauf hinweist.
*
* @version 1.3.0
* @author Andreas Demmer <mail@andreas-demmer.de>
* @copyright GNU-LGPL
*/

class formElement {
    
    /**
    * @var bool
    * @desc Host-Formular darf bereits gleichnamige Elemente enhalten
    */
    var $allowDuplicateNames = FALSE;

    /**
    * @var mixed
    * @desc CallBack
    */
    var $callBack = NULL;
    
    /**
    * @var bool
    * @desc Beschreibungstext wird nicht umgebrochen
    */
    var $doNotWrapDescription = FALSE;
    
    /**
    * @var bool
    * @desc nicht ausgeflltes Pflichtfeld
    */
    var $error = FALSE;
    
    /**
    * @var string
    * @desc alternative Fehlerbeschreibung
    */
    var $errorMessage = FALSE;
    
    /**
    * @var bool
    * @desc JavaScript-Fokus auf dieses Formular-Objekt legen
    */
    var $focus = FALSE;
        
    /**
    * @var object
    * @desc Host-Formular Objekt
    */
    var $form = FALSE;
    
    /**
    * @var string
    * @desc HTML-Code des Elements
    */
    var $html = NULL;    
      
    /**
    * @var string
    * @desc Javascripts des Elements
    */
    var $javascripts = NULL;    
    
    /**
    * @var bool
    * @desc markieren, falls Pflichtfeld
    */
    var $markIfRequired = TRUE;
    
    /**
    * @var string
    * @desc Name des Elements
    */
    var $name = NULL;
    
    /**
    * @var string
    * @desc regulrer Ausdruck zum validieren des Feldinhalts
    */
    var $regularExpression = FALSE;
        
    /**
    * @var string
    * @desc Element ist ein Pflichtfeld
    */
    var $required = FALSE;
    
    /**
    * @var string
    * @desc Beschreibung des Elements
    */
    var $text = NULL;
    
    /**
    * @var string
    * @desc Value des Elements
    */
    var $value = NULL;
    
    /**
    * @access public
    * @return void
    * @param allow bool
    * @desc erlaubt dem Host-Formular mehrere Elemente dieses Names zu enthalten,
    *       z.B. Radio-Buttons oder Array-Bezeichnungen als Name
    */
    function allowDuplicateNames($allow) {
       $this->allowDuplicateNames = $allow;
    }
        
    /**
    * @access private
    * @return bool
    * @desc validiert das Feld auf inhalt oder einen benutzerdefinierten
    *       regul. Ausdruck oder mit Hilfe eines CallBacks
    */
    function checkValue() {
        if($this->value) {
            if($this->regularExpression) {
                if(eregi($this->regularExpression, $this->value)) {
                    $returnValue = TRUE;
                } else {
                    $returnValue = FALSE;
                    $this->error = TRUE;
                }
            } else if ($this->callBack) {
                if (call_user_func($this->callBack, $this->value)) {
                    $returnValue = TRUE;
                } else {
                    $returnValue = FALSE;
                    $this->error = TRUE;
                }
            } else {
                $returnValue = TRUE;
            }
        } elseif($this->required) {
            $returnValue = FALSE;
            $this->error = TRUE;
        } else {
            $returnValue = FALSE;
        }
        
        return $returnValue;
    }
    
    /**
    * @access public
    * @return void
    * @param wrap bool
    * @desc legt fest, ob die Beschreibung des Elements umgebrochen werden darf
    */
    function doNotWrapDescription($wrap) {
        $this->doNotWrapDescription = $wrap;
    }
        
    /**
    * @access public
    * @return bool
    * @desc liefert zurck, ob ein Formular mehrere Elemente dieses Names enhalten darf,
    *       z.B. bei Radio-Buttons oder Arraybezeichnungen als Namen
    */
    function duplicateNamesAllowed() {
        return $this->allowDuplicateNames;
    }
    
    /**
    * @access private
    * @return bool
    * @desc liefert zurck, ob das Feld ein Pflichtfeld ist, welches nicht ausgefllt wurde
    */
    function errorOccured() {
        return $this->error;
    }
    
    /**
    * @access private
    * @return string
    * @desc liefert den HTML-Code dieses Elements
    */
    function fetch() {
        return $this->html;
    }
    
    /**
    * @access private
    * @return void
    * @desc Konstruktor
    */
    function formElement($form, $name) {
        $this->form = $form;
        $this->name = $name;
        
        if($this->form->isSubmitted()) {
            
            if($_REQUEST[$this->name]) {
                $this->setValue($_REQUEST[$this->name]);
            }
        }
    }
    
    /**
    * @access private
    * @return string
    * @desc liefert den Namen des Elements zurck
    */
    function getName() {
        return $this->name;
    }
        
    /**
    * @access public
    * @return void
    * @param mark bool
    * @desc falls das Element ein Pflichtfeld ist, wird ein Hinweis angezeigt
    */
    function markIfRequired($mark) {
        $this->markIfRequired = $mark;
    }
    
    /**
    * @access public
    * @return void
    * @param $required bool
    * @desc markiert das Element als Pflichtfeld
    */
    function setRequired($required) {
        $this->required = $required;
    }
    
    /**
    * @access public
    * @return bool
    * @desc liefert zurck, ob das Feld ein Pflichtfeld ist
    */
    function isRequired() {
        return $this->required;
    }
       
    /**
    * @access public
    * @return bool
    * @desc liefert zurck, ob das Feld markiert werden soll, wenn es ein Pflichtfeld ist
    */
    function isToBeMarked() {
        return $this->markIfRequired;
    }
            
    /**
    * @access public
    * @return void
    * @param validation string oder eine CallBack-Funktion
    * @desc validiert beim Absenden des Formulars das Feld mit einem
    *       regulren Ausdruck oder ueber eine CallBack-Funktion
    */
    function setCustomValidation($validation) {
        if (is_array($validation) || function_exists($validation)) {
            $this->regularExpression = false;
            $this->callBack = $validation;
        } else {
            $this->regularExpression = $validation;
            $this->callBack = NULL;
        }
    }
        
    /**
    * @access public
    * @return void
    * @param text string
    * @desc setzt den beschreibenden Text eines Formular-Elements
    */
    function setDescription($text) {
        $this->text = $text;
    }
    
    /**
    * @access public
    * @return void
    * @param text string
    * @desc setzt einen alternativen Fehlertext fr das Element
    */
    function setErrorMessage($message) {
        $this->errorMessage = $message;
    }
        
    /**
    * @access public
    * @return void
    * @param focus bool
    * @desc setzt den JavaScript Focus auf dieses Formular-Object
    */
    function setFocus($focus) {
        $this->focus = $focus;
    }
    
    /**
    * @access public
    * @return string
    * @param $elementTag string
    * @desc setzt den Value des Formular-Elements
    */
    function setValue($value) {
        $this->value = $value;
    }
    
    /**
    * @access private
    * @return string
    * @param html string
    * @desc ergnzt das Element in einer Tabellenzeile mit Beschreibung und evt. Fehlermeldung
    */
    function wrap($html) {
        $errorMessage = NULL;
        $requiredField = NULL;
        
        if($this->errorOccured() && $this->form->isSubmitted()) {
            if($this->errorMessage) {
                $errorMessage = $this->errorMessage;
            } else {
                $errorMessage = ERROR_MESSAGE;
            }
            
            $errorMessage = str_replace('{errorMessage}', $errorMessage, UNFILLED_REQUIRED_FIELD);
        }
        
        if($this->required && $this->markIfRequired) {
            $requiredField = REQUIRED_FIELD;
        }
        
        if($this->doNotWrapDescription) {
            $text = str_replace(' ', '&nbsp;', $this->text);
        } else {
            $text = $this->text;
        }
        
        if($this->focus) {
            $this->javascripts = 'document.forms[\''.$this->form->name.'\'].'.$this->name.'.focus();';
        }
        
        $html = PRE_ELEMENT.$text.$requiredField.SEPARATE_ELEMENT.$html.$errorMessage.POST_ELEMENT;
        return $html;
    }
}

class formCheckbox extends formElement {
    /**
    * @var bool
    * @desc Checkbox aktiviert?
    */
    var $checked = FALSE;
    
    /**
    * @access public
    * @return void
    * @param check bool
    * @desc aktiviert oder deaktiviert die checkbox
    */
    function check($check) {
        if($this->form->isSubmitted()) {
            $this->checked = isset($_REQUEST[$this->name]);
        } else {
            $this->checked = $check;
        }
    }
    
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param checked bool
    * @desc legt eine neue Checkbox $name im Formular $form an, $checked = TRUE falls aktiviert
    */
    function formCheckbox(&$form, $name, $checked = FALSE) {
        parent::formElement($form, $name);
        $this->check($checked);
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        if(!parent::checkValue()) {
            $this->value = 1;
        }
        
        $html = '<input type="checkbox" name="'.$this->name.'" value="'.$this->value.'"';
        
        if($this->checked) {
            $html .= ' checked';
        }
        
        $html .= '>';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formDropdown extends formElement {
    /**
    * @var array
    * @desc Eintrge des Dropdowns
    */
    var $options = array();
    
    /**
    * @var bool
    * @desc Dropdown enthlt einen vorausgewhlten Eintrag
    */
    var $valuePreselected = FALSE;
    
    /**
    * @access public
    * @return bool
    * @param option string
    * @param value string
    * @param preselected bool
    * @desc fgt eine neue Option $option mit dem Wert $value hinzu
    *       $preselected macht ihn zum vorausgewhlen Eintrag
    */
    function addOption($option, $value, $preselected = FALSE) {
        $newOption['option'] = $option;
        $newOption['value'] = $value;
        
        if($preselected && !$this->valuePreselected) {
            $newOption['selected'] = TRUE;
            $this->valuePreselected = TRUE;
            $returnValue = TRUE;
        } else {
            $returnValue = FALSE;
        }
        
        $this->options[] = $newOption;
        
        return $returnValue;
    }
         
    /**
    * @access public
    * @return bool
    * @param options array
    * @desc fgt mehrere neue Optionen auf einmal hinzu
    */
    function addOptions($options) {
        $errorsOccured = FALSE;
        
        foreach($options as $value=>$option) {
            if($this->form->isSubmitted() && $_REQUEST[$this->name] == $value) {
                $preselected = TRUE;
            } else {
                $preselected = FALSE;
            }
            
            $success = $this->addOption($option, $value, $preselected);
            
            if(!$success) {
                $errorsOccured = TRUE;
            }
        }
        
        return $errorsOccured;
    }
        
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @desc legt ein neues Dropdown $name an
    */
    function formDrowdown(&$form, $name) {
        parent::formElement($form, $name);
        
        $this->size = $size;
        $this->maxLength = $maxLength;
    }

    /**
    * @access public
    * @return bool
    * @param option string
    * @desc entfernt die Option $option aus dem Dropdown
    */
    function removeOption($option) {
        $optionExisted = FALSE;
        
        foreach($this->options as $key=>$entry) {
            if($entry['option'] == $option) {
                unset($this->options[$key]);
                
                if($option['selected']) {
                    $this->valuePreselected = FALSE;
                }
                
                $optionExisted = TRUE;
            }
        }
        
        return $optionExisted;
    }
         
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        $html = '<select name="'.$this->name.'">';
        
        foreach($this->options as $key=>$option) {
           
            if($this->value == $option['value']) {
                $selected = 'selected';
            } else {
                $selected = '';
            }
            
            $html .= '<option value="'.$option['value'].'"'.$selected.'>'.$option['option'].'</option>';
        }        
        
        $html .= '</select>';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }        
     
    /**
    * @access public
    * @return void
    * @desc sortiert die Optionen alphabetisch
    */
    function sortOptions() {
        $sortedOptions = array();
        
        foreach($this->options as $key=>$option) {
            $options["$option[option]"] = $key;
        }
        
        ksort($options);
        reset($options);
        
        foreach($options as $option=>$key) {
            $sortedOptions[] = $this->options[$key];
        }
        
        $this->options = $sortedOptions;
    }
}

class formHiddenField extends formElement {
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @desc legt ein neues verstecktes Feld $name an
    */
    function formHiddenField(&$form, $name) {
        parent::formElement($form, $name);
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        $html = '<input type="hidden" name="'.$this->name.'" value="'.$this->value.'">';
        $this->html = $html;
    }
}

class formFileField extends formElement {
    /**
    * @var int
    * @desc Lnge des Datei-Feldes in Buchstaben
    */
    var $size = 0;
    
    /**
    * @var bool
    * @desc max. Eingabelnge in Buchstaben
    */
    var $maxLength = 0;
    
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param size int
    * @param maxLength int
    * @desc legt ein neues Dateiupload-Feld $name an, mit der Lnge $size
    *       und einer maximalen Eingabelnge $maxLength
    */
    function formTextField(&$form, $name, $size = 15, $maxLength = 255) {
        parent::formElement($form, $name);
        
        $this->size = $size;
        $this->maxLength = $maxLength;
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        $html = '<input type="file" name="'.$this->name.'" value="'.$this->value.'" size="'.$this->size.'" maxlength="'.$this->maxLength.'">';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formPasswordField extends formElement {
    /**
    * @var int
    * @desc Lnge des Paswort-Feldes in Buchstaben
    */
    var $size = 0;
    
    /**
    * @var bool
    * @desc max. Eingabelnge in Buchstaben
    */
    var $maxLength = 0;
    
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param size int
    * @param maxLength int
    * @desc legt ein neues Passwort-Textfeld $name an, mit der Lnge $size
    *       und einer maximalen Eingabelnge $maxLength
    */
    function formPasswordField(&$form, $name, $size = 15, $maxLength = 15) {
        parent::formElement($form, $name);
        
        $this->size = $size;
        $this->maxLength = $maxLength;
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        $html = '<input type="password" name="'.$this->name.'" value="'.$this->value.'" size="'.$this->size.'" maxlength="'.$this->maxLength.'">';        
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formRadioButton extends formElement {

    /**
    * @var bool
    * @desc Radio-Button aktivert oder nicht
    */
    var $selected = FALSE;
        
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param activated bool
    * @desc legt ein neues Passwort-Textfeld $name an, mit der Lnge $size
    *       und einer maximalen Eingabelnge $maxLength
    */
    function formRadioButton(&$form, $name, $activated = FALSE) {
        parent::formElement($form, $name);
        
        $this->activated = $activated;
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        if($this->activated || ($this->form->isSubmitted() && $_REQUEST[$this->name] == $this->value)) {
            $checked = 'checked';
        } else {
            $checked = '';
        }
        
        $html = '<input type="radio" name="'.$this->name.'" value="'.$this->value.'" '.$checked.'>';        
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formSubmitButton extends formElement {
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @desc legt einen neuen Submit-Button an
    */
    function formSubmitButton(&$form, $name) {
        parent::formElement($form, $name);
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        $html = '<div align="right"><input type="submit" name="'.$this->name.'" value="'.$this->value.'"></div>';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formSeparator extends formElement {
    /**
    * @var int
    * @desc Hex-Wert oder Alias fr Farbwert des Trennelements 
    */
    var $color = FALSE;
        
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param color string
    * @desc legt ein Trennelement in der Farbe $color an
    */
    function formSeparator(&$form, $name, $color='#000000') {
        parent::formElement($form, $name);
        $this->color = $color;        
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        $html = str_replace('{text}', $this->text, SEPARATOR);   
        $html = str_replace('{color}', $this->color, $html);   
        $this->html = $html;
    }
}

class formTextArea extends formElement {
    /**
    * @var int
    * @desc Lnge der Textarea in Buchstaben
    */
    var $cols = 0;
    
    /**
    * @var bool
    * @desc Hhe der Textarea in Zeilen
    */
    var $rows = 0;
    
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param cols int
    * @param rows int
    * @desc legt eine neue Textarea an mit der Lnge von $cols Zeichen
    *       und der Hhe von $rows Zeilen
    */
    function formTextArea(&$form, $name, $cols = 15, $rows = 5) {
        parent::formElement($form, $name);
        
        $this->cols = $cols;
        $this->rows = $rows;
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        $html = '<textarea name="'.$this->name.'" cols="'.$this->cols.'" rows="'.$this->rows.'">'.$this->value.'</textarea>';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

class formTextField extends formElement {
    /**
    * @var int
    * @desc Lnge des Text-Feldes in Buchstaben
    */
    var $size = 0;
    
    /**
    * @var bool
    * @desc max. Eingabelnge in Buchstaben
    */
    var $maxLength = 0;
    
    /**
    * @access public
    * @return void
    * @param form object
    * @param name string
    * @param size int
    * @param maxLength int
    * @desc legt ein neues Textfeld $name an, mit der Lnge $size
    *       und einer maximalen Eingabelnge $maxLength
    */
    function formTextField(&$form, $name, $size = 15, $maxLength = 15) {
        parent::formElement($form, $name);
        
        $this->size = $size;
        $this->maxLength = $maxLength;
    }
    
    /**
    * @access public
    * @return void
    * @desc generiert den HTML-Code des Elements
    */
    function render() {
        parent::checkValue();
        
        $html = '<input type="text" name="'.$this->name.'" value="'.$this->value.'" size="'.$this->size.'" maxlength="'.$this->maxLength.'">';
        $html = parent::wrap($html);
        
        $this->html = $html;
    }
}

/**
* class formWizard (bedingt class formElement)
*
* Diese Klasse ist unter der ffentlichen GNU Lizenz (GPL) verffentlicht.
* Weiterverffentlichungen (auch in vernderter Form) sind fr jedes Medium
* ausdrcklich erlaubt, sofern diese Copyright-Klauseln bernommen werden.
* Der Autor ist neugierig, in welchen Projekten seine Klasse zum Einsatz kommt,
* und freut sich ber jede Email, welche ihn darauf hinweist.
*
* @version 1.3.0
* @author Andreas Demmer <mail@andreas-demmer.de>
* @copyright GNU-LGPL
*/
class formWizard {
    /**
    * @var string
    * @desc enthlt die Ziel-URL des Formulars
    */
    var $action = '';
    
    /**
    * @var array
    * @desc enthlt alle Formular-Elemente
    */
    var $elements = array();
        
    /**
    * @var array
    * @desc enthlt die Namen aller Formular-Elemente
    */
    var $elementNames = array();
    
    /**
    * @var bool
    * @desc wurde ein Pflichtfeld nicht ausgefllt?
    */
    var $error = FALSE;
    
    /**
    * @var string
    * @desc Beschriftung der Kopfzeile des Formulars
    */
    var $headline = '';
    
    /**
    * @var string
    * @desc HTML-Code des Formulars
    */
    var $html = '';
    
    /**
    * @var bool
    * @desc wurde das Formular schon gerendert?
    */
    var $isRendered = FALSE;
        
    /**
    * @var string
    * @desc JavaScripts am Ende des Formulars
    */
    var $javascripts = NULL;
    
    /**
    * @var bool
    * @desc markiert Pflichtfelder
    */
    var $markRequiredFields = TRUE;
    
    /**
    * @var string
    * @desc enthlt die bertragungs-Methode des Formulars
    */
    var $method = 'POST';
    
    /**
    * @var string
    * @desc enthlt den Namen des Formulars
    */
    var $name = '';
    
    /**
    * @var bool
    * @desc wurde das Formular bereits abgeschickt?
    */
    var $submitted = FALSE;
    
    /**
    * @access public
    * @return bool
    * @param element object
    * @desc fgt dem Formular das Element $element hinzu
    */
    function addElement(&$element) {
        if(!in_array($element->getName(), $this->elementNames) || $element->duplicateNamesAllowed()) {
            $this->elements[] = $element;
            $this->elementNames[] = $element->getName();
            $returnValue = TRUE;
        } else {
            $returnValue = FALSE;
        }
        
        return $returnValue;
    }

    /**
    * @access public
    * @return bool
    * @desc liefert zurck, ob ein Pflichtfeld nicht ausgeflt wurde
    */
    function errorOccured() {
        return $this->error;
    }
    
    /**
    * @access public
    * @return string
    * @desc liefert den HTML-Code des Formulars zurck
    */
    function fetch() {
        if(!$this->isRendered) {
            $this->render();
        }
        
        return $this->html;
    }
    
    /**
    * @access public
    * @return void
    * @param name string
    * @param action string
    * @param method string
    * @param headline string
    * @desc erstellt ein neues Formular $name mit der Action $action
    */
    function formWizard($action, $name = 'form') {
        $this->name = $name;
        $this->action = $action;
        $this->submitted = isset($_REQUEST['__'.$this->name.'_submitted']);
    }
    
    /**
    * @access public
    * @return bool
    * @desc liefert zurck, ob Pflichtfelder markiert werden sollen
    */
    function getMarkRequiredFields() {
        return $this->markRequiredFields;
    }
    
    /**
    * @access private
    * @return bool
    * @desc liefert zurck, ob das Formular bereits abgeschickt wurde
    */
    function isSubmitted() {
        return $this->submitted;
    }
    
    /**
    * @access public
    * @return void
    * @param mark bool
    * @desc legt fest, ob Pflichtfelder markiert werden sollen
    */
    function markRequiredFields($mark) {
        $this->markRequiredFields = $mark;
    }
    
    /**
    * @access public
    * @return bool
    * @param name string
    * @desc dentfernt das Element $name aus dem Formular
    */
    function removeElement($name) {
        if(array_key_exists($name, $this->elements)) {
            unset($this->elements[$name]);
            $returnValue = TRUE;
        } else {
            $returnValue = FALSE;
        }
        
        return $returnValue;
    }
    
    /**
    * @access public
    * @return void
    * @param mark bool
    * @desc erzeugt den HTML-Code des Formulars mit allen Elementen
    */
    function render() {      
        $formContainsRequiredFields = FALSE;
        
        foreach($this->elements as $element) {
            if(!$this->getMarkRequiredFields()) {
                $element->markIfRequired(FALSE);
            }
            
            $element->render();
            
            if($element->errorOccured()) {
                $this->setError(TRUE);
            }
            
            if($element->isRequired()) {
                $formContainsRequiredFields = TRUE;
            }
            
            $this->html .= $element->fetch();
            $this->javascripts .= $element->javascripts;
        }

        $this->html =  str_replace('{headline}', $this->headline, PRE_FORM).
                       '<form name="'.$this->name.'" method="'.$this->method.'" action="'.$this->action.'" enctype="multipart/form-data" style="margin:0px;">
                         <input type="hidden" name="__'.$this->name.'_submitted" value="1">
                         <table>'.$this->html.'</table>
                       </form>'.
                       '<script language="JavaScript">'.$this->javascripts.'</script>';
        
        if($formContainsRequiredFields && $this->markRequiredFields) {
            $this->html .= LEGEND_REQUIRED_FIELD;
        }
        
        $this->html .= POST_FORM;
        $this->isRendered = TRUE;  
    }
    
    /**
    * @access public
    * @return void
    * @param headline string
    * @desc legt eine berschrift fr das Formular fest
    */
    function setHeadline($headline) {
        $this->headline = $headline;
    }
    
    /**
    * @access private
    * @return void
    * @param error bool
    * @desc teilt dem Formular mit, dass ein Fehler aufgetreten ist
    */
    function setError($error) {
        $this->error = $error;
    }
    
    /**
    * @access public
    * @return bool
    * @param method string
    * @desc legt eine Versandmethode fr das Formular fest (POST oder GET)
    */
    function setMethod($method) {
        if(eregi('post') or eregi('get')) {
            $this->method = $method;
            $returnValue = TRUE;
        } else {
            $returnValue = FALSE;
        }
        
        return $returnValue;
    }
}
?>