<?php

/**
* Class Media Manager
*
* @copyright     ASTALAVISTA SECURE CMS - 2005 Astalavista Group GmbH
* @module    	 core
* @modulegroups  media
* @author        Contrexx Dev Team <thun@astalavista.ch>
* @version       1.0
* @access        public
*/

require_once ASCMS_CORE_MODULE_PATH  . '/media/mediaLib.class.php';
require_once ASCMS_FRAMEWORK_PATH . '/Image.class.php';
require_once ASCMS_LIBRARY_PATH . '/FRAMEWORK/File.class.php';


class MediaManager extends MediaLibrary 
{
	var $_objTpl;                          // var for the template object
	var $pageTitle;                        // var for the title of the active page
	var $statusMessage;                    // var for the status message
	
	var $iconPath;                         // icon path constant
	var $iconWebPath;                      // icon webPath constant
	var $arrPaths;                         // array paths
	var $arrWebPaths;                      // array web paths
	
	var $getAct;                           // $_GET['act']
	var $getPath;                          // $_GET['path']
	var $getSort;                          // $_GET['sort']
	var $getFile;                          // $_GET['file']
	var $getData;                          // $_GET['data']
	
	var $chmodFolder       = 0777;         // chmod for folder 0777
	var $chmodFile         = 0644;         // chmod for files  0644
	var $thumbHeight       = 80;           // max height for thumbnail
	var $thumbQuality      = 80;           // max quality for thumbnail
	
	var $docRoot;                          // ASCMS_DOCUMENT_ROOT
	var $path;                             // current path
	var $webPath;                          // current web path
	var $highlightName     = array();      // highlight added name
	var $highlightColor    = '#d8ffca';    // highlight color for added name [#d8ffca]
	var $highlightCCColor  = '#ffe7e7';    // highlight color for cuted or copied media [#ffe7e7]
	
	var $tmpPath           = array();      // dir tree path
	var $tmpPathName       = array();      // dir tree path name
	
	var $_objImage;                        // object from ImageManager class
	
	var $dirLog;                           // Dir Log

    
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */   
    function MediaManager()
    { 
    	$this->__construct();    
    }
    
    
    /**
     * PHP5 constructor
     * @param  string  $template
     * @param  array   $_ARRAYLANG      
     * @access public     
     */
    function __construct()
    {       
		global  $_ARRAYLANG, $_FTPCONFIG, $template;
		
        // sigma template
		$this->_objTpl = &new HTML_Template_Sigma(ASCMS_CORE_MODULE_PATH.'/media/template');
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);				
		
		// directory variables
		$this->iconPath     = ASCMS_MODULE_IMAGE_PATH . '/media/';
		$this->iconWebPath  = ASCMS_MODULE_IMAGE_WEB_PATH . '/media/';
		
		$this->arrPaths     = array(ASCMS_MEDIA1_PATH . '/',
		                            ASCMS_MEDIA2_PATH . '/',
		                            ASCMS_MEDIA3_PATH . '/',
		                            ASCMS_CONTENT_IMAGE_PATH . '/',
		                            ASCMS_THEMES_PATH . '/');
		                            
	    $this->arrWebPaths  = array(ASCMS_MEDIA1_WEB_PATH . '/',
	                                ASCMS_MEDIA2_WEB_PATH . '/',
	                                ASCMS_MEDIA3_WEB_PATH . '/',
	                                ASCMS_CONTENT_IMAGE_WEB_PATH . '/',
	                                ASCMS_THEMES_WEB_PATH . '/'); 
	                                                      	                               	                                

	    // get variables
    	$this->getAct  = (isset($_GET['act'])  and !empty($_GET['act']))  ? trim($_GET['act'])  : '';
    	$this->getPath = (isset($_GET['path']) and !empty($_GET['path'])) ? trim($_GET['path']) : $this->arrWebPaths[0];
    	$this->getFile = (isset($_GET['file']) and !empty($_GET['file'])) ? trim($_GET['file']) : '';
    	$this->getData = (isset($_GET['data']) and !empty($_GET['data'])) ? $_GET['data']       : '';
    	$this->getSort = (isset($_GET['sort']) and !empty($_GET['sort'])) ? trim($_GET['sort']) : 'name_a';
		
    	if($_GET['path'] == '/themes/') {
    		$_SESSION["skins"] = true;
    	}
    	
    	if(!isset($_GET['path'])) {
    		$_SESSION["skins"] = false;
    	}
    	
    	if($_SESSION["skins"] != true) {    	
			// top navigation
		    $template->set_var('CONTENT_NAVIGATION', '
		        <a href="index.php?cmd=media" name="media">' . $_ARRAYLANG['TXT_MEDIA_ARCHIVE'] . ' #1</a>
		        <a href="index.php?cmd=media&amp;path=' . $this->arrWebPaths[1] . '" name="media">' . $_ARRAYLANG['TXT_MEDIA_ARCHIVE'] . ' #2</a>&nbsp;&nbsp;
		        <a href="index.php?cmd=media&amp;path=' . $this->arrWebPaths[2] . '" name="media">' . $_ARRAYLANG['TXT_MEDIA_ARCHIVE'] . ' #3</a>&nbsp;&nbsp;
		        <a href="index.php?cmd=media&amp;path=' . $this->arrWebPaths[3] . '" name="image">' . $_ARRAYLANG['TXT_CONTENT_IMAGE_ADMINISTRATION'] . '</a>&nbsp;&nbsp;
		        <a href="index.php?cmd=media&amp;path=' . $this->arrWebPaths[4] . '" name="image">' . $_ARRAYLANG['TXT_DESIGN_FILES_ADMINISTRATION'] . '</a>&nbsp;&nbsp;
		    ');
    	} else {
    		// Skins navigation
	    	$template->set_var("CONTENT_NAVIGATION",
	                       "<a href='index.php?cmd=skins'>".$_ARRAYLANG['TXT_DESIGN_OVERVIEW']."</a>&nbsp;&nbsp;
	                       <a href='index.php?cmd=skins&amp;act=newDir'>".$_ARRAYLANG['TXT_NEW_DESIGN']."</a>&nbsp;&nbsp;
	                       <a href='index.php?cmd=skins&amp;act=activate'>".$_ARRAYLANG['TXT_ACTIVATE_DESIGN']."</a>&nbsp;&nbsp;
	                       <a href='index.php?cmd=media&path=/themes/'>".$_ARRAYLANG['TXT_DESIGN_FILES_ADMINISTRATION']."</a>&nbsp;&nbsp;
                           <a href='index.php?cmd=skins&amp;act=examples'>".$_ARRAYLANG['TXT_DESIGN_REPLACEMENTS_DIR']."</a>");
    	}
    	
    	$this->docRoot = ASCMS_DOCUMENT_ROOT; // with path offset
    	$this->docRoot = ASCMS_PATH; // without path offset
    	
    	//paths
    	$this->webPath = $this->_pathCheck($this->getPath);
    	$this->path    = $this->docRoot . $this->webPath;

    	(!isset($_SESSION['media']['sort'])) ? $_SESSION['media']['sort'] = 'name_a' : '';
    	$this->_objImage = &new ImageManager();
    }

//---------------------------------------------------------------------------------------------------------------------------
    

    /**
    * Gets the requested methods
    * 
    * @version   1.0       initial version   
    * @global	 array     $_ARRAYLANG,$_CONFIG
    * @return    string    parsed content                                                                               
    */
    
    function getMediaPage()
    {
    	global $_ARRAYLANG, $template;
    	
        switch($this->getAct)
		{
		    case 'sort':
		        $this->_sortingSession();
		        $this->_overviewMedia();
		        break;
		    case 'newDir':
		        $this->_createNewDir($_POST['dirName']);
		        $this->_overviewMedia();
		        break;
		    case 'upload':
		        $this->_uploadMedia();
		        $this->_overviewMedia();
		        break;
		    case 'download':
		        $this->_downloadMedia();
		        //$this->_overviewMedia();
		        break;
		    case 'cut':
		        $this->_cutMedia();
		        $this->_overviewMedia();
		        break;
		    case 'copy':
		        $this->_copyMedia();
		        $this->_overviewMedia();
		        break;
		    case 'paste':
		        $this->_pasteMedia();
		        $this->_overviewMedia();
		        break;
		    case 'delete':
		        $this->_deleteMedia();
		        $this->_overviewMedia();
		        break;
		    case 'edit':
		        $this->_editMedia();
		        break;
		    case 'preview':
		        $this->_previewImage();
		        break;
		    case 'previewSize':
		        $this->_previewImageSize();
		        break;
		    case 'ren':
		        $this->_renMedia();
		        $this->_overviewMedia();
		        break;
		    case 'test':
		        $this->_objImage->loadImage('/home/web/1035231054822938281273/htdocs/media/archive1/beispiel.jpg');
		        $this->_objImage->resizeImage(100, 150, 45);
		        $this->_objImage->showNewImage();
		        break;
			default:
			    $this->_overviewMedia();
		}
		
        $template->set_var("CONTENT_TITLE", $this->pageTitle); 		
		$template->set_var("CONTENT_STATUS_MESSAGE", $this->statusMessage);
		return $this->_objTpl->get(); 
    }
    
//---------------------------------------------------------------------------------------------------------------------------
    
    
    /**
    * Overview Media Data
    *   
    * @global	 array     $_ARRAYLANG
    * @return    string    parsed content                                                                               
    */

    function _overviewMedia()
    {
    	global $_ARRAYLANG;
    	
    	$this->_objTpl->loadTemplateFile('module_media.html', true, true);
    	$this->pageTitle = $_ARRAYLANG['TXT_MEDIA_OVERVIEW'];
    	
    	// cut, copy and paste session
        if(isset($_SESSION['mediaCutFile'])) // cut
        {
            $tmpArray = array();
            foreach($_SESSION['mediaCutFile'][2] as $tmp)
            {
                 if(file_exists($_SESSION['mediaCutFile'][0] . $tmp))
                 {
                     $tmpArray[] = $tmp;
                 }
            }
            
            if(count($tmpArray) > 0)
            {
                $_SESSION['mediaCutFile'][0] = $_SESSION['mediaCutFile'][0];
            	$_SESSION['mediaCutFile'][1] = $_SESSION['mediaCutFile'][1];
                $_SESSION['mediaCutFile'][2] = $tmpArray;
            }
            else
            {
                unset($_SESSION['mediaCutFile']);
            }
        }
        if(isset($_SESSION['mediaCopyFile'])) // copy
        {
            $tmpArray = array();
            foreach($_SESSION['mediaCopyFile'][2] as $tmp)
            {
                 if(file_exists($_SESSION['mediaCopyFile'][0] . $tmp))
                 {
                     $tmpArray[] = $tmp;
                 }
            }
            
            if(count($tmpArray) > 0)
            {
                $_SESSION['mediaCopyFile'][0] = $_SESSION['mediaCopyFile'][0];
                $_SESSION['mediaCopyFile'][1] = $_SESSION['mediaCopyFile'][1];
                $_SESSION['mediaCopyFile'][2] = $tmpArray;
            }
            else
            {
                unset($_SESSION['mediaCopyFile']);
            }
        }
    	
    	// tree navigation
    	for($x = 0; $x < count($this->arrWebPaths); $x++)
        {
            $tmp = $this->arrWebPaths[$x];
            if(substr($this->webPath, 0, strlen($tmp)) == $tmp)
            {
            	$this->_objTpl->setVariable(array(  // navigation #1
            	    'MEDIA_TREE_NAV_MAIN'      => 'http://' . $_SERVER['HTTP_HOST'] . $this->arrWebPaths[$x],
            	    'MEDIA_TREE_NAV_MAIN_HREF' => 'index.php?cmd=media&amp;path=' . $this->arrWebPaths[$x]
            	));
            	
            	if(strlen($this->webPath) != strlen($tmp))
            	{
                	$tmpPath = substr($this->webPath, -(strlen($this->webPath) - strlen($tmp)));
                	$tmpPath = explode('/', $tmpPath);
                	$tmpLink = '';
                	foreach($tmpPath as $path)
                	{
                	    if(!empty($path))
                	    {
                	        $tmpLink .= $path . '/';
                	        $this->_objTpl->setVariable(array(  // navigation #2
                	            'MEDIA_TREE_NAV_DIR'      => $path,
                	            'MEDIA_TREE_NAV_DIR_HREF' => 'index.php?cmd=media&amp;path=' . $this->arrWebPaths[$x] . $tmpLink
                	        ));
                	        $this->_objTpl->parse('mediaTreeNavigation');
                	    }
                	}
            	}
            	break;
            }
        }
    	
    	// media directory tree
    	$i       = 0;
    	$dirTree = $this->_dirTree($this->path);
    	$dirTree = $this->_sortDirTree($dirTree);
    	
    	foreach(array_keys($dirTree) as $key)
    	{
    		if(is_array($dirTree[$key]['icon']))
    		{
    		    for($x = 0; $x < count($dirTree[$key]['icon']); $x++)
		    	{
		    		$fileName = $dirTree[$key]['name'][$x];
		    		
		    		
		    		// colors
		    	    $class = ($i % 2) ? 'row2' : 'row1';
		    	    if(in_array($fileName, $this->highlightName)) // highlight
		    		{
		    		    $class .= '" style="background-color: ' . $this->highlightColor . ';';
		    		}
		    		if(isset($_SESSION['mediaCutFile']) && !empty($_SESSION['mediaCutFile']))  // cut
		    		{
    		    		if($this->webPath == $_SESSION['mediaCutFile'][1] && in_array($fileName, $_SESSION['mediaCutFile'][2]))
    		    		{
    		    		    $class .= '" style="background-color: ' . $this->highlightCCColor . ';';
    		    		}
		    		}
		    		if(isset($_SESSION['mediaCopyFile']) && !empty($_SESSION['mediaCopyFile']))  // copy
		    		{
    		    		if($this->webPath == $_SESSION['mediaCopyFile'][1] && in_array($fileName, $_SESSION['mediaCopyFile'][2]))
    		    		{
    		    		    $class .= '" style="background-color: ' . $this->highlightCCColor . ';';
    		    		}
		    		}
		    		
		    	    $this->_objTpl->setVariable(array(  // file
		    	        'MEDIA_DIR_TREE_ROW'  => $class,
		    	        'MEDIA_FILE_ICON'     => $this->iconWebPath . $dirTree[$key]['icon'][$x] . '.gif',
		    	        'MEDIA_FILE_NAME'     => $fileName,
		    	        'MEDIA_FILE_SIZE'     => $this->_formatSize($dirTree[$key]['size'][$x]),
		    	        'MEDIA_FILE_TYPE'     => $this->_formatType($dirTree[$key]['type'][$x]),
		    	        'MEDIA_FILE_DATE'     => $this->_formatDate($dirTree[$key]['date'][$x]),
		    	        'MEDIA_FILE_PERM'     => $this->_formatPerm($dirTree[$key]['perm'][$x], $key)
		    	    ));
		    	    
		    	    
		    	    // creates link
		    	    if($key == 'dir')
		    	    {
		    	        $tmpHref= 'index.php?cmd=media&amp;path=' . $this->webPath . $fileName . '/';
		    	    }
		    	    elseif($key == 'file')
		    	    {
		    	        if($this->_isImage($this->path . $fileName))
		    	        {
		    	            $tmpHref = 'javascript: expandcontent(\'preview_' . $fileName . '\');';
		    	        }
		    	        else
		    	        {
    		    	        $tmpHref = 'index.php?cmd=media&amp;act=download&path=' . $this->webPath . '&file='. $fileName;
		    	        }
		    	    }
		    	    
	    	        $this->_objTpl->setVariable(array(
	    	            'MEDIA_FILE_NAME_HREF'  => $tmpHref
	    	        ));
	    	        
	    	        // show thumbnail
	    	        if($this->_isImage($this->path . $fileName))
	    	        {
	    	            // make thumbnail if it doesn't exist
		    	        $tmpSize = @getimagesize($this->path . $fileName);

	    	            if(!file_exists($this->path . $fileName . '.thumb') && $tmpSize[1] > $this->thumbHeight)
	    	            {
	    	                $this->_createThumbnail($this->path . $fileName);
	    	                
		    	            $thbSize = @getimagesize($this->path . $fileName . '.thumb');
		    	            $thumb   = $this->webPath . $fileName . '.thumb';
	    	            }
	    	            elseif($tmpSize[1] > $this->thumbHeight)
	    	            {
	    	                $thbSize = @getimagesize($this->path . $fileName . '.thumb');
		    	            $thumb   = $this->webPath . $fileName . '.thumb';
	    	            }
	    	            else
	    	            {
	    	                $thbSize = @getimagesize($this->path . $fileName);
		    	            $thumb   = $this->webPath . $fileName;
	    	            }
	    	            
	    	            $this->_objTpl->setVariable(array(  // thumbnail
	    	                'MEDIA_FILE_NAME_SIZE'     => $tmpSize[0] . ' x ' . $tmpSize[1],
		    	            'MEDIA_FILE_NAME_PRE'      =>'preview_' . $fileName,
		    	            'MEDIA_FILE_NAME_IMG_HREF' => $tmpHref = 'javascript: preview(\'' . $this->webPath . $fileName . '\', ' . $tmpSize[0] . ', ' . $tmpSize[1] . ');',
	    	                'MEDIA_FILE_NAME_IMG_SRC'  => $thumb,
	    	                'MEDIA_FILE_NAME_IMG_SIZE' => $thbSize[3]
	    	            ));
	    	            $this->_objTpl->parse('mediaShowThumbnail');
	    	        }
		    	    
		    	    $this->_objTpl->setVariable(array(  // action
		    	        'MEDIA_FILE_EDIT_HREF'   => 'index.php?cmd=media&amp;act=edit&path=' . $this->webPath . '&file=' . $fileName,
		    	        'MEDIA_EDIT'             => $_ARRAYLANG['TXT_MEDIA_EDIT'] . ': ' . $fileName,
		    	        'MEDIA_FILE_DELETE_HREF' => 'index.php?cmd=media&amp;act=delete&path=' . $this->webPath . '&file=' . $fileName,
		    	        'MEDIA_DELETE'           => $_ARRAYLANG['TXT_MEDIA_DELETE'] . ': ' . $fileName
		    	    ));
		    	    
		    	    $this->_objTpl->parse('mediaDirectoryTree');
		    	    $i++;
		    	}    		    
    		}
    	}
    	
    	// empty dir or php safe mode restriction
    	if($i == 0 || !@opendir($this->path))
    	{
    	    if(!@opendir($this->path))
    	    {
    	        $tmpMessage = 'PHP Safe Mode Restriction!';
    	    }
    	    else
    	    {
    	        $tmpMessage = $_ARRAYLANG['TXT_MEDIA_DIR_EMPTY'];
    	    }
    	    
    	    $this->_objTpl->setVariable(array(
    	        'TXT_MEDIA_DIR_EMPTY'   => $tmpMessage,
    	        'MEDIA_SELECT_STATUS'   => ' disabled'
    	    ));
    	    $this->_objTpl->parse('mediaEmptyDirectory');
    	}
    	// not empty dir (select action)
    	else
    	{    	    
    	    $this->_objTpl->setVariable(array(
    	        'TXT_MEDIA_SELECT_ACTION'  => $_ARRAYLANG['TXT_MEDIA_SELECT_ACTION'],
    	        'TXT_MEDIA_CUT'            => $_ARRAYLANG['TXT_MEDIA_CUT'],
    	        'TXT_MEDIA_COPY'           => $_ARRAYLANG['TXT_MEDIA_COPY'],
    	        'TXT_MEDIA_DELETE'         => $_ARRAYLANG['TXT_MEDIA_DELETE']
    	    ));
    	    $this->_objTpl->parse('mediaSelectAction');
    	}
    	// paste media
	    if(isset($_SESSION['mediaCutFile']) or isset($_SESSION['mediaCopyFile']))
	    {
    	    $this->_objTpl->setVariable(array(
    	        'MEDIDA_PASTE_ACTION'      => 'index.php?cmd=media&amp;act=paste&path=' . $this->webPath,
    	        'TXT_MEDIA_PASTE'          => $_ARRAYLANG['TXT_MEDIA_PASTE']
    	    ));
    	    $this->_objTpl->parse('mediaActionPaste');
	    }
    	
    	// parse variables
    	$tmpHref  = 'index.php?cmd=media&amp;act=sort&amp;path=' . $this->webPath;
    	$tmpIcon  = $this->_sortingIcons();
    	$tmpClass  = $this->_sortingClass();
    	
    	$this->_objTpl->setVariable(array(  // java script
    	    'TXT_MEDIA_CHECK_NAME'      => $_ARRAYLANG['TXT_MEDIA_CHECK_NAME'],
    	    'TXT_MEDIA_CONFIRM_DELETE_2'  => $_ARRAYLANG['TXT_MEDIA_CONFIRM_DELETE_2'],
    	    'MEDIA_DO_ACTION_PATH'      => $this->webPath,
    	    'TXT_MEDIA_MAKE_SELECTION'  => $_ARRAYLANG['TXT_MEDIA_MAKE_SELECTION'],
    	    'TXT_MEDIA_SELECT_UPLOAD_FILE' => $_ARRAYLANG['TXT_MEDIA_SELECT_UPLOAD_FILE'],
    	    'MEDIA_JAVA_SCRIPT_PREVIEW' => $this->_getJavaScriptCodePreview()
    	));
    	
    	$this->_objTpl->setVariable(array(  // create new directory
    	    'TXT_MEDIA_NEW_DIRECTORY'   => $_ARRAYLANG['TXT_MEDIA_NEW_DIRECTORY'],
    	    'MEDIA_CREATE_DIR_ACTION'   => 'index.php?cmd=media&amp;act=newDir&amp;path=' . $this->webPath,
    	    'TXT_MEDIA_NAME'            => $_ARRAYLANG['TXT_MEDIA_NAME'],
    	    'TXT_MEDIA_CREATE'          => $_ARRAYLANG['TXT_MEDIA_CREATE']
    	));
    	
    	$this->_objTpl->setVariable(array(  // upload files
    	    'TXT_MEDIA_UPLOAD_FILES'    => $_ARRAYLANG['TXT_MEDIA_UPLOAD_FILES'],
    	    'MEDIA_UPLOAD_FILES_ACTION' => 'index.php?cmd=media&amp;act=upload&amp;path=' . $this->webPath,
    	    'TXT_MEDIA_UPLOAD'          => $_ARRAYLANG['TXT_MEDIA_UPLOAD']
    	));
    	
    	$this->_objTpl->setVariable(array(  // parse dir content
    	    'MEDIA_NAME_HREF'           => $tmpHref . '&amp;sort=name',
    	    'MEDIA_SIZE_HREF'           => $tmpHref . '&amp;sort=size',
    	    'MEDIA_TYPE_HREF'           => $tmpHref . '&amp;sort=type',
    	    'MEDIA_DATE_HREF'           => $tmpHref . '&amp;sort=date',
    	    'MEDIA_PERM_HREF'           => $tmpHref . '&amp;sort=perm',
    	    'TXT_MEDIA_FILE_NAME'       => $_ARRAYLANG['TXT_MEDIA_FILE_NAME'],
    	    'TXT_MEDIA_FILE_SIZE'       => $_ARRAYLANG['TXT_MEDIA_FILE_SIZE'],
    	    'TXT_MEDIA_FILE_TYPE'       => $_ARRAYLANG['TXT_MEDIA_FILE_TYPE'],
    	    'TXT_MEDIA_FILE_DATE'       => $_ARRAYLANG['TXT_MEDIA_FILE_DATE'],
    	    'TXT_MEDIA_FILE_PERM'       => $_ARRAYLANG['TXT_MEDIA_FILE_PERM'],
    	    'MEDIA_NAME_ICON'           => $tmpIcon['name'],
    	    'MEDIA_SIZE_ICON'           => $tmpIcon['size'],
    	    'MEDIA_TYPE_ICON'           => $tmpIcon['type'],
    	    'MEDIA_DATE_ICON'           => $tmpIcon['date'],
    	    'MEDIA_PERM_ICON'           => $tmpIcon['perm'],
    	    'MEDIA_NAME_CLASS'           => $tmpClass['name'],
    	    'MEDIA_SIZE_CLASS'           => $tmpClass['size'],
    	    'MEDIA_TYPE_CLASS'           => $tmpClass['type'],
    	    'MEDIA_DATE_CLASS'           => $tmpClass['date'],
    	    'MEDIA_PERM_CLASS'           => $tmpClass['perm'],
    	));
    }



    /**
    * Edit Media Data
    *   
    * @global	 array     $_ARRAYLANG
    * @return    string    parsed content                                                                               
    */

    function _editMedia()
    {
        global $_ARRAYLANG;
        
    	$this->_objTpl->loadTemplateFile('module_media_edit.html', true, true);
    	$this->pageTitle = $_ARRAYLANG['TXT_MEDIA_EDIT_FILE'];
    	
    	$check = true;
    	(!isset($this->getFile) && empty($this->getFile)) ? $check = false : '';
    	(!isset($this->getPath) && empty($this->getPath)) ? $check = false : '';
    	(!file_exists($this->path . $this->getFile))      ? $check = false : '';
    	
    	if($check == false)  // file doesn't exist
    	{
    	    $this->_objTpl->setVariable(array(  // ERROR
        	    'TXT_MEDIA_ERROR_OCCURED'    => $_ARRAYLANG['TXT_MEDIA_ERROR_OCCURED'],
        	    'TXT_MEDIA_FILE_DONT_EXISTS' => $_ARRAYLANG['TXT_MEDIA_FILE_DONT_EXISTS']
        	));
        	$this->_objTpl->parse('mediaErrorFile');
    	}
    	elseif($check == true)  // file exists
    	{
    	    $this->_objTpl->setVariable(array(  // java script
    	        'TXT_MEDIA_RENAME_NAME'  => $_ARRAYLANG['TXT_MEDIA_RENAME_NAME'],
    	        'TXT_MEDIA_RENAME_EXT'   => $_ARRAYLANG['TXT_MEDIA_RENAME_EXT']
    	    ));
    	    
        	$this->_objTpl->setVariable(array(  // txt
        	    'MEDIA_EDIT_ACTION'         => 'index.php?cmd=media&act=ren&path=' . $this->webPath,
        	    'MEDIA_EDIT_ACTION_PREVIEW' => 'index.php?cmd=media&act=preview&path=' . $this->webPath .'&file=' . $this->getFile,
        	    'MEDIA_EDIT_ACTION_PREVIEW_S' => 'index.php?cmd=media&act=previewSize&path=' . $this->webPath .'&file=' . $this->getFile,
        	    'TXT_MEDIA_EDIT_FILE'       => $_ARRAYLANG['TXT_MEDIA_EDIT_FILE'],
        	    'MEDIA_DIR'                 => $this->webPath,
        	    'MEDIA_FILE'                => $this->getFile,
        	    'TXT_MEDIA_INSERT_AS_COPY'  => $_ARRAYLANG['TXT_MEDIA_INSERT_AS_COPY'],
        	    'TXT_MEDIA_SAVE'            => $_ARRAYLANG['TXT_MEDIA_SAVE'],
            	'TXT_MEDIA_RESET'           => $_ARRAYLANG['TXT_MEDIA_RESET'],
            	'TXT_PREVIEW' => $_ARRAYLANG['TXT_PREVIEW'],
        	));
        	
            $icon     = $this->_getIcon($this->path . $this->getFile);
            $fileName = $this->getFile;
        	
        	// extension
        	if(is_file($this->path . $this->getFile))
        	{
            	$info     = pathinfo($this->getFile);
                $fileExt  = $info['extension'];
                $ext      = (!empty($fileExt)) ? '.' . $fileExt : '';
                $fileName = substr($this->getFile, 0, strlen($this->getFile) - strlen($ext));
                
                $this->_objTpl->setVariable(array(
        	        'MEDIA_ORGFILE_EXT'   => $fileExt . ''
                ));
        	    $this->_objTpl->parse('mediaFileExt');
        	}
            
        	// edit name
        	$this->_objTpl->setVariable(array(
        	    'MEDIA_FILE_ICON'     => $this->iconWebPath . $icon . '.gif',
        	    'MEDIA_ORGFILE_NAME'  => $fileName
        	));
        	
        	// edit image
        	if($this->_isImage($this->path . $this->getFile))
        	{
        	    $tmpSize  = @getimagesize($this->path . $this->getFile);
        	    $fileSize = $this->_formatSize($this->_getSize($this->path . $this->getFile));
        	    
        	    $this->_objTpl->setVariable(array(
        	        'TXT_MEDIA_EDIT_IMAGE' => $_ARRAYLANG['TXT_MEDIA_EDIT_IMAGE'],
        	        'TXT_MEDIA_NO'         => $_ARRAYLANG['TXT_MEDIA_NO'],
        	        'TXT_MEDIA_YES'        => $_ARRAYLANG['TXT_MEDIA_YES'],
        	    ));
        	    $this->_objTpl->parse('mediaShowImage');
        	    
        	    $this->_objTpl->setVariable(array(
            	    'TXT_MEDIA_EDIT_IMAGE' => $_ARRAYLANG['TXT_MEDIA_EDIT_IMAGE'],
            	    'TXT_MEDIA_FILE_SIZE'  => $_ARRAYLANG['TXT_MEDIA_FILE_SIZE'],
            	    'TXT_MEDIA_WIDTH'      => $_ARRAYLANG['TXT_MEDIA_WIDTH'],
            	    'TXT_MEDIA_HEIGHT'     => $_ARRAYLANG['TXT_MEDIA_HEIGHT'],
            	    'TXT_MEDIA_BALANCE'    => $_ARRAYLANG['TXT_MEDIA_BALANCE'],
            	    'TXT_MEDIA_QUALITY'    => $_ARRAYLANG['TXT_MEDIA_QUALITY'],
            	    'MEDIA_FILE_SIZE'      => $fileSize,
            	    'MEDIA_IMG_WIDTH'      => $tmpSize[0],
            	    'MEDIA_IMG_HEIGHT'     => $tmpSize[1],
            	    'MEDIA_FILE_IMAGE_IMG' => $this->webPath . $this->getFile
        	    ));
        	   $this->_objTpl->parse('mediaFileImage');
        	}
        	
        	$this->_objTpl->parse('mediaFile');
    	}
    	
    	// variables
    	$this->_objTpl->setVariable(array(
    	    'TXT_MEDIA_BACK'        => $_ARRAYLANG['TXT_MEDIA_BACK'],
    	    'MEDIA_BACK_HREF'       => 'index.php?cmd=media&amp;path=' . $this->webPath
	    ));
    }
}
?>