<?php

/**
* Class IMAGE MANAGER
*
* @copyright     ASTALAVISTA SECURE CMS - 2004 Astalavista Group GmbH
* @module    	 
* @modulegroups  
* @author        Paulo M. Santos <pmsantos@astalavista.net>
* @version       1.0
* @access        public
*/

class ImageManager
{
    var $orgImage;
    var $orgImageWidth;
    var $orgImageHeight;
    var $orgImageType;
    var $orgImageFile;
    
    var $newImage;
    var $newImageWidth;
    var $newImageHeight;
    var $newImageQuality;
    var $newImageType;
    var $newImageFile;
    
    var $imageCheck       = 1;
       
    
    
    /**
     * Constructor
     *
     * @access   public
     * @return   void
     */     
    function ImageManager()
    {
        $this->__construct();
    }
    
    
    
    function __construct()
    {
        $this->_resetVariables();
    }    
    
    
    /**
     * Load Image
     *
     * Loads an existing image into a variable
     *
     * @access   public
     * @param    string [$file] path and filename of the existing image
     * @return   bool
     */    
    function loadImage($file)
    {
        $this->_resetVariables();
        $this->orgImageFile = $file;
        
        if($this->orgImageType = $this->_isImage($this->orgImageFile))
        {
            $getImage             = $this->_getImageSize($this->orgImageFile);
            $this->orgImageWidth  = $getImage[0];
            $this->orgImageHeight = $getImage[1];
            
            if($this->orgImage = $this->_imageCreateFromFile($this->orgImageFile))
            {
                return true;
            }
            else
            {
                $this->imageCheck = 0;
                $this->_resetVariables();
                return false;
            }
            
            return true;
        }
        else
        {
            $this->imageCheck = 0;
            $this->_resetVariables();
            return false;
        }
    }   
    
    
    
    /**
     * Resize Image
     *
     * Resizes the loaded Image as you wish and creates a variable with
     * the new image
     *
     * @access   public
     * @param    string [$width]   width of the new image
     * @param    string [$height]  height of the new image
     * @param    string [$quality] quality for the new image
     * @return   bool
     */  
    function resizeImage($width, $height, $quality)
    {
        if($this->imageCheck == 1)
        {
            $this->newImageWidth   = $width;
            $this->newImageHeight  = $height;
            $this->newImageQuality = $quality;
            $this->newImageType    = $this->orgImageType;
            
            if(function_exists ("imagecreatetruecolor")) {
            	$this->newImage = @imagecreatetruecolor($this->newImageWidth, $this->newImageHeight);
            	// GD > 2 check
            	if (!$this->newImage) { $this->newImage = ImageCreate($this->newImageWidth, $this->newImageHeight); }  
            } else {
            	$this->newImage = ImageCreate($this->newImageWidth, $this->newImageHeight);
            }                  
            imagecopyresized($this->newImage, $this->orgImage, 0, 0, 0, 0, $this->newImageWidth + 1, $this->newImageHeight + 1, $this->orgImageWidth, $this->orgImageHeight); 
            return true;
        }
        else
        {
            return false;
        }
    }
    
    
    
    
    
    /**
     * Saves new image
     *
     * Saves the new image wherever you want
     *
     * @access   public
     * @param    string [$file] path and filename where to save the new image
     * @return   bool
     */ 
    function saveNewImage($file)
    {
        if($this->imageCheck == 1 && !empty($this->newImage))
        {
            $this->newImageFile = $file;
        
            switch($this->newImageType)
            {
                case 1:  // gif
                    $function = 'imagegif';
                    if(!function_exists($function)){
                        $function = 'imagejpeg';
                    }
                    break;
                case 2:  // jpg
                    $function = 'imagejpeg';
                    break;
                case 3:  // png
                    $function = 'imagepng';
                    break;
                default:
                    return false;
            }
            
            $function($this->newImage, $this->newImageFile, $this->newImageQuality);
            return true;
        }
        else
        {
            return false;
        }
    }
    
    
    
    
    
    /**
     * Show new image
     *
     * Outputs the new image into the browser
     * or inserts it in a <img .. > tag
     *
     * @access   public
     * @return   bool
     */ 
    function showNewImage()
    {
        if($this->imageCheck == 1 && !empty($this->newImage))
        {
            switch($this->newImageType)
            {
                case 1:  // gif
                    header("Content-type: image/gif");
                    $function = 'imagegif';
                    if(!function_exists($function)){
                        $function = 'imagejpeg';
                    }
                    break;
                case 2:  // jpg
                    header("Content-type: image/jpeg");
                    $function = 'imagejpeg';
                    break;
                case 3:  // png
                    header("Content-type: image/png");
                    $function = 'imagepng';
                    break;
                default:
                    return false;
            }            
            $function($this->newImage, '', $this->newImageQuality);           
            return true;
        }
        else
        {
            return false;
        }
    }
    
    
    
    
    
    /**
     * Reset variables
     *
     * Resets all variales
     *
     * @access   private
     * @return   void
     */
    function _resetVariables()
    {
        $this->orgImage        = '';
        $this->orgImageWidth   = '';
        $this->orgImageHeight  = '';
        $this->orgImageType    = '';
        $this->orgImageFile    = '';
        
        $this->newImage        = '';
        $this->newImageWidth   = '';
        $this->newImageHeight  = '';
        $this->newImageQuality = '';
        $this->newImageType    = '';
        $this->newImageFile    = '';
    }
    
    
    
    
    
    /**
     * Create Image
     *
     * Creates a new image from ana old image
     *
     * @access   private
     * @param    string [$file] path and filename of the old image
     * @return   string [$image] image variable
     */
    function _imageCreateFromFile($file)
    {
        if($type = $this->_isImage($file))
        {
            switch($type)
            {
                case 1:  // gif
                    $function = 'imagecreatefromgif';
                    break;
                case 2:  // jpg
                    $function = 'imagecreatefromjpeg';
                    break;
                case 3:  // png
                    $function = 'imagecreatefrompng';
                    break;
                default:
                    return false;     
            }
            
            $image = $function($file);            
            return $image;  
        }
        else
        {
            return false;
        }
    }
    
    
    
    
    
    /**
     * Image Check
     *
     * Checks if the file is an image or not
     *
     * @access   private
     * @param    string [$file] path and filename of the old image
     * @return   string [$imageSize[2]] type of the image
     */
    function _isImage($file)
    {
        if(file_exists($file))
        {
            $imageSize = $this->_getImageSize($file);
            
            // 1 = GIF,  2 = JPG,  3 = PNG,  4 = SWF,  5 = PSD, 6 = BMP, 7 = TIFF(intel byte order), 8 = TIFF(motorola byte order,
            // 9 = JPC, 10 = JP2, 11 = JPX, 12 = JB2, 13 = SWC
            
            if($imageSize[2] == 1 || $imageSize[2] == 2 || $imageSize[2] == 3)  // gif, jpg, png
            {
                if($imageSize[2] == 1)
                {
                    if(function_exists(imagecreatefromgif))  // for test add an !
                    {
                        return $imageSize[2];
                    }
                    else
                    {
                        return false;
                    }
                }
                else
                {
                    return $imageSize[2];
                }
            }
            else
            {
                return false;
            }
        }
        else
        {
            return false;
        }
    }
    
    
    
    
    
    /**
     * Image Size
     *
     * Gets the size of the image
     *
     * @access   private
     * @param    string [$file] path and filename of the old image
     * @return   array [$getImageSize] function getimagesize() of the image
     */
    function _getImageSize($file)
    {
        if($getImageSize = @getimagesize($file))
        {
            return $getImageSize;
        }
        else
        {
            return false;
        }
    }
}
?>