<?PHP
/**
* Guestbook Modul
*
* frontend guestbook class
*
* @copyright   ASTALAVISTA SECURE CMS - 2004 Astalavista IT Engineering GmbH 
* @author      Ivan Schmid <ivan.schmid@astalavista.ch>   
* @module      guestbook
* @modulegroup modules
*/

require_once ASCMS_MODULE_PATH . '/guestbook/Lib.class.php';



class Guestbook extends GuestbookLibrary
{	
    var $langId;
    var $_objTpl;
    var $statusMessage;
    
    		
	/**
    * Constructor
    *
    * @param  string  
    * @access public
    */   
    function Guestbook($pageContent)
    { 
    	$this->__construct($pageContent);    
    }
	

    
    /**
     * PHP5 constructor
     * @param  string  $pageContent
     * @global string  $_LANGID      
     * @access public     
     */
    function __construct($pageContent)
    {  
	    global $_LANGID;
	    $this->pageContent = $pageContent;
	    $this->langId = $_LANGID;
	    $this->objTemplate = &new Template();
	    
	    $this->_objTpl = &new HTML_Template_Sigma('.');
		$this->_objTpl->setErrorHandling(PEAR_ERROR_DIE);   
	}

	
	
	
	function getPage()
	{
    	if(!isset($_REQUEST['cmd']))
    	{
    		$_REQUEST['cmd'] = '';
    	}
    	
    	switch($_REQUEST['cmd'])
    	{
    		case 'post':
		    	$this->_showForm();
		    	break;
		    default:
		        $this->_store();
		        $this->_showList();
		        break;
    	}
    	return $this->_objTpl->get(); 
    }	
	

    
    
    
    
    
	/**
	* shows the submit form
	*
	* @access private
	*/
	
	function _showForm()
	{	
		$this->_objTpl->setTemplate($this->pageContent, true, true);
		$this->_objTpl->setVariable("GUESTBOOK_JAVASCRIPT", $this->_getJavascript());
	}
    
    
	/**
	* Gets the guestbook status
	*
	* @global  array    $_CONFIG
	* @global  array    $_ARRAYLANG
	* @global  object   $db
	* @access private	
	*/
	
	function _showList()
	{
		global $db, $_CONFIG, $_ARRAYLANG;
		
		$this->_objTpl->setTemplate($this->pageContent, true, true);
		
		// initialize variables
	    $i = 1;
	    $paging = "";
		$pos = (isset($_GET['pos'])) ? intval($_GET['pos']) : 0;		
	
		/** start paging **/
		$db->query("SELECT * 
		              FROM ".DBPREFIX."module_guestbook 
		             WHERE lang_id=".$this->langId."
		          ORDER BY id DESC");
				
		$count = $db->num_rows();
		$paging = getPaging($count, $pos, "&amp;section=guestbook", "<b>".$_ARRAYLANG['TXT_GUESTBOOK_ENTRIES']."</b>", false);
		/** end paging **/
		
		$this->_objTpl->setVariable("GUESTBOOK_PAGING", $paging);
        $this->_objTpl->setVariable("GUESTBOOK_TOTAL_ENTRIES", $count);
					
		$db->query("SELECT * 
		              FROM ".DBPREFIX."module_guestbook
				     WHERE lang_id=".$this->langId." 
		          ORDER BY id DESC LIMIT $pos, {$_CONFIG['corePagingLimit']}");
		
		while($db->next_record()){
			$class = ($i % 2) ? "row1" : "row2";
			$gender = ($db->f("gender")=="M") ? $_ARRAYLANG['guestbookGenderMale'] : $_ARRAYLANG['guestbookGenderFemale']; // N/A
			
			if ($db->f('url')!=""){
				$this->_objTpl->setVariable("GUESTBOOK_URL", "<a href='".$db->f('url')."'><img alt='".$db->f('url')."' src='".ASCMS_MODULE_IMAGE_WEB_PATH."/guestbook/www.gif' align='baseline' border='0' /></a>");
			}
			if ($db->f('email')!=""){
				$this->_objTpl->setVariable("GUESTBOOK_EMAIL", "<a href='mailto:".$db->f('email')."'><img alt='".$db->f("email")."' src='".ASCMS_MODULE_IMAGE_WEB_PATH."/guestbook/email.gif' align='baseline' border='0' /></a>");
			}
			
			$this->_objTpl->setVariable(array(
					   'GUESTBOOK_ROWCLASS'   => $class,
					   'GUESTBOOK_NICK'	      => stripslashes($db->f("nickname")),
					   'GUESTBOOK_GENDER'	  => $gender,
					   'GUESTBOOK_LOCATION'	  => stripslashes($db->f("location")),
					   'GUESTBOOK_DATE'		  => $db->f("datetime"),
					   'GUESTBOOK_COMMENT'	  => stripslashes($db->f("comment")),
					   'GUESTBOOK_ID'		  => $db->f("id"),
					   'GUESTBOOK_IP'		  => $db->f("ip")
			));
			$this->_objTpl->parse('guestbook_row');
			$i++;
		}
		$this->_objTpl->setVariable("GUESTBOOK_STATUS", $this->statusMessage);
	}	

	
	
	
	/**
	* Save an entry
	*
	* @global  array    $_POST
	* @global  array    $_ARRAYLANG
	* @global  object   $db
	* @return  string   $status
	*/
	function _store()
	{
		global $db, $_ARRAYLANG;

		if(isset($_POST['nickname']) && isset($_POST['comment']) &&
		  !empty($_POST['nickname']) && !empty($_POST['comment']))
		{
			$error = "";
			$nick = htmlspecialchars($_POST['nickname']);
			$gender = htmlspecialchars($_POST['malefemale']);
			$mail = (isset($_POST['email'])&& strlen($_POST['email'])>7) ?  htmlspecialchars($_POST['email']) : ""; 
			$url = (isset($_POST['url'])&& strlen($_POST['url'])>7) ? htmlspecialchars($_POST['url']) : ""; 
			$comment = nl2br($this->addHyperlinking(htmlspecialchars(strip_tags($_POST['comment']))));
			$location = htmlspecialchars($_POST['location']);
			
			if(!empty($url)) { 
				if (!$this->isUrl($url)) $error.= $_ARRAYLANG['TXT_INVALID_INTERNET_ADDRESS']."<br />"; 
			}
			if(!empty($mail)){
				if(!$this->isEmail($mail)) $error.= $_ARRAYLANG['TXT_INVALID_EMAIL_ADDRESS']."<br />";
			}
			if(empty($error)){
			    $db->query("INSERT INTO ".DBPREFIX."module_guestbook 
			                            (id,
			                             nickname,
									     gender,
									     url,
									     datetime,
									     email,
									     comment,
									     ip,
			                             location,
			                             lang_id)
					             VALUES ('',
										'$nick', 
										'$gender', 
										'$url', 
										NOW(), 
										'$mail', 
										'$comment', 
										'{$_SERVER['REMOTE_ADDR']}', 
										'$location', 			    
										'$this->langId')
			                           ");
			    
			    $this->sendNotificationEmail($nick, $comment);			    
			    $this->statusMessage = $_ARRAYLANG['TXT_DATA_RECORD_STORED_SUCCESSFUL']."<br />";
			} else {
			    $this->statusMessage = $error;	
			}
		}
	}

	

    /**
    * @return void
    * @desc Sends a notification email to the administrator
    */	
	function sendNotificationEmail($nick,$comment) {
		global $_ARRAYLANG, $_CONFIG;
	    $message = $_ARRAYLANG['TXT_CHECK_GUESTBOOK_ENTRY']."\n\n";
	    $message .= $_ARRAYLANG['TXT_ENTRY_READS']."\n".$nick."\n".$comment;
	    $mailto = $_CONFIG['coreAdminEmail'];
	    $subject = $_ARRAYLANG['TXT_NEW_GUESTBOOK_ENTRY']." ".$_SERVER['HTTP_HOST'];
		$return = @mail($mailto, 
		                $subject, 
		                $message,
		                "From: ".$mailto."\r\n" .
		                "Reply-To: ".$mailto."\r\n" .
		                "X-Mailer: PHP/" . phpversion());
		return $return;				
	}	
}
?>
